#ifndef LIB_ERRDESC_MQH_INCLUDED
#define LIB_ERRDESC_MQH_INCLUDED
/**********************************************************************************
 * Copyright (C) 2010-2022 Dominik Egert <info@freie-netze.de>
 *
 * This file is error code error messages include file.
 *
 * MQLplus, including this file may not be copied and/or distributed 
 * without explecit permit by the author.
 * Author Dominik Egert / Freie Netze UG.
 **********************************************************************************
 *
 *  Version: 4.2
 *  State: public
 *
 *  File information
 *  ================
 *
 *
 *  Use: resolve error codes to text.
 *
 *      Content is provided as is. All text
 *      and definitions have been extracted from
 *      https://www.mql5.com/en/docs/constants/errorswarnings/errorcodes
 *      https://www.mql5.com/en/docs/constants/errorswarnings/enum_trade_return_codes
 *
 *      Feel free to edit or add any new codes
 *
 *  Date of update: 29. April 2022
*/
#ifdef DBG_MSG_TRACE_FILE_LOADER
    DBG_MSG_TRACE_FILE_LOADER;

#endif


// Language specific error code resolver (english)
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "The operation completed successfully.")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "Unexpected internal error.")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "Wrong parameter in the inner call of the client terminal function.")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "Wrong parameter when calling the system function.")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "Not enough memory to perform the system function.")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "The structure contains objects of strings and/or dynamic arrays and/or structure of such objects and/or classes.")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "Array of a wrong type, wrong size, or a damaged object of a dynamic array.")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "Not enough memory for the relocation of an array, or an attempt to change the size of a static array.")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "Not enough memory for the relocation of string.")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "Not initialized string.")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "Invalid date and/or time.")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "Requested array size exceeds 2 GB.")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "Wrong pointer.")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "Wrong type of pointer.")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "Function is not allowed for call.")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "The names of the dynamic and the static resource match.")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "Resource with this name has not been found in EX5.")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "Unsupported resource type or its size exceeds 16 Mb.")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "The resource name exceeds 63 characters.")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "Overflow occurred when calculating math function.")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Out of test end date after calling Sleep().")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                      "ERR_PROGRAM_STOPPED",                     "Test forcibly stopped from the outside. For example, optimization interrupted, visual testing window closed or testing agent stopped.")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "Wrong chart ID.")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "Chart does not respond.")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "Chart not found.")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "No Expert Advisor in the chart that could handle the event.")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "Chart opening error.")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "Failed to change chart symbol and period.")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "Error value of the parameter for the function of working with charts.")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "Failed to create timer.")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "Wrong chart property ID.")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "Error creating screenshots.")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "Error navigating through chart.")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "Error applying template.")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "Subwindow containing the indicator was not found.")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "Error adding an indicator to chart.")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "Error deleting an indicator from the chart.")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "Indicator not found on the specified chart.")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "Error working with a graphical object.")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "Graphical object was not found.")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "Wrong ID of a graphical object property.")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "Unable to get date corresponding to the value.")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "Unable to get value corresponding to the date.")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "Unknown symbol.")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "Symbol is not selected in MarketWatch.")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "Wrong identifier of a symbol property.")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "Time of the last tick is not known (no ticks).")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "Error adding or deleting a symbol in MarketWatch.")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "Requested history not found.")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "Wrong ID of the history property.")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "Exceeded history request timeout.")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "Number of requested bars limited by terminal settings.")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "Multiple errors when loading history.")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "Receiving array is too small to store all requested data.")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "Global variable of the client terminal is not found.")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "Global variable of the client terminal with the same name already exists.")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "Global variables were not modified.")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "Cannot read file with global variable values.")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "Cannot write file with global variable values.")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "Email sending failed.")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "Sound playing failed.")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "Wrong identifier of the program property.")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "Wrong identifier of the terminal property.")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "File sending via ftp failed.")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "Failed to send a notification.")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "Invalid parameter for sending a notification — an empty string or NULL has been passed to the SendNotification function.")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "Wrong settings of notifications in the terminal (ID is not specified or permission is not set).")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "Too frequent sending of notifications.")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "FTP server is not specified.")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "FTP login is not specified.")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "File not found in the MQL5\\Files directory to send on FTP server.")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "FTP connection failed.")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "FTP path not found on server.")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "FTP connection closed.")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "Not enough memory for the distribution of indicator buffers.")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "Wrong indicator buffer index.")


        // Custom Indicator Properties

            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "Wrong ID of the custom indicator property.")


        // Account

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "Wrong account property ID.")
            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "Wrong trade property ID.")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "Trading by Expert Advisors prohibited.")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "Position not found.")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "Order not found.")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "Deal not found.")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "Trade request sending failed.")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "Failed to calculate profit or margin.")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "Unknown symbol.")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "Indicator cannot be created.")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "Not enough memory to add the indicator.")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "The indicator cannot be applied to another indicator.")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "Error applying an indicator to chart.")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "Requested data not found.")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "Wrong indicator handle.")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "Wrong number of parameters when creating an indicator.")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "No parameters when creating an indicator.")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "The first parameter in the array must be the name of the custom indicator.")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "Invalid parameter type in the array when creating an indicator.")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "Wrong index of the requested indicator buffer.")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "Depth Of Market can not be added.")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "Depth Of Market can not be removed.")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "The data from Depth Of Market can not be obtained.")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "Error in subscribing to receive new data from Depth Of Market.")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "More than 64 files cannot be opened at the same time.")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "Invalid file name.")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "Too long file name.")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "File opening error.")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "Not enough memory for cache to read.")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "File deleting error.")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "A file with this handle was closed, or was not opening at all.")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "Wrong file handle.")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "The file must be opened for writing.")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "The file must be opened for reading.")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "The file must be opened as a binary one.")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "The file must be opened as a text.")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "The file must be opened as a text or CSV.")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "The file must be opened as CSV.")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "File reading error.")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "String size must be specified, because the file is opened as binary.")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "A text file must be for string arrays, for other arrays - binary.")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "This is not a file, this is a directory.")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "File does not exist.")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "File can not be rewritten.")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "Wrong directory name.")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "Directory does not exist.")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "This is a file, not a directory.")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "The directory cannot be removed.")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "Failed to clear the directory (probably one or more files are blocked and removal operation failed).")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "Failed to write a resource to a file.")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "Unable to read the next piece of data from a CSV file (FileReadString, FileReadNumber, FileReadDatetime, FileReadBool), since the end of file is reached.")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "No date in the string.")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "Wrong date in the string.")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "Wrong time in the string.")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "Error converting string to date.")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "Not enough memory for the string.")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "The string length is less than expected.")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "Too large number, more than ULONG_MAX.")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "Invalid format string.")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "Amount of format specifiers more than the parameters.")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "Amount of parameters more than the format specifiers.")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "Damaged parameter of string type.")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "Position outside the string.")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "0 added to the string end, a useless operation.")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "Unknown data type when converting to a string.")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "Damaged string object.")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "Copying incompatible arrays. String array can be copied only to a string array, and a numeric array - in numeric array only.")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "The receiving array is declared as AS_SERIES, and it is of insufficient size.")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "Too small array, the starting position is outside the array.")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "An array of zero length.")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "Must be a numeric array.")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "Must be a one-dimensional array.")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "Timeseries cannot be used.")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "Must be an array of type double.")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "Must be an array of type float.")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "Must be an array of type long.")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "Must be an array of type int.")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "Must be an array of type short.")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "Must be an array of type char.")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "String array only.")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "OpenCL functions are not supported on this computer.")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "Internal error occurred when running OpenCL.")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "Invalid OpenCL handle.")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "Error creating the OpenCL context.")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "Failed to create a run queue in OpenCL.")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "Error occurred when compiling an OpenCL program.")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "Too long kernel name (OpenCL kernel).")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "Error creating an OpenCL kernel.")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "Error occurred when setting parameters for the OpenCL kernel.")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "OpenCL program runtime error.")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "Invalid size of the OpenCL buffer.")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "Invalid offset in the OpenCL buffer.")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "Failed to create an OpenCL buffer.")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "Too many OpenCL objects.")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "OpenCL device selection error.")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "Internal database error.")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "Invalid database handle.")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "Exceeded the maximum acceptable number of Database objects.")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "Database connection error.")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "Request execution error.")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "Request generation error.")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "No more data to read.")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "Failed to move to the next request entry.")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "Data for reading request results are not ready yet.")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "Failed to auto substitute parameters to an SQL request.")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "Invalid URL.")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "Failed to connect to specified URL.")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "Timeout exceeded.")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "HTTP request failed.")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "Invalid socket handle passed to function.")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "Too many open sockets (max 128).")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "Failed to connect to remote host.")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "Failed to send/receive data from socket.")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "Failed to establish secure connection (TLS Handshake).")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "No data on certificate protecting the connection.")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "A custom symbol must be specified.")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "The name of the custom symbol is invalid. The symbol name can only contain Latin letters without punctuation, spaces or special characters (may only contain '.', '_', '&' and '#'). It is not recommended to use characters <, >, :, \", /,\\, |, ?, *.")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "The name of the custom symbol is too long. The length of the symbol name must not exceed 32 characters including the ending 0 character.")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "The path of the custom symbol is too long. The path length should not exceed 128 characters including 'Custom\\\\', the symbol name, group separators and the ending 0.")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "A custom symbol with the same name already exists.")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "Error occurred while creating, deleting or changing the custom symbol.")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "You are trying to delete a custom symbol selected in Market Watch.")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "An invalid custom symbol property.")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "A wrong parameter while setting the property of a custom symbol.")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "A too long string parameter while setting the property of a custom symbol.")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "Ticks in the array are not arranged in the order of time.")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "Array size is insufficient for receiving descriptions of all values.")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "Request time limit exceeded.")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "Country is not found.")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "Generic error.")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "SQLite internal logic error.")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "Access denied.")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "Callback routine requested abort.")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "Database file locked.")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "Database table locked.")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "Insufficient memory for completing operation.")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "Attempt to write to readonly database.")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "Operation terminated by sqlite3_interrupt.")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "Disk I/O error.")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "Database disk image corrupted.")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "Unknown operation code in sqlite3_file_control.")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "Insertion failed because database is full.")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "Unable to open the database file.")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "Database lock protocol error.")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "Internal use only.")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "Database schema changed.")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "String or BLOB exceeds size limit.")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "Abort due to constraint violation.")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "Data type mismatch.")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "Library used incorrectly.")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "Uses OS features not supported on host.")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "Authorization denied.")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "Not used.")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "Bind parameter error, incorrect index.")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "File opened that is not database file.")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "Requote.")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "Request rejected.")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "Request canceled by trader.")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "Order placed.")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "Request completed.")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "Only part of the request was completed.")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "Request processing error.")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "Request canceled by timeout.")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "Invalid request.")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "Invalid volume in the request.")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "Invalid price in the request.")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "Invalid stops in the request.")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "Trade is disabled.")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "Market is closed.")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "There is not enough money to complete the request.")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "Prices changed.")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "There are no quotes to process the request.")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "Invalid order expiration date in the request.")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "Order state changed.")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "Too frequent requests.")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "No changes in request.")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "Autotrading disabled by server.")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "Autotrading disabled by client terminal.")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "Request locked for processing.")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "Order or position frozen.")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "Invalid order filling type.")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "No connection with the trade server.")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "Operation is allowed only for live accounts.")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "The number of pending orders has reached the limit.")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "The volume of orders and positions for the symbol has reached the limit.")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "Incorrect or prohibited order type.")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "Position with the specified POSITION_IDENTIFIER has already been closed.")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "A close volume exceeds the current position volume.")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "A close order already exists for a specified position. This may happen when working in the hedging system:.")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "The number of open positions simultaneously present on an account can be limited by the server settings. After a limit is reached, the server returns the TRADE_RETCODE_LIMIT_POSITIONS error when attempting to place an order. The limitation operates differently depending on the position accounting type:.")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "The pending order activation request is rejected, the order is canceled.")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "The request is rejected, because the Only long positions are allowed rule is set for the symbol (POSITION_TYPE_BUY).")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "The request is rejected, because the Only short positions are allowed rule is set for the symbol (POSITION_TYPE_SELL).")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "The request is rejected, because the Only position closing is allowed rule is set for the symbol.")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "The request is rejected, because Position closing is allowed only by FIFO rule flag is set for the trading account (ACCOUNT_FIFO_CLOSE=true).")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "The request is rejected, because the 'Opposite positions on a single symbol are disabled' rule is set for the trading account. For example, if the account has a Buy position, then a user cannot open a Sell position or place a pending sell order. The rule is only applied to accounts with hedging accounting system (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING).")
    }

    // Return
    return(NULL);
}


// Language specific error code resolver (spanish)
#ifdef LIB_ERROR_LANG_TERM_ID_ES
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_ES)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "La operación se ha ejecutado con éxito.")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "Error interno inesperado.")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "Parámetro erróneo durante la llamada built-in a la función del terminal de cliente.")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "Parámetro erróneo durante la llamada a la función de sistema.")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "No hay memoria suficiente para ejecutar la función de sistema.")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "Estructura contiene objetos de cadenas y/o de arrays dinámicos y/o estructuras con estos objetos y/o clases.")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "Array del tipo inapropiado, tamaño inapropiado o objeto dañado del array dinámico.")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "No hay memoria suficiente para la reubicación de un array, o un intento de cambio del tamaño de un array estático.")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "No hay memoria suficiente para la reubicación de una cadena.")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "Cadena no inicializada.")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "Valor de fecha y/o hora incorrecto.")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "El número total de los elementos del array no puede superar 2147483647.")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "Puntero erróneo.")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "Tipo erróneo del puntero.")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "Función de sistema no está permitida para la llamada.")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "Coincidencia del nombre del recurso dinámico y estático.")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "Recurso con este nombre no encontrado en EX5.")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "Tipo del recurso no soportado o el tamaño superior a 16 Mb.")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "Nombre del recurso supera 63 caracteres.")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "Desbordamiento (overflow) ocurrido al calcular la función.")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Fuera de la fecha de finalización de la simulación tras llamar a Sleep().")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                       "ERR_PROGRAM_STOPPED",                     "La simulación ha sido interrumpida forzosamente desde el exterior. Por ejemplo, ha sido interrumpida por la optimización, o se ha cerrado la ventana de simulación visual, o se ha detenido el agente de simulación.")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "Identificador erróneo del gráfico.")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "Gráfico no responde.")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "Gráfico no encontrado.")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "Gráfico no tiene un Asesor Experto que pueda procesar el evento.")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "Error al abrir el gráfico.")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "Error al cambiar el símbolo y período del gráfico.")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "Valor erróneo del parámetro para la función de trabajo con los gráficos.")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "Error al crear el temporizador.")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "Identificador erróneo de la propiedad del gráfico.")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "Error al crear un screenshot.")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "error de navegación por el gráfico.")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "Error al aplicar una plantilla.")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "Subventana que contiene el indicador especificado no encontrada.")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "Error al insertar un indicador en el gráfico.")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "Error al quitar un indicador desde el gráfico.")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "El indicador no ha sido encontrado en el gráfico especificado.")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "Error al manejar un objeto gráfico.")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "Objeto gráfico no encontrado.")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "Identificador erróneo de la propiedad del objeto gráfico.")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "Imposible recibir fecha correspondiente al valor.")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "Imposible recibir valor correspondiente a la fecha.")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "Símbolo desconocido.")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "Símbolo no está seleccionado en MarketWatch.")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "Identificador erróneo de la propiedad del símbolo.")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "Hora del último tick no se conoce (no había ticks).")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "Error al agregar o eliminar el símbolo a/de MarketWatch.")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "Historial solicitado no encontrado.")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "Identificador erróneo de la propiedad del historial.")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "Se ha superado el límite de tiempo al solicitar la historia.")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "El número de barras solicitado está limitado por los ajustes del terminal.")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "Errores múltiples al cargar la historia.")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "La matriz receptora es demasiado pequeña para almacenar los datos solicitados.")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "Variable global del terminal de cliente no encontrada.")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "Variable global del terminal de cliente con este nombre ya existe.")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "Las variables globales no han sido modificadas.")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "No ha sido posible abrir y leer el archivo con los valores de las variables globales.")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "No ha sido posible grabar el archivo con los valores de las variables globales.")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "Envío de carta fallido.")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "Reproducción de sonido fallido.")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "Identificador erróneo de la propiedad del programa.")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "Identificador erróneo de la propiedad del terminal.")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "Envío de archivo a través de ftp fallido.")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "No se ha podido enviar la notificación.")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "Parámetro incorrecto para el envío de la notificación — en la función SendNotification() han pasado una línea vacía o NULL.")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "Ajustes incorrectos de las notificaciones en el terminal (ID no especificada o permiso no concedido).")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "Envío de notificaciones muy frecuente.")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "No se ha indicado el servidor ftp en los ajustes.")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "No se ha indicado el login ftp en los ajustes.")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "El archivo no existe.")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "No ha sido posible conectarse al servidor ftp.")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "En el servidor ftp no se ha encontrado el directorio para cargar el archivo.")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "La conexión al servidor ftp está cerrada.")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "No hay memoria suficiente para la redistribución de buffers de indicadores.")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "Índice erróneo de su búfer de indicadores.")


        // Custom Indicator Properties

            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "Identificador erróneo de la propiedad del indicador personalizado.")


        // Account

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "Identificador erróneo de la propiedad de la cuenta.")
            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "Identificador erróneo de la propiedad de la actividad comercial.")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "Prohibida la actividad comercial para el Asesor Experto.")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "Posición no encontrada.")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "Orden no encontrada.")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "Transacción no encontrada.")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "Envío de solicitud comercial fallida.")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "Fallo al calcular el valor del beneficio o el margen.")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "Símbolo desconocido.")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "No se puede crear indicador.")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "Memoria insuficiente para añadir el indicador.")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "Indicador no puede ser aplicado a otro indicador.")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "Error al añadir indicador.")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "Datos solicitados no encontrados.")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "Handle del indicador es erróneo.")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "Número erróneo de parámetros al crear un indicador.")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "No hay parámetros cuando se crea un indicador.")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "El primer parámetro en la matriz tiene que ser el nombre del indicador personalizado.")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "Tipo erróneo del parámetro en la matriz al crear un indicador.")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "Índice del búfer de indicador que se solicita es erróneo.")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "No se puede añadir la profundidad de mercado.")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "No se puede eliminar la profundidad de mercado.")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "No se puede obtener los datos de la profundidad de mercado.")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "Error al suscribirse a la recepción de nuevos datos de la profundidad de mercado.")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "No se puede abrir más de 64 archivos.")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "Nombre del archivo no válido.")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "Nombre del archivo demasiado largo.")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "Error al abrir el archivo.")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "Memoria insuficiente para la caché de lectura.")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "Error al eliminar el archivo.")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "Archivo con este manejador ya está cerrado, o no se abría en absoluto.")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "Manejador erróneo de archivo.")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "El archivo debe ser abierto para la escritura.")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "El archivo debe ser abierto para la lectura.")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "El archivo debe ser abierto como un archivo binario.")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "El archivo debe ser abierto como un archivo de texto.")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "El archivo debe ser abierto como un archivo de texto o CSV.")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "El archivo debe ser abierto como un archivo CSV.")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "Error de lectura de archivo.")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "Hay que especificar el tamaño de la cadena porque el archivo ha sido abierto como binario.")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "Para los arrays de cadenas - un archivo de texto, para los demás - un archivo binario.")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "No es un archivo, es un directorio.")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "Archivo no existe.")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "No se puede reescribir el archivo.")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "Nombre erróneo del directorio.")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "Directorio no existe.")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "Es un archivo, no es un directorio.")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "No se puede eliminar el directorio.")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "No se puede limpiar el directorio (tal vez, uno o más archivos estén bloqueados y no se ha podido llevar a cabo la eliminación).")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "No se ha podido escribir el recurso en el archivo.")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "No se ha podido leer el siguiente fragmento de datos del archivo CSV (FileReadString, FileReadNumber, FileReadDatetime, FileReadBool), puesto que se ha alcanzado el final del archivo.")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "No hay fecha en la cadena.")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "Fecha errónea en la cadena.")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "Hora errónea en la cadena.")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "Error de conversión de cadena a fecha.")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "Memoria insuficiente para la cadena.")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "Longitud de cadena es menos de la esperada.")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "Número excesivamente grande, más que ULONG_MAX.")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "Cadena de formato errónea.")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "Hay más especificadores de formato que los parámetros.")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "Hay más Parámetros que los especificadores de formato.")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "Parámetro del tipo string dañado.")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "Posición fuera de los límites de la cadena.")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "Al final de la cadena se ha añadido 0, una operación inútil.")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "Tipo de datos desconocido durante la conversión a una cadena.")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "Objeto de cadena dañado.")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "Copiado de los arrays incompatibles. Un array de cadena puede ser copiado sólo en un array de cadena, un array numérico sólo en un array numérico.")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "El array que recibe está declarado como AS_SERIES, y no tiene el tamaño suficiente.")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "Un array muy pequeño, posición de inicio está fuera de los límites del array.")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "Un array de longitud cero.")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "Tiene que ser un array numérico.")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "Tiene que ser un array unidimensional.")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "No se puede usar serie temporal.")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "Tiene que ser un array del tipo double.")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "Tiene que ser un array del tipo float.")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "Tiene que ser un array del tipo long.")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "Tiene que ser un array del tipo int.")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "Tiene que ser un array del tipo short.")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "Tiene que ser un array del tipo char.")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "Solo matrices del tipo string.")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "Las funciones OpenCL no se soportan en este ordenador.")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "Error interno al ejecutar OpenCL.")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "Manejado OpenCL incorrecto.")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "Error al crear el contexto OpenCL.")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "Error al crear la cola de ejecución en OpenCL.")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "Error al compilar el programa OpenCL.")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "Punto de entrada demasiado largo (kernel OpenCL).")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "Error al crear el kernel - punto de entrada de OpenCL.")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "Error al establecer los parámetros para el kernel OpenCL (punto de entrada en el programa OpenCL).")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "Error de ejecución del programa OpenCL.")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "Tamaño del búfer OpenCL incorrecto.")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "Desplazamiento incorrecto en el búfer OpenCL.")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "Error de creación del búfer OpenCL.")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "Se ha superado el número de objetos OpenCL.")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "Error al elegir el dispositivo OpenCL.")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "Error interno en la base de datos.")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "Puntero no válido de la base de datos.")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "Se ha superado el número máximo permitido de objetos Database.")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "Error al conectarse a la base de datos.")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "Error al ejecutar la solicitud.")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "Error al crear la solicitud.")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "Ya no hay más datos para la lectura.")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "Error al pasar a la siguiente entrada de la solicitud.")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "Los datos para leer los resultados de la solicitud aún no están preparados.")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "Error al realizar la autosustitución de los parámetros en la solicitud SQL.")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "URL no ha superado la prueba.")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "No se ha podido conectarse a la URL especificada.")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "Superado el tiempo de espera de recepción de datos.")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "Error de ejecución de la solicitud HTTP.")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "A la función se ha transmitido un puntero incorrecto a del socket.")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "Se han abierto demasiados sockets (128 como máximo).")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "Error al conectar con el host remoto.")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "Error de envío/recepción de datos del socket.")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "Error al establecer una conexión protegida (TLS Handshake).")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "No hay datos sobre el certificado con el que se protege la conexión.")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "Debe indicarse un símbolo personalizado.")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "Nombre del símbolo personalizado incorrecto. En el nombre dado al símbolo se usan solo letras latinas sin signos de puntuación, sin espacios en blanco y ni símbolos especiales (se permiten '.', '_', '&' y '#'). No se recomienda utilizar los símbolos <, >, :, \", /,\\, |, ?, *.")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "Nombre demasiado largo para el símbolo personalizado. La longitud del nombre no deberá superar los 32 caracteres contando el 0 final.")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "Ruta para el símbolo personalizado demasiado larga. La longitud de la ruta no deberá superar los 128 caracteres incluyendo 'Custom\\\\', el nombre del símbolo, los separadores de grupos y el 0 final.")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "No existe ningún símbolo personalizado con ese nombre.")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "Error al crear, eliminar o modificar el símbolo personalizado.")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "Intento de eliminar un símbolo personalizado elegido en la observación de mercado (Market Watch).")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "Propiedad de símbolo personalizado incorrecta.")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "Parámetro erróneo al establecer las propiedades del símbolo personalizado.")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "Parámetro de cadena demasiado largo al establecer las propiedades del símbolo personalizado.")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "Matriz de ticks no organizada por tiempo.")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "El tamaño de la matriz es insuficiente para obtener las descripciones de todos los valores.")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "Se ha superado el límite de solicitud por tiempo.")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "El país no ha sido encontrado.")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "Error generico.")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "Error de lógica interna de SQLite.")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "Acceso denegado.")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "La rutina de devolución de llamada solicitó la cancelación.")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "Archivo de base de datos bloqueado.")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "Tabla de base de datos bloqueada.")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "Memoria insuficiente para completar la operación.")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "Intente escribir en la base de datos de solo lectura.")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "Operación terminada por sqlite3_interrupt().")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "Error de E/S de disco.")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "La imagen del disco de la base de datos está dañada.")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "Código de operación desconocido en sqlite3_file_control().")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "La inserción falló porque la base de datos está llena.")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "No se puede abrir el archivo de la base de datos.")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "Error de protocolo de bloqueo de base de datos.")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "Solo para uso interno.")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "El esquema de la base de datos cambió.")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "La cadena o el BLOB exceden el límite de tamaño.")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "Cancelar debido a la violación de la restricción.")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "Discrepancia en el tipo de datos.")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "Biblioteca utilizada incorrectamente.")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "Utiliza funciones del sistema operativo que no son compatibles con el host.")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "Autorización denegada.")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "No utilizado.")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "Error de parámetro de enlace, índice incorrecto.")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "Archivo abierto que no es un archivo de base de datos.")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "Recuota.")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "Solicitud rechazada.")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "Solicitud cancelada por el agente.")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "Orden colocada.")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "Solicitud ejecutada.")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "Solicitud ejecutada parcialmente.")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "Error al procesar la solicitud.")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "Solicitud cancelada al expirar el plazo.")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "Solicitud no válida.")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "Volumen en la solicitud no válido.")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "Precio en la solicitud no válido.")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "Stops en la solicitud no válido.")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "Transacciones comerciales están prohibidas.")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "Mercado está cerrado.")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "Falta de medios monetarios para cumplir la solicitud.")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "Precios se han cambiado.")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "Faltan las cotizaciones para procesar la solicitud.")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "Fecha de expiración no válida de la orden en la solicitud.")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "Estado de la orden se ha cambiado.")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "Solicitudes muy frecuentes.")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "Sin cambios en la solicitud.")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "Autotrading está prohibido por el servidor.")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "Autotrading está prohibido por el terminal de cliente.")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "Solicitud está bloqueada para procesar.")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "Orden o posición están congeladas.")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "Está especificado el tipo de ejecución de orden no válido.")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "No hay conexión con el servidor de comercio.")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "Operación permitida únicamente para las cuentas reales.")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "Alcanzado el límite del número de órdenes pendientes.")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "Alcanzado el límite del volumen de órdenes y posiciones para este símbolo.")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "Tipo de orden inválido o prohibido.")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "Posición con el POSITION_IDENTIFIER especificado ya está cerrada.")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "El volumen cerrado supera el volumen actual de la posición.")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "Para la posición indicada ya existe una orden de cierre. Puede surgir al trabajar en el sistema de cobertura: \r\nal intentar cerrar una posición con una opuesta, si ya existe una orden de cierre de esta posición \r\nal intentar realizar un cierre total o parcial, si el volumen sumado de las órdenes de cierre ya existentes y la orden colocada de nuevo supera el volumen actual de la posición.")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "El número de posiciones abiertas que puede existir en la cuenta de forma simultánea puede verse limitado por los ajustes del servidor. Una vez alcanzado el límite, el servidor retornará el error TRADE_RETCODE_LIMIT_POSITIONS como respuesta a la colocación de una orden. Esta restricción actúa de forma diferente, dependiendo del tipo de registro de posición usado en la cuenta: \r\nSistema de compensación – tiene en cuenta el número de posiciones abiertas. Al alcanzar el límite, la plataforma no permite establecer nuevas órdenes cuya ejecución pueda provocar el aumento de posiciones abiertas. De hecho, la plataforma permite colocar órdenes solo de aquellos símbolos de los que ya existen posiciones abiertas. En el sistema de compensación, al comprobar el límite, no se tienen en cuenta las órdenes pendientes actuales, puesto que su ejecución puede causar cambios en las posiciones actuales, pero no el aumento de su número. \r\nSistema de cobertura – aparte de las posiciones abiertas, se tienen en consideración las órdenes pendientes colocadas, puesto que su activación siempre conduce a la apertura de una nueva posición. Al alcanzar el límite, la plataforma no permite colocar órdenes de mercado para la apertura de posiciones, así como órdenes pendientes.")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "La solicitud de activación de la orden pendiente ha sido rechazada, la orden ha sido cancelada.")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "La solicitud ha sido rechazada, ya que para el símbolo se ha establecido la regla 'Solo se permiten posiciones largas'  (POSITION_TYPE_BUY).")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "La solicitud ha sido rechazada, ya que para el símbolo se ha establecido la regla 'Solo se permiten posiciones cortas' (POSITION_TYPE_SELL).")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "La solicitud ha sido rechazada, ya que para el símbolo se ha establecido la regla 'Solo se permite cerrar las posiciones existentes'.")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "La solicitud ha sido rechazada, ya que para el símbolo se ha establecido la regla 'Solo se permite cerrar las posiciones existentes según el principio FIFO' (ACCOUNT_FIFO_CLOSE=true).")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "La solicitud ha sido rechazada, ya que para la cuenta comercial se ha establecido la regla 'Prohibido cerrar posiciones opuestas de un mismo símbolo'. Por ejemplo, si en la cuenta tenemos una posición Buy, el usuario no podrá abrir una posición Sell o colocar una orden pendiente de venta. La regla se aplica solo en las cuentas con sistema de cobertura de registro de posiciones (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING).")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
};
#endif


// Language specific error code resolver (portugese)
#ifdef LIB_ERROR_LANG_TERM_ID_PT
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_PT)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "A operação concluída com sucesso.")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "Erro interno inesperado.")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "Parâmetro errado na chamada interna da função do terminal cliente.")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "Parâmetro errado ao chamar a função de sistema.")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "Sem memória suficiente para executar a função de sistema.")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "A estrutura contém objetos de strings e/ou arrays dinâmicos e/ou estrutura de tais objetos e/ou classes.")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "Array de um tipo errado, tamanho errado, ou um objeto defeituoso de um array dinâmico.")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "Sem memória suficiente para a realocação de um array, ou uma tentativa de alterar o tamanho de um array estático.")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "Sem memória suficiente para a realocação de string.")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "String não inicializada.")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "Data e/ou hora inválida.")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "Total amount of elements in the array cannot exceed 2147483647.")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "Ponteiro errado.")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "Tipo errado de ponteiro.")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "Função de sistema não é permitida para chamar.")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "Os nomes do recurso dinâmico e do estático equivalem.")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "Recurso com este nome não foi encontrado em EX5.")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "Tipo de recurso não suportado ou seu tamanho excede 16 Mb.")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "O nome do recurso excede 63 caracteres.")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "Durante cálculo de funções matemáticas ocorreu um estouro.")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Excede a data de término do teste após chamar Sleep().")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                       "ERR_PROGRAM_STOPPED",                     "Os testes foram interrompidos forçosamente de fora. Por exemplo, ao interromper a otimização, ao fechar a janela de teste visual ou ao parar o agente de teste.")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "Identificador de gráfico (chart ID) errado.")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "Gráfico não responde.")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "Gráfico não encontrado.")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "Nenhum Expert Advisor no gráfico que pudesse manipular o evento.")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "Erro de abertura de gráfico.")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "Falha ao alterar ativo e período de um gráfico.")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "Valor de erro do parâmetro para a função que trabalha com gráficos.")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "Falha ao criar timer.")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "Identificador de propriedade (property ID) do gráfico errado.")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "Erro criando telas (screenshots).")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "Erro navegando através de gráfico.")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "Erro aplicando template.")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "Sub-janela contendo o indicador não foi encontrada.")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "Erro adicionando um indicador no gráfico.")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "Erro excluindo um indicador do gráfico.")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "Indicador não encontrado no gráfico especificado.")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "Erro trabalhando com um objeto gráfico.")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "Objeto gráfico não foi encontrado.")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "Identificador (ID) de uma propriedade de objeto gráfico errado.")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "Não foi possível obter data correspondente ao valor.")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "Não foi possível obter valor correspondente à data.")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "Ativo desconhecido.")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "Ativo não está selecionado na janela Observação de Mercado.")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "Identificador de uma propriedade de ativo errado.")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "Hora do último tick não é conhecida (sem ticks).")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "Erro adicionando ou excluindo um ativo na janela Observação de Marcado.")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "Histórico solicitado não encontrado.")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "Identificador (ID) da propriedade de histórico errado.")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "Esgotado o tempo de solicitação do histórico.")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "Número de barras restrito pelas configurações do terminal.")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "Erros múltiplos ao carregar o histórico.")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "A matriz de recebimento é muito pequena para armazenar todos os dados solicitados.")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "Variável global do terminal cliente não foi encontrada.")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "Variável global do terminal cliente com o mesmo nome já existe.")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "Não houve modificações de variáveis ​​globais.")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "Foi impossível abrir e ler o arquivo com os valores das variáveis ​​globais.")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "Foi impossível escrever o arquivo com os valores das variáveis ​​globais.")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "Envio de email falhou.")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "Reprodução de som falhou.")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "Identificador de propriedade do programa errado.")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "Identificador de propriedade do terminal errado.")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "Envio de arquivo via ftp falhou.")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "Falha ao enviar uma notificação.")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "Parâmetro inválido para enviar uma notificação — uma string vazia ou NULL foi passada para a função SendNotification().")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "Configurações de notificações erradas no terminal (ID não está especificado ou permissão não está definida).")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "Freqüência de envio de notificações em excesso.")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "O servidor FTP não está especificado nos atributos de configuração.")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "O login FTP não está especificado nos atributos de configuração.")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "O ficheiro não existe.")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "A ligação ao servidor FTP falhou.")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "Não foi encontrado o diretório no servidor FTP para o upload do ficheiro.")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "A ligação ao servidor FTP foi fechada.")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "Sem memória suficiente para a distribuição de buffers de indicador.")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "Índice de buffer de indicador errado.")


        // Custom Indicator Properties

            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "Identificador (ID) de propriedade do indicador customizado errado.")


        // Account

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "Identificador (ID) de propriedade da conta errado.")
            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "Identificador (ID) de propriedade da negociação (trade) errado.")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "Negociação via Expert Advisors proibida.")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "Posição não encontrada.")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "Ordem não encontrada.")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "Operação (deal) não encontrada.")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "Envio de solicitação de negociação falhou.")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "Impossível calcular o valor do índice de negociação.")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "Ativo desconhecido.")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "Indicador não pode ser criado.")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "Sem memória suficiente para adicionar o indicador.")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "O indicador não pode ser aplicado a um outro indicador.")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "Erro ao aplicar um indicador ao gráfico.")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "Dado solicitado não encontrado.")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "Manuseio de indicador errado.")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "Numero errado de parâmetros ao criar um indicador.")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "Sem parâmetros ao criar um indicador.")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "O primeiro parâmetro no array deve ser o nome do indicador customizado.")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "Tipo de parâmetro inválido no array ao criar um indicador.")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "Índice errado de buffer do indicador solicitado.")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "Profundidade de Mercado não pode ser adicionado.")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "Profundidade de Mercado não pode ser removido.")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "Os dados da Profundidade de Mercado não podem ser obtidos.")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "Erro em subscrever para receber novos dados da Profundidade de Mercado.")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "Mais que 64 arquivos não podem ser abertos ao mesmo tempo.")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "Nome de arquivo inválido.")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "Nome de arquivo longo demais.")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "Erro de abertura de arquivo.")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "Sem memória suficiente de cache para leitura.")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "Erro excluindo arquivo.")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "Um arquivo com este handle foi fechado, ou simplesmente não estava aberto.")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "Handle de arquivo errado.")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "O arquivo deve estar abertura para escrita.")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "O arquivo deve estar aberto para leitura.")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "O arquivo deve estar aberto como um arquivo binário.")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "O arquivo deve estar aberto como um texto.")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "O arquivo deve estar aberto como um texto ou CSV.")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "O arquivo deve estar aberto como CSV.")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "Erro de leitura de arquivo.")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "Tamanho da string deve estar especificado, porque o arquivo está aberto como binário.")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "Um arquivo de texto deve ser usado para arrays de strings, para outros arrays - binários.")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "Isto não é um arquivo, isto é um diretório.")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "Arquivo inexistente.")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "Arquivo não pode ser reescrito.")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "Nome de diretório errado.")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "Diretório inexistente.")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "Isto é um arquivo, não um diretório.")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "O diretório não pode ser removido.")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "Falha ao limpar o diretório (provavelmente um ou mais arquivos estão bloqueados e a operação de remoção falhou).")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "Falha ao escrever um recurso para um arquivo.")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "Falha ao ler o próximo bloco de dados a partir do arquivo CSV (FileReadString, FileReadNumber, FileReadDatetime, FileReadBool), porque atingido o final do arquivo.")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "Sem data na string.")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "Data errada na string.")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "Hora errada na string.")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "Erro convertendo string em data.")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "Sem memória suficiente para a string.")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "O comprimento da string é menor que o esperado.")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "Número grande demais, maior que ULONG_MAX.")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "string de formato inválido.")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "Quantidade de especificadores de formato maior que de parâmetros.")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "Quantidade de parâmetros maior que de especificadores de formato.")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "Parâmetro de tipo string defeituoso.")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "Posição fora da string.")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "0 adicionado ao final da string, uma operação inútil.")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "Tipo de dado desconhecido ao converter para uma string.")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "Objeto de string defeituoso.")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "Copiando arrays incompatíveis. Array de string pode ser copiado somente para um array de string, e um array numérico - somente em um array numérico.")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "O array de recepção está declarado como AS_SERIES, e é de tamanho insuficiente.")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "Array pequeno demais, a posição inicial está fora do array.")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "Um array de comprimento zero.")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "Deve ser um array numérico.")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "Deve ser um array unidimensional.")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "Série de tempo (timeseries) não pode ser usada.")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "Deve ser um array de tipo double.")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "Deve ser um array de tipo float.")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "Deve ser um array de tipo long.")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "Deve ser um array de tipo int.")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "Deve ser um array de tipo short.")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "Deve ser um array de tipo char.")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "Deve ser uma matriz do tipo cadeia de caracteres.")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "Funções OpenCL não são suportados neste computador.")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "Erro interno ocorreu ao executar OpenCL.")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "Handle de OpenCL inválido.")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "Erro criando o contexto de OpenCL.")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "Falha ao criar um fila de execução em OpenCL.")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "Erro ocorreu ao compilar um programa OpenCL.")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "Nome de kernel longo demais(kernel de OpenCL).")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "Erro criando um kernel de OpenCL.")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "Erro ocorreu ao configurar parâmetrospara o kernel de OpenCL.")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "Erro em tempo de execução de programa de OpenCL.")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "Tamanho inválido do buffer de OpenCL.")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "Deslocamento (offset) inválido do buffer de OpenCL.")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "Falha ao criar um buffer de OpenCL.")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "Excedido o número máximo de objetos OpenCL.")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "Erro ao selecionar o dispositivo OpenCL.")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "Erro interno no banco de dados.")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "Identificador de banco de dados inválido.")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "Número máximo de objetos de banco de dados excedido.")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "Erro ao conectar ao banco de dados.")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "Erro de execução de consulta.")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "Erro ao criar consulta.")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "Não há mais dados de leitura.")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "Erro ao passar para o próximo registro da consulta.")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "Os dados para leitura dos resultados da consulta ainda não estão prontos.")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "Erro de substituição automática de parâmetro na consulta SQL.")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "URL inválido.")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "Falha ao conectar com o URL especificado.")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "Tempo limite excedido.")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "Falha na solicitação do HTTP.")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "Para a função foi passado um identificador de soquete inválido.")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "Muitos soquetes abertos (máximo 128).")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "Erro ao conectar-se ao host remoto.")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "Erro ao enviar/receber dados do soquete.")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "Erro ao estabelecer uma conexão segura (TLS Handshake).")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "Não há dados sobre o certificado que protege a conexão.")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "Deve ser especificado o símbolo personalizado.")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "Nome de símbolo personalizado incorreto. No nome do símbolo é possível utilizar apenas caracteres latinos sem pontuação, espaços e caracteres especiais (são permitidos '.', '_', '&' e '#'). Não é recomendado usar os caracteres <, >, :, \", /,\\, |, ?, *.")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "Nome demasiado longo para o símbolo personalizado. O nome não pode exceder 32 caracteres tendo em conta o 0 final.")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "Caminho demasiado longo para o símbolo personalizado. A caminho não deve exceder 128 caracteres, tendo em conta 'Custom\\\\', o nome do símbolo, separadores de grupos e o 0 final.")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "Já existe um caráter personalizado com esse nome.")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "Erro ao criar, excluir ou modificar o símbolo personalizado.")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "Tentativa de excluir um símbolo personalizado selecionado na Observação do mercado (Market Watch).")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "Propriedade de símbolo personalizado incorreto.")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "Parâmetro errado ao definir propriedade do símbolo personalizado.")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "Parâmetro de cadeia muito longo ao definir propriedade do símbolo personalizado.")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "Array de ticks não sequenciada por tempo.")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "Tamanho de array insuficiente para obter descrições de todos os valores.")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "Limite de tempo da solicitação excedido.")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "País não encontrado.")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "Erro genérico.")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "Erro de lógica interna do SQLite.")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "Acesso negado.")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "A rotina de retorno de chamada solicitou o cancelamento.")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "Arquivo de banco de dados bloqueado.")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "Tabela de banco de dados bloqueada.")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "Memória insuficiente para completar a operação.")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "Tente gravar no banco de dados somente leitura.")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "Operação terminada por sqlite3_interrupt().")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "Erro de E/S de disco.")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "Imagem de disco do banco de dados corrompida.")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "Código de operação desconhecido em sqlite3_file_control().")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "Falha na inserção porque o banco de dados está cheio.")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "Não é possível abrir o arquivo de banco de dados.")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "Erro de protocolo de bloqueio de banco de dados.")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "Somente para uso interno.")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "Esquema de banco de dados alterado.")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "String ou BLOB excede o limite de tamanho.")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "Abortar devido a violação de restrição.")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "Incompatibilidade de tipo de dados.")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "Biblioteca usada incorretamente.")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "Usa recursos do SO não suportados no host.")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "Autorização negada.")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "Não usado.")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "Erro de parâmetro de ligação, índice incorreto.")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "Arquivo aberto que não é arquivo de banco de dados.")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "Nova Cotação.")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "Solicitação rejeitada.")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "Solicitação cancelada pelo negociador.")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "Ordem colocada.")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "Solicitação concluída.")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "Somente parte da solicitação foi concluída.")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "Erro de processamento de solicitação.")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "Solicitação cancelada por expiração de tempo (timeout).")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "Solicitação inválida.")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "Volume inválido na solicitação.")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "Preço inválido na solicitação.")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "Stops inválidos na solicitação.")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "Negociação está desabilitada.")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "Mercado está fechado.")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "Não existe dinheiro suficiente para completar a solicitação.")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "Os preços se alteraram.")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "Não existem cotações para processar a solicitação.")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "Data de expiração da ordem inválida na solicitação.")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "Estado da ordem alterada.")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "Solicitações com freqüência em excesso.")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "Sem alterações na solicitação.")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "Autotrading desabilitado pelo servidor.")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "Autotrading desabilitado pelo terminal cliente.")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "Solicitação bloqueada para processamento.")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "Ordem ou posição congeladas.")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "Tipo de preenchimento de ordem inválido.")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "Sem conexão com o servidor de negociação.")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "Operação é permitida somente para contas reais.")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "O número de ordens pendentes atingiu o limite.")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "O volume de ordens e posições para o ativo atingiu o limite.")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "Incorreto ou proibida tipo de ordem.")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "Posição com a especificação POSITION_IDENTIFIER já foi fechado.")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "O volume que se pode fechar excede o volume da posição atual.")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "Para a posição indicada já existe uma ordem de fechamento. Pode aoontecer no trabalho no sistema de cobertura: \r\nao tentar fechar a posição oposta, se já existir uma ordem para fechamento desta posição \r\nao tentar fechar completa ou parcialmente, se o volume total de ordens existentes para fechamento e o volume total da ordem re-colocada excede o volume da posição atual.")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "O número de posições abertas, que pode estar simultaneamente na conta, pode ser limitado pelas definições do servidor. Quando é atingido o limite, em resposta à colocação de uma ordem, o servidor retorna o erro TRADE_RETCODE_LIMIT_POSITIONS. A restrição opera de forma diferente dependendo do tipo de cálculo para as posições da conta: \r\nSistema de compensação – considera o número de posições abertas. Ao atingir o limite, a plataforma não permite colocar novas ordens, cuja execução pode aumentar o número de posições abertas. Na verdade, a plataforma irá colocar ordens apenas para os símbolos que já têm posições abertas. No sistema de compensação, durante a verificação do limite, não são levadas em conta as ordens pendentes atuais, uma vez que sua execução pode conduzir a uma alteração nas posições atuais, em vez de um aumento do seu número. \r\nSistema de cobertura – além das posições abertas, são consideradas as ordens pendentes colocadas, uma vez que sua execução sempre conduz à apertura de uma nova posição. Ao atingir o limite, a plataforma não permite colocar tanto ordens de mercado para abrir posições quanto ordens pendentes.")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "O pedido de ativação da ordem pendente foi rejeitado, e a ordem cancelada.")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "O pedido foi rejeitado, porque, no símbolo, foi definida a regra 'Somente são permitidas posições longas'  (POSITION_TYPE_BUY).")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "O pedido foi rejeitado, porque, no símbolo, foi definida a regra 'Somente são permitidas posições curtas' (POSITION_TYPE_SELL).")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "O pedido foi rejeitado, porque, no símbolo, foi definida a regra 'Só é permitido o fechamento de posição'.")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "O pedido foi rejeitado, porque, no símbolo, foi definida a regra 'Só é permitido o fechamento da posição edxistente segundo o princípio FIFO' (ACCOUNT_FIFO_CLOSE=true).")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "O pedido foi rejeitado, porque, no símbolo, foi definida a regra 'Proibido abrir posições opostas segundo um mesmo símbolo'. Por exemplo, se a conta tiver uma posição Buy, o usuário não poderá abrir uma posição Sell ou colocar uma ordem de venda pendente. A regra só pode ser aplicada em contas com sistema de cobertura (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING).")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
};
#endif


// Language specific error code resolver (german)
#ifdef LIB_ERROR_LANG_TERM_ID_DE
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_DE)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "Die Operation wurde erfolgreich ausgeführt.")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "Unerwarteter interner Fehler.")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "Fehlerwert beim internen Aufruf des Client-Terminals.")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "Fehlerwert beim Aufruf der Systemfunktion.")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "Nicht genug Speicherplatz für Ausführung der Systemfunktion.")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "Struktur hat Zeilenobjekte und/oder Objekte der dynamischen Felder und/oder Strukturen mit solchen Objekten und/oder Klassen.")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "Array mit unpassendem Typ, falscher Größe oder beschädigtes Objekt des dynamischen Arrays.")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "Zu kleine Arraygröße für die geforderte Größe oder der Versuch der Größenänderung eines statischen Arrays.")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "Zeichenkette ist zu groß.")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "nicht initialisierte Zeichenkette.")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "Ungültiger Wert des Datums und/oder der Zeit.")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "Die Gesamtzahl der Elemente im Array darf nicht größer als 2147483647 sein.")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "Ungültiger Anzeiger.")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "Falscher Typ des Pointers.")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "Systemfunktion ist für Anruf nicht erlaubt.")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "Die Namen der dynamischen und statischen Ressource sind gleich.")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "Ressource mit diesem Namen ist nicht in EX5 gefunden.")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "Nicht unterstützte Ressource-Typ oder Größe von mehr als 16 MB.")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "Der Name der Ressource ist mehr als 63 Zeichen.")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "Es ist ein Speicherüberlauf bei der Berechnung der mathematischen Funktion aufgetreten.")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Das aufgerufene Sleep() überschreitet den Zeitpunkt des Testendes.")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                      "ERR_PROGRAM_STOPPED",                     "Der Test wurde zwangsweise von außen beendet. Beispielsweise wurde die Optimierung unterbrochen, das visuelle Testfenster geschlossen oder der Test-Agent angehalten.")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "Falscher Identifikator des Charts.")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "Chart antwortet nicht.")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "Chart ist nicht gefunden.")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "Im Chart gibt es keinen Expert Advisor, der das Ereignis verarbeiten kann.")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "Fehler bei Charteröffnung.")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "Fehler bei Veränderung des Symbols und der Periode des Charts.")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "Ein fehlerhafter Parameterwert für Funktionen für die Arbeit mit dem Chart.")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "Fehler bei Timererzeugung.")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "Falsche Charteigenschaft ID.")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "Fehler bei Screenshot Erzeugung.")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "Fehler der Navigierung durch Chart.")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "Fehler der Schablonenverwendung.")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "Subfenster mit angegebenen Indikator nicht gefunden.")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "Fehler beim Hinzufügen eines Indikators zu einem Chart.")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "Fehler beim Entfernen des Indikators aus dem Chart.")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "Der Indikator kann nicht auf dem angegebenen Chart gefunden werden.")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "Fehler bei Arbeit mit dem graphischen Objekt.")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "Graphisches Objekt ist nicht gefunden.")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "Fehleridentifikator der Eigenschaft des graphischen Objektes.")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "Datum entsprechend dem Wert kann nicht erhalten werden.")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "Wert entsprechend dem Datum kann nicht erhalten werden.")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "Unbekanntes Symbol.")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "Symbol nicht gewählt in  MarketWatch.")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "Fehleridentifikator der Symboleigenschaft.")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "Zeit des Letzten Ticks ist unbekannt (es gab keine Ticks).")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "Fehler beim Hinzufügung oder Löschung eines Symbols in MarketWatch.")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "Angeforderte Historie ist nicht gefunden.")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "Falscher Identifikator der Eigenschaften der Historie.")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "Zeitrüberschreitung beim Abruf der Historie.")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "Die Anzahl der abgerufenen Balken ist in den Einstellungen des Terminals begrenzt.")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "Zahlreiche Fehler beim Laden der Historie.")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "Das aufnehmende Array ist zu klein, um alle abgerufenen Daten zu speichern.")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "Globale Variable des Client-Terminals ist nicht gefunden.")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "Globale Variable des Client-Terminals mit demselben Namen existiert schon.")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "Globale Variablen wurden nicht modifiziert.")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "Die Datei mit den Werten der globalen Variablen konnte nicht geöffnet und gelesen werden.")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "Die Datei mit den Werten der globalen Variablen konnte nicht geschrieben werden.")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "Fehler beim Sender der E-Mail.")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "Fehler beim Abspielen eines Tons.")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "Falscher Identifikator der Programmeigenschaft.")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "Falscher Identifikator der Terminalseigenschaft.")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "Fehler beim Dateisenden via ftp.")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "Benachrichtigung konnte nicht gesendet werden.")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "Ungültige Parameter, um Benachrichtigung zu senden – ein leerer String oder NULL war in die Funktion SendNotification() übergeben.")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "Falsche Einstellung von Benachrichtigungen im Terminal (ID ist nicht eingegeben oder keine Berechtigung ist aufgesetzt).")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "Zu häufige Zusendung von Benachrichtigungen.")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "Ftp-Server wurde nicht in den Einstellungen definiert.")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "Ftp-Benutzername wurde nicht in den Einstellungen definiert.")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "Datei existiert nicht.")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "Verbindung mit dem Ftp-Server fehlgeschlagen.")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "Upload-Verzeichnis auf dem Ftp-Server nicht gefunden.")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "Verbindung mit einem Ftp-Server geschlossen.")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "Nicht genug Speicherplatz für Neuzuordnung der Indikatorpuffer.")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "Falscher Index des Indikatorpuffers.")
            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "Falscher Identifikator der Eigenschaft von Benutzerindikator.")


        // Custom Indicator Properties

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "Falscher Identifikator der Kontoeigenschaft.")


        // Account

            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "Falscher Identifikator der Handelseigenschaft.")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "Handel für Expert ist verboten.")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "Position ist nicht gefunden.")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "Order ist nicht gefunden.")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "Deal ist nicht gefunden.")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "Fehler beim Senden der Handelsanforderung.")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "Berechnung des Profits oder der Margin fehlgeschlagen.")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "Unbekanntes Symbol.")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "Indikator kann nicht erzeugt werden.")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "Nicht genug Speicherplatz, um den Indikator zu starten.")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "Indikator kann nicht auf den anderen Indikator angewendet werden.")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "Fehler beim Hinzufügen des Indikators.")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "Angeforderte Daten nicht gefunden.")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "Handle des Indikators ist ungültig.")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "Falsche Parameterzahl beim Indikator.")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "Fehlende Parameter beim Indikator.")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "Der erste Parameter im Feld muss der Name des nutzerdefinierten Indikators sein.")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "Falscher Parametertyp für den Indikator.")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "Falscher Index des angeforderten Indikatorpuffers.")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "DOM kann nicht zugefügt werden.")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "DOM kann nicht entfernt werden.")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "DOM Dasten können nicht erhalten werden.")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "Fehler in Subskription neue DOM Daten zu erhalten.")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "Mehr als 64 Dateien können nicht gleichzeitig eröffnet werden.")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "Ungültiger Dateiname.")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "Zu langer Dateiname.")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "Fehler der Dateieröffnung.")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "Nicht genug Speicherplatz, um Cache zu lesen.")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "Fehler beim Löschen der Datei.")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "Datei mit diesem Handle ist schon geschlossen oder konnte nicht erstellt werden.")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "Falsches Handle der Datei.")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "Datei muss für Schreiben eröffnet werden.")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "Datei muss für Lesen eröffnet werden.")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "Datei muss als binäre Datei eröffnet werden.")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "Datei muss als Textdatei eröffnet werden.")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "Datei muss als Textdatei oder CSV eröffnet werden.")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "Datei muss als CSV eröffnet werden.")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "Fehler des Datei Lesen.")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "Es muss Zeilengröße angegeben werden, denn die Datei ist als binäre Datei eröffnet.")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "für Zeilenfelder muss Textdatei sein, für andere - binäre Datei.")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "Das ist keine Datei, sondern ein Verzeichnis.")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "Datei existiert nicht.")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "Datei kann nicht neugeschrieben werden.")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "Falscher Verzeichnisname.")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "Verzeichnis existiert nicht.")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "Das ist eine Datei, nicht Verzeichnis.")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "Verzeichnis kann nicht entfernt werden.")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "Misslungen, das Verzeichnis zu löschen (eine oder mehrere Dateien können blockiert werden und Operation der Entfernung ist misslungen).")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "Ressource konnte nicht in die Datei geschrieben werden.")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "Es ist unmöglich, das nächste Datenfragment aus der CSV-Datei (FileReadString, FileReadNumber, FileReadDatetime, FileReadBool) zu lesen, Dateiende erreicht.")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "In der Zeile gibt es kein Datum.")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "Falsches Datum in der Zeile.")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "Falsche Zeit in der Zeile.")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "Fehler der Umwandlung der Zeile in Datum.")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "Nicht genug Speicherplatz für Zeile.")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "Zeilenlänge ist kleiner als erwartet.")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "Zu lange Zahl, länger als ULONG_MAX.")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "Falsche Formatzeile.")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "Zahl der Formatspezifikationen ist größer, als die Parameterzahl.")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "Parameterzahl ist mehr als Zahl der Formatspezifikatoren.")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "Beschädigter Parameter des Typs.")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "Position außerhalb der Zeile.")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "Zum Zeilenende wird  0 hinzugefügt, eine sinnlose Operation.")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "Unbekannter Datentyp bei Umwandlung in die Zeile.")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "Beschädigtes Zeichenkettenobjekt.")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "Kopieren von inkompatiblen Arrays. Ein Zeichenarray kann nur in ein Zeichenarray kopiert werden, numerisches Array in ein numerisches.")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "Zielarray ist als  AS_SERIES erklärt, und es ist von der unzureichender Größe.")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "Zu kleines Feld, Startposition außerhalb des Feldes.")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "Array mit der Größe Null.")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "Muss ein numerisches Array sein.")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "Muss eindimensionales Array sein.")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "Zeitreihe kann nicht verwendet werden.")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "Muss ein Array des Typs double sein.")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "Muss ein Array des Typs float sein.")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "Muss ein Array des Typs long sein.")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "Muss ein Array des Typs int sein.")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "Muss ein Array des Typs short sein.")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "Muss ein Array des Typs char sein.")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "Nur Array vom Typ string.")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "OpenCL-Funktionen werden auf diesem Computer nicht unterstützt.")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "Interner Fehler bei der Ausführung von OpenCL.")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "Ungültiges OpenCL-Handle.")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "Fehler beim Erstellen von OpenCL-Kontext.")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "Es konnte kein Lauf-Warteschlange in OpenCL erstellen.")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "Fehler beim Kompilieren eines OpenCL-Programms.")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "Zu lange Kernel-Name(OpenCL-Kernel).")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "Fehler beim Erstellen vom OpenCL-Kernel.")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "Fehler bei Eingabe von Parameters für den OpenCL-Kernel.")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "Laufzeitfehler vom OpenCL-Programm.")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "Ungültige Größe des OpenCL-Puffers.")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "Ungültiges Offset im OpenCL-Puffer.")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "Fehler beim Erstellen des OpenCL-Puffers.")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "Maximale Anzahl der OpenCL-Objekte überschritten.")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "Fehler bei der Auswahl des OpenCl-Device.")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "Interner Datenbankfehler.")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "Ungültiges Datenbankhandle.")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "Übersteigt die maximal erlaubte Anzahl von Datenbankobjekten.")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "Verbindungsfehler zur Datenbank.")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "Fehler bei der Anfrageausführung.")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "Fehler bei der Anfrageerstellung.")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "Keine zu lesenden Daten mehr.")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "Der Wechsel zur nächsten Anfrage ist fehlgeschlagen.")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "Die Daten zum Lesen der Anfrageergebnisse sind noch nicht bereit.")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "Das automatische Ersetzen der Parameter für eine SQL-Anfrage ist fehlgeschlagen.")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "Ungültige URL.")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "Verbindung mit der angegebenen URL fehlgeschlagen.")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "Zeitliches Limit für das Erhalten von Daten überschritten.")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "Bei der Ausführung der HTTP-Anfrage ist ein Fehler aufgetreten.")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "Ungültiges Handle eines Socket wurde der Funktion übergeben.")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "Zu viele offene Sockets (max 128).")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "Verbindung zum entfernten Host ist fehlgeschlagen.")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "Senden/Empfangen der Daten vom Socket ist fehlgeschlagen.")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "Das Herstellen einer sicheren Verbindung (TLS Handshake) ist fehlgeschlagen.")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "Das Zertifikat zum Schutz der Verbindung enthält keine Daten.")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "Ein benutzerdefinierter Symbol muss angegeben werden.")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "Ungültiger Name des benutzerdefinierten Symbols. Der Name des Symbols darf nur lateinische Buchstaben ohne Satzzeichen, Leerzeichen und Sonderzeichen ('.', '_', '&' und '#') enthalten. Es ist nicht empfehlenswert, Symbole <, >, :, \", /,\\, |, ?, * zu verwenden.")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "Der Name des benutzerdefinierten Symbols ist zu lang. Der Name des Symbols darf nicht länger als 32 Zeichen inklusive der abschließenden 0 sein.")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "Der Pfad zum benutzerdefinierten Symbol ist zu lang. Der Pfad darf nicht länger als 128 Zeichen einschließlich 'Custom\\\\', Symbolnamens, Trennzeichens von Gruppen und der abschließenden 0 sein.")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "Ein benutzerdefinierter Symbol mit diesem Namen existiert bereits.")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "Fehler beim Erstellen, Löschen oder Ändern eines benutzerdefinierten Symbols.")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "Versuch, das in der Marktübersicht (Market Watch) ausgewählte benutzerdefinierte Symbol zu löschen.")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "Falsche Eigenschaft des benutzerdefinierten Symbols.")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "Falscher Parameter beim Setzen der Eigenschaft des benutzerdefinierten Symbols.")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "Der String-Parameter beim Setzen der Eigenschaft des benutzerdefinierten Symbols ist zu lang.")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "Die Ticks im Array sind nicht in zeitlicher Reihenfolge geordnet.")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "Arraygröße ist zu klein für die Übernahme aller Werte.")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "Zeitlimit der Anforderung ist überschritten.")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "Land wurde nicht gefunden.")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "Allgemeiner Fehler.")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "SQLite interner Logikfehler.")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "Zugriff verweigert.")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "Durch die Rückrufroutine bedingter Abbruch.")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "Die Datei der Datenbank ist blockiert.")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "Die Tabelle der Datenbank ist blockiert.")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "Nicht genügend Speicherplatz, die Operation zu beenden.")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "Versuch, in eine schreibgeschützte Datenbank zu schreiben.")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "Operation wurde durch sqlite3_interrupt() beendet.")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "E/A-Fehler der Festplatten.")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "Das Festplattenabbild der Datenbank ist beschädigt.")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "Unbekannter Operationscode in sqlite3_file_control().")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "Das Einfügen ist fehlgeschlagen, weil die Datenbank voll ist.")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "Die Datei der Datenbank kann nicht geöffnet werden.")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "Fehler im Sperrprotokoll der Datenbank.")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "Ausschließlich für den internen Gebrauch.")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "Verändertes Schema der Datenbank.")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "Zeichenkette oder BLOB überschreitet die Größenbeschränkung.")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "Abbruch wegen Verletzung der Einschränkungen.")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "Nicht übereinstimmende Datentypen.")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "Fehlerhafte Verwendung der Bibliothek.")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "Verwendete Betriebssystemfunktionen werden vom Host nicht unterstützt.")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "Authentifizierung ist fehlgeschlagen.")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "nicht verwendet.")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "Parameterfehler bei der Einbindung, Indexfehler.")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "Geöffnete Datei ist keine Datenbankdatei.")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "Requote.")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "Anforderung ist abgelehnt.")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "Anforderung ist vom Trader aufgehoben.")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "Order ist platziert.")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "Anforderung ist erfüllt.")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "Anforderung ist partiell erfüllt.")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "Fehler der Anforderung Verarbeitung.")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "Anforderung abgelehnt nach Zeitablaufs.")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "Ungültige Anforderung.")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "Ungültiges Volumen in der Anforderung.")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "Ungültiger Preis in der Anforderung.")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "Ungültige Stops in der Anforderung.")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "Handel ist verboten.")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "Markt ist geschlossen.")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "Nicht genug Geld, um Anforderung zu erfüllen.")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "Preise haben sich verändert.")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "Es gibt keine Quotationen für die Verarbeitung der Anforderung.")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "Ungültiges Datum des Orderablaufs in der Anforderung.")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "Order Status hat sich verändert.")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "Sehr offene Anforderungen.")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "Keine Veränderungen in der Anforderung.")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "Autotrading ist vom Server untersagt.")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "Autotrading ist vom Client-Terminal untersagt.")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "Anforderung ist für Verarbeitung blockiert.")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "Order oder Position sind eingefroren.")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "Nicht unterstützter Durchführungstyp der Order nach dem Rest.")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "keine Verbindung mit dem Handelsserver.")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "Operation ist nur für reelle Kontos erlaubt.")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "Limit für Anzahl der Warteordern ist erreicht.")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "Limit für Volumen der Ordern und Positionen für dieses Symbol ist erreicht.")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "Ungültiger oder verbotener Ordertyp.")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "Die Position mit dem angegebenen POSITION_IDENTIFIER wurde bereits geschlossen.")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "Das zu schließende Volumen übersteigt das aktuelle Volumen der Position.")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "Für die angegebene Position ist bereits eine Verkaufsorder vorhanden. Kann im Hedging Modus auftreten:\r\nbeim Versuch, eine Position zur Gegenposition zu schließen, wenn es bereits Orders zum Schließen dieser Position gibt. \r\nbeim Versuch, eine Position ganz oder teilweise zu schließen, wenn das Gesamtvolumen der vorhandenen Verkaufsorders und der zu platzierenden Order das aktuelle Volumen der Position übersteigt.")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "Die Anzahl offener Positionen, die man zur gleichen Zeit auf einem Konto haben kann, kann durch die Einstellungen des Servers beschränkt werden. Wenn ein Limit erreicht ist, gibt der Server beim Versuch, eine Order zu platzieren, den Fehler TRADE_RETCODE_LIMIT_POSITIONS zurück. Die Beschränkung funktioniert je nach dem Modus der Verrechnung von Positionen auf dem Konto: \r\nNetting-Modus — die Anzahl offener Positionen wird berücksichtigt. Wenn ein Limit erreicht ist, lässt die Plattform keine weiteren Orders platzieren, deren Ausführung die Erhöhung der Anzahl offener Positionen verursachen kann. In Wirklichkeit lässt die Plattform Orders nur für die Symbole platzieren, für welche es offene Positionen bereits gibt. Im Netting-Modus werden aktuelle Pending Orders nicht berücksichtigt, denn die Ausführung einer Pending Order kann zur Änderung aktueller Positionen und nicht zur Erhöhung ihrer Anzahl führen. \r\nHedging-Modus — Pending Orders werden zusammen mit offenen Positionen berücksichtigt, denn die Auslösung einer Pending Order führt immer zur Eröffnung einer neuen Position. Wenn ein Limit erreicht ist, lässt die Plattform keine Marktorders für Eröffnung von Positionen sowie keine Pending Orders platzieren.")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "Die Anfrage auf die Aktivierung der Pending Order wurde abgelehnt, die Order wurde abgebrochen.")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "Die Anfrage wurde abgelehnt, weil für das Symbol die Regel 'Nur Long-Positionen erlaubt' (POSITION_TYPE_BUY) festgelegt wurde.")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "Die Anfrage wurde abgelehnt, weil für das Symbol die Regel 'Nur Short-Positionen erlaubt' (POSITION_TYPE_SELL) festgelegt wurde.")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "Die Anfrage wurde abgelehnt, weil für das Symbol die Regel 'Nur das Schließen vorhandener Postionen erlaubt' festgelegt wurde.")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "Der Auftrag wurde zurückgewiesen, weil das Flag 'Positionsschließung nur nach FIFO-Regel erlaubt' für das Handelskonto gesetzt ist (ACCOUNT_FIFO_CLOSE=true).")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "Die Anfrage wurde abgelehnt, weil für das Handelskonto die Regel festgelegt wurde 'Gegensätzliche Positionen ein und desselben Symbols ist deaktiviert'. Wenn das Konto z.B. eine Kaufposition hat, kann ein Nutzer keine Verkaufsposition eröffnen oder einen schwebenden Verkaufsauftrag platzieren. Die Regel wird nur auf Konten mit Hedging-Buchhaltungssystem angewendet (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING).")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
}
#endif


// Language specific error code resolver (frensh)
#ifdef LIB_ERROR_LANG_TERM_ID_FR
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_FR)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "Opération terminée avec succès.")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "Erreur interne inattendue.")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "Paramètre incorrect dans l'appel interne à la fonction du terminal client.")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "Paramètre incorrect dans l'appel à la fonction système.")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "Pas assez de mémoire pour effectuer la fonction système.")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "La structure contient des objets de type string et/ou des tableaux dynamiques et/ou une structure de tels objets et/ou classes.")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "Tableau de type ou de taille invalide, ou l'objet du tableau dynamique est endommagé.")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "Pas assez de mémoire pour la réallocation d'un tableau, ou pour changer la taille d'un tableau statique.")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "Pas assez de mémoire pour la réallocation d'une chaîne de caractères.")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "Chaîne de caractère non initialisée.")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "Date et/ou heure invalide.")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "Le nombre total d'éléments du tableau ne peut pas excéder 2 147 483 647.")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "Pointeur incorrect.")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "Type de pointeur incorrect.")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "Appel à la fonction non autorisé.")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "Les noms des ressources dynamique et statique sont identiques.")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "Aucune ressource trouvée avec ce nom dans EX5.")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "Type de ressource non supportée ou sa taille est supérieure à 16 Mo.")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "Le nom de la ressource excède 63 caractères.")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "Dépassement mémoire (overflow) lors du calcul de la fonction mathématique.")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Date de fin de test en dehors de l'appel après avoir appelé Sleep().")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                       "ERR_PROGRAM_STOPPED",                     "Test arrêté de force de l'extérieur. Par exemple, optimisation interrompue, fenêtre de test visuel fermée ou agent de test arrêté.")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "Identifiant de graphique incorrect.")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "Le graphique ne répond pas.")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "Graphique non trouvé.")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "Aucun Expert Advisor pouvant gérer l'évènement n'est présent sur le graphique.")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "Erreur d'ouverture du graphique.")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "Echec de changement du symbole ou de la période du graphique.")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "Valeur d'erreur du paramètre des fonctions pour travailler avec les graphiques.")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "Echec de création du timer.")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "Identifiant de propriété du graphique incorrect.")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "Erreur de création de la copie d'écran.")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "Erreur de navigation dans le graphique.")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "Erreur lors de l'application du modèle.")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "La sous-fenêtre contenant l'indicateur n'a pas été trouvée.")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "Erreur lors de l'ajout de l'indicateur sur le graphique.")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "Erreur de suppression d'un indicateur du graphique.")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "Indicateur non trouvé sur le graphique spécifié.")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "Erreur lors de l'utilisation d'un objet graphique.")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "L'objet graphique n'a pas été trouvé.")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "Identifiant de propriété d'un objet graphique incorrect.")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "Impossible de récupérer la date correspondant à la valeur.")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "Impossible de récupérer la valeur correspondant à la date.")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "Symbole inconnu.")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "Le symbole n'est pas sélectionné dans le MarketWatch.")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "Identifiant de propriété du symbole incorrect.")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "L'heure du dernier tick est inconnue (aucun tick).")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "Erreur lors de l'ajout ou de la suppression d'un symbole dans le MarketWatch.")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "Historique demandé non trouvé.")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "Identifiant de propriété d'historique incorrect.")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "Demande d'historique expirée (timeout).")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "Nombre de barres demandées limité par les paramètres du terminal.")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "Multiples erreurs lors du chargement de l'historique.")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "Tableau de destination trop petit pour stocker toutes les données demandées.")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "Variable globale du terminal client non trouvée.")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "Une variable globale du terminal client existe déjà avec ce nom.")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "Variable globale non modifiée.")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "Erreur de lecture du fichier des valeurs des variables globales.")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "Erreur d'écriture du fichier des valeurs des variables globales.")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "L'envoi de l'e-mail a échoué.")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "Echec de lecture du son.")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "Identifiant de propriété du programme incorrect.")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "Identifiant de propriété du terminal incorrect.")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "Echec de l'envoi d'un fichier en ftp.")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "Echec d'envoi d'une notification.")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "Paramètre invalide pour l'envoi d'une notification — une chaîne de caractères vide ou NULL a été envoyé à la fonction SendNotification().")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "Paramètre incorrect des notifications dans le terminal (l'identifiant n'est pas spécifié ou la permission n'est pas définie).")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "Envois de notifications trop fréquents.")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "Serveur FTP non spécifié.")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "Login FTP non spécifié.")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "Fichier à envoyer sur le serveur FTP non trouvé dans le répertoire MQL5\\Files.")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "Echec de la connexion FTP.")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "Chemin FTP non trouvé sur le serveur.")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "Connexion FTP fermée.")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "Pas assez de mémoire pour les buffers des indicateurs.")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "Indice incorrect du buffer de l'indicateur.")
            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "Identifiant de propriété de l'indicateur personnalisé incorrect.")


        // Custom Indicator Properties.")

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "Identifiant de propriété du compte incorrect.")


        // Account

            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "Identifiant de propriété de trade incorrect.")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "Trading par les Expert Advisors interdit.")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "Position non trouvée.")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "Ordre non trouvé.")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "Transaction non trouvée.")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "Echec de l'envoi de la demande de trade.")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "Echec du calcul du profit ou de la marge.")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "Symbole inconnu.")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "L'indicateur ne peut pas être créé.")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "Pas assez de mémoire pour ajouter l'indicateur.")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "L'indicateur ne peut pas être appliqué à un autre indicateur.")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "Erreur lors de l'application d'un indicateur sur le graphique.")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "Données demandées non trouvées.")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "Handle d'indicateur incorrect.")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "Nombre de paramètres incorrect lors de la création d'un indicateur.")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "Aucun paramètre lors de la création d'un indicateur.")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "Le premier paramètre du tableau doit être le nom de l'indicateur personnalisé.")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "Type de paramètre invalide dans le tableau lors de la création d'un indicateur.")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "Indice incorrect du buffer demandé de l'indicateur.")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "Le Depth Of Market ne peut pas être ajouté.")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "Le Depth Of Market ne peut pas être enlevé.")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "Impossible d'obtenir les données du Depth Of Market.")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "Erreur lors de l'abonneemnt pour reçevoir les nouvelles données du Depth Of Market.")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "Impossible d'ouvrir plus de 64 fichiers en même temps.")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "Nom de fichier invalide.")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "Nom de fichier trop long.")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "Erreur d'ouverture du fichier.")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "Pas assez de mémoire en cache pour lire le fichier.")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "Erreur de suppression du fichier.")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "Un fichier avec ce handle a déjà été fermé, ou n'a pas été ouvert.")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "Handle de fichier incorrect.")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "Le fichier doit être ouvert en écriture.")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "Le fichier doit être ouvert en lecture.")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "Le fichier doit être ouvert en mode binaire.")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "Le fichier doit être ouvert en mode texte.")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "Le fichier doit être ouvert en mode texte ou CSV.")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "Le fichier doit être ouvert en mode CSV.")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "Erreur de lecture du fichier.")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "La taille de la chaîne de caractères doit être spécifiée, car le fichier est ouvert en mode binaire.")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "Un fichier texte est prévu pour les tableaux de chaînes de caractères, pour les autres tableaux, utiliser le mode binaire.")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "Ce n'est pas un fichier mais un répertoire.")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "Le fichier n'existe pas.")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "Impossible d'écrire dans le fichier.")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "Nom de répertoire incorrect.")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "Le répertoire n'existe pas.")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "Ce n'est pas un répertoire mais un fichier.")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "Le répertoire ne peut pas être supprimé.")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "Echec de suppression du répertoire (un ou plusieurs fichiers sont peut-être bloqués et l'opération de suppression a échoué).")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "Echec d'écriture de la ressource vers un fichier.")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "Imposible de lire l'élément suivant du fichier CSV (FileReadString, FileReadNumber, FileReadDatetime, FileReadBool), car la fin du fichier est atteinte.")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "Aucune date dans la chaîne de caractères.")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "Date incorrecte dans la chaîne de caractères.")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "Heure incorrecte dans la chaîne de caractères.")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "Erreur de conversion de la chaîne de caractères en date.")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "Pas assez de mémoire pour la chaîne de caractères.")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "La longueur de la chaîne de caractères est inférieure à la taille attendue.")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "Nombre trop grand, supérieur à ULONG_MAX.")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "Formatage de la chaîne de caractères invalide.")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "Nombre de spécificateurs de format supérieur au nombre de paramètres.")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "Nombre de paramètres supérieur au nombre de spécificateurs de format.")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "Paramètre de type string endommagé.")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "Position en dehors de la chaîne de caractères.")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "0 ajouté à la fin de la chaîne de caractères, opération inutile.")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "Type de données inconnu lors de la conversion vers une chaîne de caractères.")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "Objet string endommagé.")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "Copie de tableaux incompatibles Le tableau de chaîne de caractères ne peut être copié que vers un tableau de chaîne de caractèresn et un tableau numérique vers un tableau numérique.")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "Le tableau destination est déclaré comme AS_SERIES, et n'a pas une taille suffisante.")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "Tableau trop petit, le position de départ est en dehors du tableau.")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "Tableau de longueur zéro.")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "Doit être un tableau numérique.")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "Doit être un tableau à 1 dimension.")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "Timeseries ne peut pas être utilisé.")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "Doit être un tableau de type double.")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "Doit être un tableau de type float.")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "Doit être un tableau de type long.")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "Doit être un tableau de type int.")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "Doit être un tableau de type short.")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "Doit être un tableau de type char.")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "Doit être un tableau de type char.")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "Les fonctions OpenCL ne sont pas supportées sur cet ordinateur.")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "Une erreur interne est survenue lors de l'exécution d'OpenCL.")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "Handle OpenCL invalide.")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "Erreur lors de la création du contexte OpenCL.")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "Echec de création d'une queue dans OpenCL.")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "Une erreur est survenue lors de la compilation d'un programme OpenCL.")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "Nom de noyau (kernel) trop long (noyau OpenCL).")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "Erreur de création d'un noyau OpenCL.")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "Une erreur est survenue lors de la définition des paramètres pour le noyau OpenCL.")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "Erreur d'exécution du programme OpenCL runtime error.")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "Taille invalide du buffer OpenCL.")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "Offset invalide du buffer OpenCL.")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "Echec de création d'un buffer OpenCL.")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "Trop d'objets OpenCL.")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "Erreur de sélection du périphérique OpenCL.")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "Erreur interne de la base de données.")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "Handle incorrect de base de données.")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "Nombre maximum d'objets de base de données acceptables atteint.")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "Erreur de connexion à la base de données.")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "Erreur d'exécution de la requête.")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "Erreur de génération de la requête.")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "Plus de données à lire.")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "Echec du déplacement sur l'entrée suivante de la requête.")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "Les données pour la lecture des résultats de la requête ne sont pas encore prêts.")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "Echec de la substitution des paramètress de la requête SQL.")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "URL invalide.")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "Echec de connexion à l'URL spécifiée.")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "Délai dépassé.")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "Echec de la requête HTTP.")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "Handle de socket invalide passé à la fonction.")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "Trop de sockets ouvertes (max 128).")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "Echec de connexion à l'hôte distant.")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "Echec de l'envoi ou de la réception de données depuis la socket.")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "Echec d'établissement de la connexion sécurisée (TLS Handshake).")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "Aucune donnée concernant le certificat protégeant la connexion.")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "Un symbole personnalisé doit être spécifié.")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "Le nom du symbole personnalisé est invalide. Le nom du symbole ne peut contenir que des lettres latines, sans ponctuation, espace ou caractère spécial (ne peut contenir que '.', '_', '&' and '#'). Il n'est pas recommandé d'utiliser les caractères <, >, :, \", /,\\, |, ?, *..")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "Le nom du symbole personnalisé est trop long. La longueur du nom du symbole ne doit pas être supérieure à 32 caractères, incluant le caractère 0 terminal.")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "Le chemin du symbole personnalisé est trop long. La longueur du chemin ne doit pas excéder 128 caractères, incluant 'Custom\\', le nom du symbole, les séparateurs de groupes et le 0 terminal.")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "Un symbole personnalisé existe déjà avec ce nom.")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "Une erreur est survenue lors de la création, de la suppression ou du changement du symbole personnalisé.")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "Vous essayez de supprimer un symbole personnalisé sélectionné dans le Market Watch.")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "Propriété invalide du symbole personnalisé.")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "Paramètre incorrect lors de la définition de la propriété d'un symbole personnalisé.")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "Paramètre de type string trop long lors de la définition de la propriété d'un symbole personnalisé.")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "Les ticks du tableau ne sont pas ordonnés par heure.")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "La taille du tableau est insuffisante pour recevoir les descriptions de toutes les valeurs.")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "Délai d'attente de la requête dépassé.")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "Pays non trouvé.")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "Erreur générique.")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "Erreur de logique interne de SQLite.")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "Accés refusé.")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "Annulation de l'appel à la callback.")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "Fichier de la base de données verrouillé.")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "Table de la base de données verrouillée.")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "Mémoire insuffisante pour terminer l'opération.")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "Tentative d'écriture dans une base de données en lecture seule.")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "Opération terminée par sqlite3_interrupt().")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "Erreur de lecture/écriture sur le disque.")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "Image disque de la base de données corrompue.")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "Code d'opération inconnu dans sqlite3_file_control().")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "Echec de l'insertion car la base de données est pleine.")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "Impossible d'ouvrir le fichier de la base de données.")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "Erreur de protocole de verrouillage de la base de données.")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "Usage interne uniquement.")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "Schéma modifié de la base de données.")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "La taille de la chaîne de caractères ou du BLOB est supérieure à la limite autorisée.")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "Annulation suite à la violation d'une contrainte.")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "Différence de type des données.")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "Bibliothèque utilisée incorrectement.")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "Utilisation des fonctionnalités du système d'exploitation non supportée sur l'hôte.")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "Autorisation refusée.")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "Non utilisé.")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "Erreur de liaison du paramètre, indice incorrect.")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "Le fichier ouvert n'est pas un fichier de base de données.")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "Recotation (requote).")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "Demande rejetée.")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "Demande annulée par le trader.")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "Ordre placé.")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "Demande terminée.")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "La demande a été complétée partiellement.")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "Erreur de traitement de la demande.")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "Demande annulée en raison du délai trop long.")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "Demande invalide.")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "Volume invalide dans la demande.")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "Prix invalide dans la demande.")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "Stops invalides dans la demande.")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "Le trading est désactivé.")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "Le marché est fermé.")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "Pas assez d'argent pour compléter la demande.")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "Les prix ont changé.")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "Il n'y a pas de cotation pour traiter la demande.")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "Date d'expiration de l'ordre invalide dans la demande.")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "L'état de l'ordre a changé.")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "Demandes trop fréquentes.")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "Aucun changement dans la demande.")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "Trading automatique désactivé par le serveur.")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "Trading automatique désactivé par le terminal client.")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "Demande verrouillée pour traitement.")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "Ordre ou position gelé.")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "Type de remplissage d'ordre invalide.")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "Aucune connexion au serveur de trades.")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "L'opération n'est autorisée que pour les comptes réels.")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "Le nombre limite d'ordres en attente est atteint.")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "Le volume des ordres et des positions pour le symbole a atteint la limite autorisée.")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "Type d'ordre incorrect ou interdit.")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "La position avec le POSITION_IDENTIFIER spécifié a déjà été fermée.")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "Le volume de clôture est supérieur au volume actuel de la position.")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "Un ordre de clôture existe déjà pour la position spécifiée Ceci peut arriver lors de l'utilisation du hedging: \r\nlors de la tentative de clôturer une position avec une position opposée, alors que des ordres de clôture pour la position existent déjà. \r\nlors de la tentative de clôturer complétement ou partiellement une position, si le volume total des ordres de clôture existants et du nouvel ordre placé est supérieur au volume actuel de la position.")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "Le nombre de positions ouvertes simultanément sur un compte peut être limité par le paramètrage du serveur. Lorsque la limite est atteinte, le serveur retourne l'erreur TRADE_RETCODE_LIMIT_POSITIONS lors de la demande de placement d'un nouvel ordre. La limite se comporte différemment suivant le type de comptabilisation des positions: \r\nNetting – le nombre de positions ouvertes est pris en compte. Lorsque la limite est atteinte, la plateforme désactive le placement de nouveaux ordres dont l'exécution augmenterait le nombre de positions ouvertes. La plateforme n'autorise en fait que le placement d'ordres pour les symboles ayant déjà des positions ouvertes. Les ordres en attente en cours ne sont pas considérés puisque leur exécution peut amener des changements pour les positions actuelles mais n'augmente pas leur nombre. \r\nHedging – les ordres en attente sont pris en compte de même que les positions ouvertes, puisque l'activation d'un ordre en attente conduit toujours à ouvrir une nouvelle position. Lorsque la limite est atteinte, la plateforme désactive à la fois les nouveaux ordres au marché pour ouvrir une position et les ordres en attente..")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "La demande d'activation de l'ordre en attente est rejetée, l'ordre est annulé.")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "La demande est rejetée car le paramètre 'Seules les positions long sont autorisées' est activé pour le symbole (POSITION_TYPE_BUY).")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "La demande est rejetée car le paramètre 'Seules les positions short sont autorisées' est activé pour le symbole (POSITION_TYPE_SELL).")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "La demande est rejetée car le paramètre 'Seules les clôtures de positions sont autorisées' est activé pour le symbole.")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "La requête est rejetée car le flag 'La fermeture de la position n'est autorisée que par une règle FIFO' est utilisé pour le compte de trading (ACCOUNT_FIFO_CLOSE=true).")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "La requête est rejetée car la règle 'Les positions opposées sur un seul symbole sont désactivées' est définie pour le compte de trading. Par exemple, si le compte a une position d'achat, un utilisateur ne peut pas ouvrir une position de vente ou passer un ordre de vente en attente. La règle n'est appliquée qu'aux comptes avec système de comptabilité de couverture (ACCOUNT_MARGIN_MODE= ACCOUNT_MARGIN_MODE_RETAIL_HEDGING)..")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
}
#endif


// Language specific error code resolver (italian)
#ifdef LIB_ERROR_LANG_TERM_ID_IT
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_IT)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "L'operazione è stata completata con successo.")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "Errore interno imprevisto.")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "Parametri non validi nella chiamata interna della funzione del terminale client.")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "Parametro errato quando si chiama la funzione di sistema.")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "Memoria insufficiente per eseguire la funzione del sistema.")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "La struttura contiene oggetti di stringhe e/o array dinamici e/o la struttura di tali oggetti e/o classi.")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "Array di un tipo errato, grandezza errata, o un oggetto danneggiato di un array dinamico.")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "Memoria insufficiente per il trasferimento di un array, o un tentativo di modificare la grandezza di un array statico.")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "Memoria insufficiente per il trasferimento di stringa.")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "Stringa non inizializzata.")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "Data e/o ora non validi.")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "La quantità totale di elementi nell'array non può superare 2147483647.")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "Puntatore errato.")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "Tipo errato di puntatore.")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "La funzione di sistema non è autorizzata a chiamare.")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "I nomi delle risorse dinamiche e statiche, corrispondono.")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "Risorse con questo nome non sono state trovate in EX5.")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "Tipo di risorsa non supportata o la sua grandezza supera i 16 Mb.")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "Il nome della risorsa supera i 63 caratteri.")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "E' avvenuto l'overflow quando si calcolava la funzione matematica.")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Fuori data di fine test dopo aver chiamato Sleep().")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                       "ERR_PROGRAM_STOPPED",                     "Test forzatamente interrotto dall'esterno. Ad esempio, ottimizzazione interrotta, finestra di test visuali chiusa o agente di testing interrotto.")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "ID del Chart errato.")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "Il chart non risponde.")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "Chart non trovato.")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "Nessun Expert Advisor nel chart che potrebbe gestire l'evento.")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "Errore di apertura del chart.")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "Impossibile modificare il simbolo ed il periodo del chart.")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "Valore dell'errore dei parametri per la funzione di lavoro con i charts.")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "Impossibile creare il timer.")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "ID proprietà del chart, sbagliato.")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "Errore durante la creazione di uno screenshot.")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "Errore di navigazione attraverso il grafico.")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "Errore durante l'applicazione del template.")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "La sottofinestra contenente l'indicatore non è stata trovata.")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "Errore durante l'aggiunta di un indicatore al chart.")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "Errore durante l'eliminazione di un indicatore dal chart.")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "Indicatore non trovato sul chart specificato.")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "Errore di lavoro con un oggetto grafico.")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "L' oggetto grafico non è stato trovato.")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "ID errato di una proprietà oggetto grafico.")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "Impossibile ottenere data corrispondente al valore.")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "Impossibile ottenere il valore corrispondente alla data.")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "Simbolo sconosciuto.")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "Il simbolo non è selezionato in MarketWatch.")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "Identificatore errato di una proprietà del simbolo.")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "L'orario dell'ultimo tick non è noto (nessun ticks).")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "Errore durante l'aggiunta o l'eliminazione di un simbolo in MarketWatch.")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "Storico richiesto non trovato.")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "ID errato della proprietà dello storico.")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "Timeout eccessivo nella richiesta dello storico.")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "Numero di barre richieste limitato dalle impostazioni terminale.")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "Errori multipli durante il caricamento dello storico.")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "L'array ricevente è troppo piccolo per conservare tutti i dati richiesti.")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "La variabile globale del terminale cliente non è stata trovata.")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "La variabile globale del terminale client con lo stesso nome esiste già.")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "Le variabili globali non sono state modificate.")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "Non posso leggere il file con i valori delle variabiili globali.")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "Non posso scrivere il file con i valori delle variabiili globali.")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "Invio email fallito.")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "Riproduzione del suono fallita.")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "Identificatore errato della proprietà del programma.")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "Identificatore errato della proprietà del terminale.")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "Invio file tramite ftp fallito.")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "Fallimento nell'invio di una notifica.")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "Parametro non valido per l'invio di una notifica - una stringa vuota o NULL è stato passato alla funzione SendNotification().")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "Impostazioni errate di notifiche nel terminale (ID non è specificato o l'autorizzazione non è impostata).")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "Invio troppo frequente delle notifiche.")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "Il server FTP non è specificato.")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "L'accesso FTP non è specificato.")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "File non trovato nella directory MQL5\\Files da inviare sul server FTP.")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "Connessione FTP non riuscita.")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "Percorso FTP non trovato sul server.")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "Connessione FTP chiusa.")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "Memoria insufficiente per la distribuzione dei buffer indicatore.")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "Errato indice buffer indicatore.")
            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "ID errato della proprietà indicatore personalizzato.")


        // Custom Indicator Properties.")

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "Proprietà ID dell'account, sbagliata.")


        // Account

            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "Proprietà ID del trade, sbagliata.")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "Trading da Expert Advisors vietato.")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "Posizione non trovata.")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "Ordine non trovato.")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "Affare non trovato.")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "Richiesta di trade non riuscita.")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "Errore nel calcolare profitto o margine.")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "Simbolo sconosciuto.")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "L' indicatore non può essere creato.")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "Memoria insufficiente per aggiungere l'indicatore.")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "L'indicatore non può essere applicato ad un altro indicatore.")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "Errore durante l'applicazione di un indicatore al grafico.")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "Dati richiesti non trovati.")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "Handle indicatore, errato.")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "Numero errato di parametri durante la creazione di un indicatore.")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "Nessun parametro quando si crea un indicatore.")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "Il primo parametro dell'array deve essere il nome dell' indicatore personalizzato.")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "Parametro di tipo non valido nell'array durante la creazione di un indicatore.")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "Indice errato del buffer indicatore richiesto.")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "Profondità di Mercato non può essere aggiunta.")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "Profondità di Mercato non può essere rimossa.")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "I dati dalla Profondità di Mercato non possono essere ottenuti.")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "Errore nella sottoscrizione di ricezione di nuovi dati da Profondità di Mercato.")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "Più di 64 file non possono essere aperti contemporaneamente.")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "Nome di file non validi.")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "Nome del file troppo lungo.")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "Errore durante l'apertura del file.")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "Memoria insufficiente per la cache di lettura.")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "Errore durante l'eliminazione del file.")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "Un file con questo handle è stato chiuso, o non è stato proprio aperto.")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "File handle errato.")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "Il file deve essere aperto per la scrittura.")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "Il file deve essere aperto per la lettura.")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "Il file deve essere aperto come un file binario.")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "Il file deve essere aperto come un testo.")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "Il file deve essere aperto come un testo o CSV.")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "Il file deve essere aperto come CSV.")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "Errore lettura file.")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "La grandezza della stringa deve essere specificata, in quanto il file viene aperto come binario.")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "Un file di testo deve essere per gli array di stringhe, per altri array - binario.")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "Questo non è un file, questa è una directory.")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "Il file non esiste.")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "Il file non può essere riscritto.")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "Nome directory errata.")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "Directory non esiste.")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "Questo è un file, non una directory.")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "La directory non può essere rimossa.")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "Impossibile cancellare la directory (probabilmente uno o più file sono bloccati e l'operazione di rimozione è fallita).")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "Impossibile scrivere una risorsa in un file.")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "Impossibile leggere il successivo pezzo di dati dal file CSV (FileReadString, FileReadNumber, FileReadDatetime, FileReadBool), finchè non viene raggiunta la fine del file.")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "Nessuna data nella stringa.")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "Data errata nella stringa.")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "Orario sbagliato nella stringa.")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "Errore di conversione da stringa a data.")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "Memoria insufficiente per la stringa.")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "La lunghezza della stringa è inferiore al previsto.")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "Numero troppo largo, più di ULONG_MAX.")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "Formato stringa non valido.")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "Quantità di specificatori di formato superiore ai parametri.")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "Quantità dei parametri più degli specificatori di formato.")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "Parametro danneggiato di tipo stringa.")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "Posizione al di fuori della stringa.")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "0 aggiunto alla fine della stringa, una operazione inutile.")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "Dati di tipo sconosciuto durante la conversione in una stringa.")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "Oggetto della stringa, dannegiato.")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "Copia di array incompatibili. Array di stringhe possono essere copiati solo per array di stringhe, ed un array numerico - solo in un array numerico.")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "L'array ricevente viene dichiarato come AS_SERIES, ed è di grandezza insufficiente.")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "Array troppo piccolo, la posizione di partenza è fuori dell'array.")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "Un array di lunghezza zero.")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "Deve essere un array numerico.")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "Deve essere un array mono-dimensionale.")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "Timeseries non possono essere utilizzate.")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "Deve essere un array di tipo double.")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "Deve essere un array di tipo float.")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "Deve essere un array di tipo long.")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "Deve essere un array di tipo int.")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "Deve essere un array di tipo corto.")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "Deve essere un array di tipo char.")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "Deve essere un array di tipo stringa.")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "Funzioni OpenCL non sono supportate su questo computer.")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "Un errore interno si è verificato quando si eseguiva OpenCL.")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "Non valido handle OpenCL.")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "Errore durante la creazione del contesto OpenCL.")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "Impossibile creare una coda di esecuzione in OpenCL.")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "Si è verificato un errore durante la compilazione di un programma OpenCL.")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "Nome kernel troppo lungo (OpenCL kernel).")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "Errore durante la creazione di un OpenCL kernel.")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "Errore avvenuto durante impostazione dei parametri per il kernel OpenCL.")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "Errore programma OpenCL:errore di runtime.")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "Dimensione non valida del buffer OpenCL.")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "Offset non valido nel buffer OpenCL.")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "Impossibile creare un buffer OpenCL.")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "Troppi oggetti OpenCL.")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "Errore selezione dispositivo OpenCL.")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "Errore interno del database.")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "Handle del database non valido.")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "Superato il numero massimo accettabile di oggetti Database.")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "Errore di connessione al database.")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "Errore esecuzione della Richiesta.")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "Errore generazione della Richiesta.")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "Non ci sono più dati da leggere.")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "Impossibile passare alla successiva voce di richiesta.")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "I dati per la lettura dei risultati della richiesta non sono ancora pronti.")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "Impossibile sostituire automaticamente i parametri con una richiesta SQL.")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "URL non valido.")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "Impossibile connettersi all' URL specificato.")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "È stato superato il timeout.")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "La richiesta HTTP non è riuscita.")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "L'handle del socket non valido è passato alla funzione.")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "Troppi socket aperti (max 128).")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "Impossibile connettersi all'host remoto.")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "Impossibile inviare/ricevere dati dal socket.")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "Impossibile stabilire una connessione sicura (TLS Handshake).")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "Nessun dato sul certificato che protegge la connessione.")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "È necessario specificare un simbolo personalizzato.")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "Il nome del simbolo personalizzato non è valido. Il nome del simbolo può contenere solo lettere latine senza punteggiatura, spazi o caratteri speciali (può contenere solo '.', '_', '&' e '#'). Non è consigliabile utilizzare i caratteri <, >, :, \", /,\\, |, ?, *..")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "Il nome del simbolo personalizzato è troppo lungo. La lunghezza del nome del simbolo non deve superare i 32 caratteri tra cui il carattere finale 0.")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "Il percorso del simbolo personalizzato è troppo lungo. La lunghezza del percorso non deve superare i 128 caratteri tra cui 'Custom\\', il nome del simbolo, i separatori di gruppo e la fine 0.")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "Esiste già un simbolo personalizzato con lo stesso nome.")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "Errore durante la creazione, la cancellazione o la modifica del simbolo personalizzato.")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "Stai cercando di eliminare un simbolo personalizzato selezionato in Market Watch.")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "Una proprietà di simboli personalizzati non valida.")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "Un parametro sbagliato durante l'impostazione della proprietà di un simbolo personalizzato.")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "Un parametro di stringa troppo lungo impostando la proprietà di un simbolo personalizzato.")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "I ticks nell'array sono non organizzati nell'ordine di tempo.")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "La grandezza dell'array è insufficiente per la ricezione delle descrizioni di tutti i valori.")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "Limite di tempo richiesto superato.")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "Paese non trovato.")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "Errore generico.")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "Errore logico interno di SQLite.")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "Accesso negato.")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "La routine di callback ha richiesto l'interruzione.")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "File di database bloccato.")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "Tabella del database bloccata.")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "Memoria insufficiente per il completamento dell'operazione.")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "Tentativo di scrittura nel database di sola lettura.")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "Operazione terminata da sqlite3_interrupt().")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "Errore I/O del disco.")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "Immagine del disco del database danneggiata.")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "Codice operazione sconosciuto in sqlite3_file_control().")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "Inserimento non riuscito perché il database è pieno.")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "Impossibile aprire il file del database.")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "Errore di blocco del protocollo del database.")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "Solo per uso interno.")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "Schema del database modificato.")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "String o BLOB supera il limite di dimensioni.")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "Annullato a causa di violazione del vincolo.")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "Mancata corrispondenza del tipo di dati.")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "Libreria utilizzata in modo errato.")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "Utilizzo funzionalità del sistema operativo non supportate sull'host.")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "Autorizzazione negata.")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "Non usato.")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "Errore parametro bind, indice errato.")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "File aperto che non è un file di database.")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "Riquotazione.")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "Richiesta rigettata.")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "Richiesta annullata dal trader.")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "Ordine piazzato.")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "Richiesta completata.")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "Solo una parte della richiesta è stata completata.")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "Errore elaborazione richiesta.")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "Richiesta annullata per timeout.")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "Richiesta non valida.")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "Volume non valido nella richiesta.")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "Prezzo non valido nella richiesta.")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "Stops non validi nella richiesta.")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "Il trade è disattivato.")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "Il mercato è chiuso.")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "Non ci sono abbastanza soldi per completare la richiesta.")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "Prezzi cambiato.")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "Non ci sono quotazioni per elaborare la richiesta.")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "Data di espirazione dell'ordine non valida nella richiesta.")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "Stato ordine cambiato.")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "Richieste troppo frequenti.")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "Nessuna modifica nella richiesta.")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "Autotrading disabilitato dal server.")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "Autotrading disabilitato dal terminale client.")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "Richiesta bloccata pe l'elaborazione.")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "Ordine o posizione congelati.")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "Non valido tipo di filling dell'ordine.")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "Nessuna connessione con il trade server.")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "Il funzionamento è consentito solo per i conti live.")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "Il numero di ordini in corso ha raggiunto il limite.")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "Il volume degli ordini e posizioni per il simbolo ha raggiunto il limite.")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "Errato o proibitotipo di ordine.")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "La posizione con lo specificato POSITION_IDENTIFIER è stata già chiusa.")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "Il volume di chiusura supera il volume della posizione corrente.")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "Un ordine già chiuso esiste già per una posizione specificata. Questo può accadere quando si lavora nel sistema hedging: \r\nquando si tenta di chiudere una posizione con quella opposta, mentre esistono già ordini di chiusura per la posizione. \r\nquando si tenta di chiudere completamente o parzialmente una posizione se il volume totale dei già presenti ordini di chiusura ed i nuovi piazzati eccedono il volume della posizione corrente..")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "l numero di posizioni aperte contemporaneamente presenti sull'account può essere limitato dalle impostazioni del server. Una volta raggiunto il limite, il server restituisce l'errore TRADE_RETCODE_LIMIT_POSITIONS quando si tenta di piazzare un ordine. La limitazione funziona in modo diverso a seconda del tipo di accounting della posizione: \r\nNetting(compensazione) — viene considerato il numero di posizioni aperte. Quando viene raggiunto un limite, la piattaforma disabilita il piazzamento di nuovi ordini la cui esecuzione può aumentare il numero di posizioni aperte. Infatti, la piattaforma permette di piazzare ordini solo per i simboli che già hanno posizioni aperte. Gli ordini pendenti attuali non sono considerati in quanto la loro esecuzione può portare a cambiamenti nelle posizioni attuali, ma non può aumentare il loro numero. \r\nHedging(copertura) — gli ordini pendenti vengono considerati insieme alle posizioni aperte, dal momento che l'attivazione id un ordine pendente porta sempre ad aprire una nuova posizione. Quando viene raggiunto un limite, la piattaforma disabilita sia i nuovi ordini di mercato per l'apertura di posizioni che gli ordini pendenti..")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "La richiesta di attivazione dell'ordine pendente viene rifiutata, l'ordine viene annullato.")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "La richiesta è stata respinta perché è impostata per il simbolo la regola 'Sono consentite solo posizioni long' (POSITION_TYPE_BUY).")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "La richiesta è stata respinta perché è impostata per il simbolo la regola 'Sono consentite solo posizioni short' (POSITION_TYPE_SELL).")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "La richiesta è stata respinta perché è impostata per il simbolo la regola 'È consentita solo la chiusura della posizione'.")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "La richiesta è stata respinta perché è impostato per l'account di trading il flag 'La chiusura della posizione è consentita solo dalla regola FIFO' (ACCOUNT_FIFO_CLOSE=true).")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "La richiesta viene rifiutata, perché per il conto di trading è impostata la regola 'Posizioni opposte su un unico simbolo sono disabilitate'. Ad esempio, se l'account ha una posizione di acquisto, un utente non può aprire una posizione di vendita o inserire un ordine di vendita in sospeso. La regola si applica solo ai conti con sistema di contabilizzazione di copertura (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING)..")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
}
#endif



// Language specific error code resolver (turkish)
#ifdef LIB_ERROR_LANG_TERM_ID_TR
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_TR)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "İşlem başarıyla tamamlandı.")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "Beklenmeyen içsel hata.")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "Müşteri terminali fonksiyonunun çağrısında yanlış parametre kullanımı.")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "Sistem fonksiyonunun çağrısında yanlış fonksiyon kullanımı.")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "Sistem fonksiyonunu uygulamak için yeterli bellek yok.")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "Yapı, dizgi nesnelerini ve/veya dinamik dizileri ve/veya bu tip nesnelerin yapılarını ve/veya sınıflarını içeriyor.")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "Yanlış tipli veya yanlış büyüklükte bir dizi veya hasarlı bir nesne veya bir dinamik dizi.")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "Dizinin yer değişimi için yeterli belek yok, veya bir statik dizinin büyüklüğünü değiştirme girişimi yapıldı.")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "Dizginin yeniden yerleştirilmesi için yeterli bellek yok.")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "Başlatılmamış dizgi.")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "Geçersiz tarih ve/veya zaman.")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "Dizideki elemanların sayısı 2147483647'yi geçemez.")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "Yanlış işaretçi.")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "Yanlış tipte işaretçi.")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "Sistem fonksiyonunun çağrılmasına izin verilmiyor.")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "dynamic ve static kaynakların isimleri uyuşuyor.")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "EX5 içinde bu isimde kaynak bulunamadı.")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "Desteklenmeyen kaynak tipi veya kaynağın boyutu 16 Mb'i geçiyor.")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "kaynak ismi 63 karakteri aşıyor.")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "Matematiksel fonksiyon hesaplanırken taşma oluştu.")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Çağrılan Sleep(), test bitiş zamanını aşıyor.")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                      "ERR_PROGRAM_STOPPED",                     "Test zorla dışarıdan durduruldu. Örneğin, optimizasyon kesintiye uğratıldı, görsel test penceresi kapatıldı veya test temsilcisi durduruldu.")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "Yanlış çizelge kimliği (tanımlayıcısı).")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "Çizelge yanıt vermiyor.")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "Çizelge bulunamadı.")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "Çizelgede, olayı işleyebilecek bir Uzman Danışman yok.")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "Çizelge açılma hatası.")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "Çizelge periyodunu ve sembolünü değiştirme işlemi başarısız oldu.")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "Çizelge ile çalışma fonksiyonu için kullanılan parametrenin hata değeri.")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "Sayacı başlatma başarısız.")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "Yanlış çizelge özelliği tanımlayıcısı.")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "Ekran görüntüsü oluşturma hatası.")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "Çizelge boyunca konumlandırma hatası.")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "Şablon uygulama hatası.")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "Göstergeyi içeren alt pencere bulunamadı.")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "Çizelgeye gösterge eklerken hata oluştu.")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "Göstergeyi çizelgeden silerken hata oluştu.")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "Gösterge belirtilen çizelge üzerinde bulunamadı.")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "Grafiksel nesne ile çalışma hatası.")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "Grafiksel nesne bulunamadı.")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "Grafiksel nesne için yanlış tanımlayıcı.")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "Değere karşılık gelen tarih alınamadı.")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "Tarihe karşılık gelen değer alınamadı.")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "Bilinmeyen sembol.")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "Sembol, Piyasa Gözleminde seçilmedi.")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "Sembol özelliği için yanlış tanımlayıcı.")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "Son tik zamanı bilinmiyor (hiç tik yok).")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "Sembolün Piyasa Gözleminden silinmesinde hata.")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "İstenen geçmiş bulunamadı.")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "Geçmiş özeliğinin tanımlayıcısı yanlış.")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "Geçmiş veri isteğinde zamanaşımı oluştu.")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "İstenen çubuk sayısı terminal ayarlarında sınırlandırılmış.")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "Geçmiş veri yüklemesi sırasında hatalar oluştu.")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "Hedef dizi, istenen veriyi depolamak için çok küçük.")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "Müşteri terminalinin global değişkeni bulunamadı.")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "Aynı isimde bir müşteri terminali global değişkeni mevcut.")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "Global değişkenler ayarlanmamış.")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "Global değişken değerlerini içeren dosya okunamadı.")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "Global değişken değerlerini içeren dosyaya yazılamadı.")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "Email gönderimi başarısız oldu.")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "Ses oynatımı başarısız oldu.")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "Program özelliğinin tanımlayıcısı yanlış.")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "Terminal özelliğinin tanımlayıcısı yanlış.")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "Ftp ile dosya gönderimi başarısız oldu.")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "Uyarı gönderme başarısız oldu.")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "Uyarı gönderimi için geçersiz parametre – boş bir dizgi veya NULL değeri SendNotification() fonksiyonuna geçirilmiş.")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "Terminalin uyarı ayarları hatalı yapılmış (tanımlayıcı belirtilmemiş veya izin durumu ayarlanmamış).")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "Uyarı gönderimi çok sık.")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "FTP sunucusu belirtilmedi.")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "FTP girişi belirtilmedi.")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "FTP sunucusuna gönderilecek MQL5\\Files dizininde dosya bulunamadı.")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "FTP bağlantısı başarısız oldu.")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "FTP yolu sunucuda bulunamadı.")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "FTP bağlantısı kapatıldı.")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "Gösterge tamponlarının dağıtılması için yeterli bellek yok.")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "Gösterge tamponunun indisi yanlış.")
            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "Özel gösterge özeliğinin tanımlayıcısı yanlış.")


        // Custom Indicator Properties.")

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "Hesap özelliğinin tanımlayıcısı yanlış.")


        // Account

            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "Alım-satım özelliği tanımlayıcısı yanlış.")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "Uzman Danışmanlar ile alım-satım yapmak yasaklanmış.")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "Pozisyon bulunamadı.")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "Emir bulunamadı.")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "İşlem bulunamadı.")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "Alım-satım isteğinin gönderilmesi başarısız oldu.")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "Kar veya teminat değeri hesaplanamadı.")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "Bilinmeyen sembol.")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "Gösterge oluşturulamıyor.")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "Göstergeyi eklemek için yeterli bellek yok.")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "Bu gösterge başka bir göstergeye uygulanamaz.")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "Göstergenin çizelgeye uygulanmasında hata.")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "İstenen veri bulunamadı.")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "Göstergenin tanıtıcı değeri yanlış.")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "Göstergedeki parametre sayısı yanlış.")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "Göstergede hiç parametre yok.")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "Dizideki ilk parametre, özel göstergenin ismi olmalı.")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "Gösterge oluşturulması sırasında, dizi içinde geçersiz parametre tipi.")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "İstenen gösterge tamponunun indisi hatalı.")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "Piyasa Derinliği eklenemiyor.")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "Piyasa Derinliği kaldırılamıyor.")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "Piyasa Derinliğinden veri alınamıyor.")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "Piyasa Derinliğinden veri alımı için abonelik hatası.")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "64 dosyadan fazlası aynı anda açılamaz.")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "Geçersiz dosya ismi.")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "Dosya ismi çok uzun.")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "Dosya açma hatası.")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "Okuma için yeterli önbellek alanı yok.")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "Dosya silme hatası.")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "Bu tanıtıcı değere sahip bir dosya kapatıldı, veya hiç açılmadı.")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "Dosya için yanlış tanıtıcı değer.")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "Dosya yazım amacıyla açılmalıdır.")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "Dosya okuma amacıyla açılmalıdır.")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "Dosya, ikili (binary) dosya şeklinde açılmalıdır.")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "Dosya, metin (txt) dosyası şeklinde açılmalıdır.")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "Dosya, metin (txt) veya CSV dosyası şeklinde açılmalıdır.")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "Dosya, CSV dosyası şeklinde açılmalıdır.")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "Dosya okuma hatası.")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "Dosya ikili biçimde açıldığı için dizgi büyüklüğü belirtilmelidir.")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "Metin dosyaları dizgi dizileri için olmalıdır, diğer diziler için ikili (binary) dosyalar kullanılmalıdır.")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "Bu bir dosya değil, bir klasör.")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "Dosya mevcut değil.")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "Dosya yeniden yazılamaz.")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "Dosya yolunun ismi yanlış.")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "Böyle bir dosya yolu bulunmuyor.")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "Bu bir dosya, klasör değil.")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "Klasör kaldırılamaz.")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "Klasörün kaldırılması başarısız oldu (büyük olasılıkla bir veya iki dosya bloke edilmiş ve kaldırma işlemi başarısız olmuş).")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "Kaynağı dosyaya yazma işlemi başarısız oldu.")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "Verinin sonraki kısımları CSV dosyasından okunamıyor (FileReadString, FileReadNumber, FileReadDatetime, FileReadBool) dosyanın sonuna ulaşıldı.")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "Dizgide tarih yok.")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "Dizgideki tarih yanlış.")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "Dizgideki zaman yanlış.")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "Dizgiyi tarihe çevirme hatası.")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "Dizgi için yeterli bellek yok.")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "Dizgi uzunluğu beklenenden az.")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "Sayı çok büyük, ULONG_MAX değerinden fazla.")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "Geçersiz biçim dizgisi.")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "Biçim belirteçlerinin sayısı, parametrelerden fazla.")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "Parametrelerin sayısı, biçim belirteçlerinden fazla.")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "string tipli hatalı parametre.")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "Konum, dizginin dışında.")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "Dizginin sonuna 0 eklenmiş, kullanışsız işlem.")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "Dizgiye dönüşüm yaparken bilinmeyen veri tipi.")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "Hasarlı dizgi nesnesi.")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "Uyumlu olmayan dizilerin kopyalanması. Dizgi dizisi sadece bir dizgi dizisine kopyalanabilir, aynı şekilde bir sayısal dizi de sadece sayısal diziye kopyalanabilir.")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "Alınan dizi AS_SERIES şeklinde bildirilmiş ve yeterli büyüklükte değil.")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "Dizi çok küçük, başlangıç konumu dizinin dışında.")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "Dizinin büyüklüğü sıfır.")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "Nümerik bir dizi olmalı.")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "Tek boyutlu bir dizi olmalı.")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "Zaman serileri kullanılamaz.")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "double tipli bir dizi olmalı.")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "float tipli bir dizi olmalı.")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "long tipli bir dizi olmalı.")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "int tipli bir dizi olmalı.")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "short tipli bir dizi olmalı.")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "char tipli bir dizi olmalı.")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "Sadece dizgi dizileri.")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "OpenCL fonksiyonları bu bilgisayarda desteklenmiyor.")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "OpenCL çalışması sırasında bir hata oluştu.")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "Geçersiz OpenCL işleyici.")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "OpenCL bağlamı oluşturma hatası.")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "OpenCL içinde bir çalıştırma kuyruğu oluşturma hatası.")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "OpenCL programının derlenmesi sırasında hata oluştu.")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "Kernel ismi çok uzun (OpenCL kernel).")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "OpenCL kerneli oluşturma hatası.")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "OpenCL kerneli için parametrelerin ayarlanması sırasında hata oluştu.")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "OpenCL programı çalışma zamanı hatası.")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "OpenCL tamponu için geçersiz büyüklük.")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "OpenCL tamponu içinde geçersiz konum.")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "OpenCL tamponu oluşturma hatası.")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "Çok fazla OpenCL nesnesi var.")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "OpenCL cihaz seçimi hatası.")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "Dahili veritabanı hatası.")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "Geçersiz veritabanı tanıtıcısı.")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "Kabul edilebilir maksimum Database nesnesi sayısı aşıldı.")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "Veritabanı bağlantı hatası.")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "İstek yürütme hatası.")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "İstek oluşturma hatası.")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "Okunacak daha fazla veri yok.")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "Bir sonraki istek girişine geçerken hata oluştu.")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "İstek sonuçlarını okumak için veriler henüz hazır değil.")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "SQL isteğinde parametrelerin otomatik değiştirilmesi başarısız oldu.")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "Geçersiz URL.")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "Belirtilen URL ile bağlantı kurulamadı.")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "Zaman-aşımı oluştu.")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "HTTP isteği başarısız.")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "Fonksiyona geçersiz soket tanıtıcısı aktarıldı.")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "Çok fazla açık soket(maksimum 128).")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "Uzak ana bilgisayara bağlanılamadı.")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "Soketten veri gönderilemedi/alınamadı.")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "Güvenli bağlantı kurulamadı (TLS Tokalaşma).")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "Bağlantıyı koruyan sertifikada veri yok.")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "Kullanıcı-tanımlı bir sembol belirtilmeli.")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "Kullanıcı-tanımlı sembolün ismi geçersiz. Sembol ismi sadece Latin karakterleri ve '.', '_', '&' ve '#' karakterlerini içerebilir, bunların dışındaki noktalama işaretlerini, boşluk ve diğer özel karakterleri içeremez. <, >, :, \", /,\\, |, ?, * karakterlerinin kullanılması önerilmez..")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "Kullanıcı-tanımlı sembolün ismi çok uzun. Sembol ismi, sondaki 0 karakteri de dahil olmak üzere 32 karakteri geçemez.")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "Kullanıcı-tanımlı sembolün adresi çok uzun. Adres; 'Custom\\', sembol ismi, grup ayraçları ve sondaki 0 karakteri de dahil olmak üzere 128 karakterden fazla olamaz.")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "Aynı isimde başka bir sembol mevcut.")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "Kullanıcı-tanımlı sembolün oluşturulması, silinmesi veya değiştirilmesi sırasında hata meydana geldi.")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "Piyasa gözleminde seçili olan kullanıcı-tanımlı bir sembolü silmeyi deniyorsunuz.")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "Kullanıcı-tanımlı sembol için geçersiz özellik.")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "Kullanıcı-tanımlı sembol özelliği ayarlanırken hatalı parametre kullanıldı.")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "Kullanıcı-tanımlı sembol özelliğinin parametresi için kullanılan dizgi çok uzun.")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "Dizideki tikler zamana göre sıralanmamıştır.")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "Dizi boyutu, tüm değerlerin açıklamalarını elde etmek için yetersizdir.")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "İstek süresi sınırı aşıldı.")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "Ülke bulunamadı.")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "Genel hata.")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "SQLite dahili mantık hatası.")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "Erişim reddedildi.")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "Geri arama prosedürü durdurma istedi.")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "Veritabanı dosyası kilitli.")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "Veritabanı tablosu kilitli.")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "İşlemi tamamlamak için yetersiz bellek.")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "Salt okunur veritabanına yazma girişimi.")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "İşlem sqlite3_interrupt() tarafından sonlandırıldı.")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "Disk girdi-çıktı hatası.")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "Veritabanı disk görüntüsü bozuk.")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "Sqlite3_file_control()'de bilinmeyen işlem kodu.")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "Veritabanı dolu olduğu için ekleme başarısız oldu.")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "Veritabanı dosyası açılamıyor.")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "Veritabanı kilit protokolü hatası.")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "Sadece dahili kullanım içindir.")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "Veritabanı şeması değişti.")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "Dizge veya BLOB boyut sınırını aşıyor.")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "Kısıtlama ihlali nedeniyle durduruldu.")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "Veri tipi uyumsuzluğu.")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "Kütüphanenin yanlış kullanımı.")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "Kullanılan işletim sistemi işlevleri ana bilgisayar tarafından desteklenmiyor.")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "Yetkilendirme reddedildi.")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "Kullanılmıyor.")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "Bağlama parametresi hatası, yanlış indeks.")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "Açılan dosya bir veritabanı dosyası değil.")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "Yeniden fiyatlandırma (requote).")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "İstek reddedildi.")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "İstek kullanıcı tarafından iptal edildi.")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "Emir işlendi.")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "İstek tamamlandı.")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "İsteğin sadece bir kısmı tamamlandı.")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "İstek işleme hatası.")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "İstek zaman-aşımı nedeniyle iptal edildi.")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "Geçersiz istek.")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "Geçersiz istek hacmi.")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "Geçersiz istek fiyatı.")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "İstek içinde geçersiz stop (durdurma) seviyeleri.")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "Alım-satım işlemleri devre dışı.")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "Piyasa kapalı.")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "İsteği tamamlayabilecek yeterli para yok.")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "Fiyatlar değişti.")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "İstek içinde işlenebilecek bir fiyat teklifi yok.")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "İstek içinde geçersiz zaman-aşımı tarihi.")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "Emir durumu değişti.")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "İsteklerin sıklığı fazla.")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "İstekte değişim yok.")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "Otomatik alım-satım, sunucu tarafından devre dışı bırakıldı.")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "Otomatik alım-satım, müşteri terminali tarafından devre dışı bırakıldı.")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "İstek işlem için kilitlendi.")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "Emir veya pozisyon dondurulmuş.")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "Geçersiz emir işleme tipi.")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "Alım-satım sunucusuyla bağlantı yok.")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "Sadece gerçek hesaplarda işleme izin veriliyor.")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "Bekleyen emirlerin sayısı sınıra ulaştı.")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "Sembol üzerindeki emirler ve pozisyonlar için hacim sınırına ulaşıldı.")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "Yanlış veya geçersiz emir tipi.")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "Belirtilmiş POSITION_IDENTIFIER özelliğine sahip olan pozisyon kapatılmış.")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "Kapanış hacmi mevcut pozisyon hacmini geçiyor.")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "Belirtilen pozisyon için zaten bir kapanış emri var. Bu durum hedge'li sistemde ortaya çıkabilir: \r\nBir pozisyonun ters yönlü başka bir pozisyonla kapatılması denendiğinde, önceden tanımlanan bir kapanış emri mevcutsa. \r\nPozisyonun tamamen veya kısmen kapatılması denendiğinde, önceden tanımlanan ve yeni yerleştirilen kapanış emirlerinin hacimlerinin mevcut pozisyon hacmini aşması durumunda.")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "Hesap üzerinde aynı anda açık olabilecek posizyonların sayısı sunucu ayarlarında sınırlandırılmış olabilir. Bu sınıra ulaşıldığında her yeni emir girişimi için sunucu tarafından TRADE_RETCODE_LIMIT_POSITIONS şeklinde bir hata dönüşü yapılır. Sınırlama, pozisyon muhasebesi sistemine bağlı olarak değişim gösterir: \r\nNetleştirme — açık pozisyonların sayısı göz önüne alınır. Sınıra ulaşıldığında, pozisyon sayısını artıracak yeni emirler platform tarafından devre-dışı bırakılır. Aslında, platform yeni emirlere sadece üzerinde zaten açık pozisyon bulunan semboller için izin verir. Mevcut bekleyen emirler, gerçekleşmeleri durumunda pozisyon sayısını artırmayabilecekleri için gözardı edilir ve pozisyon sayısını artıramazlar. \r\nHedge — her bekleyen emrin tetiklenmesi yeni bir pozisyonla sonuçlanacağı için, bekleyen emirler de açık pozisyonlarla birlikte değerlendirilir. Sınıra ulaşıldığında, platform bekleyen emirleri de piyasa emirleri gibi devre dışı bırakır..")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "Bekleyen emir isteği reddedildi, emir iptal edildi.")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "İstek reddedildi, çünkü sembol için'sadece uzun pozisyon açılabilir' kuralı ayarlanmış (POSITION_TYPE_BUY).")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "İstek reddedildi, çünkü sembol için'sadece kısa pozisyon açılabilir' kuralı ayarlanmış (POSITION_TYPE_SELL).")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "İstek reddedildi, çünkü sembol için'sadece pozisyon kapatılabilir' kuralı ayarlanmış.")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "İstek reddedildi, çünkü 'Pozisyon kapatmaya yalnızca FIFO kuralına göre izin verilmektedir' bayrağı alım-satım hesabı için ayarlanmıştır (ACCOUNT_FIFO_CLOSE=true).")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "İşlem hesabı için 'Sembol üzerinde zıt pozisyon açma devre dışıdır' kuralı ayarlandığından, istek reddedildi. Örneğin, işlem hesabında Alış pozisyonu varsa, kullanıcı Satış pozisyonu açamaz veya bekleyen satış emri giremez. Kural yalnızca hedge muhasebe sistemine sahip hesaplara uygulanır (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING)..")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
}
#endif


// Language specific error code resolver (russian)
#ifdef LIB_ERROR_LANG_TERM_ID_RU
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_RU)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "Операция выполнена успешно.")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "Неожиданная внутренняя ошибка.")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "Ошибочный параметр при внутреннем вызове функции клиентского терминала.")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "Ошибочный параметр при вызове системной функции.")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "Недостаточно памяти для выполнения системной функции.")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "Структура содержит объекты строк и/или динамических массивов и/или структуры с такими объектами и/или классы.")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "Массив неподходящего типа, неподходящего размера или испорченный объект динамического массива.")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "Недостаточно памяти для перераспределения массива либо попытка изменения размера статического массива.")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "Недостаточно памяти для перераспределения строки.")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "Неинициализированная строка.")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "Неправильное значение даты и/или времени.")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "Общее число элементов в массиве не может превышать 2147483647.")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "Ошибочный указатель.")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "Ошибочный тип указателя.")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "Системная функция не разрешена для вызова.")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "Совпадение имени динамического и статического ресурсов.")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "Ресурс с таким именем в EX5 не найден.")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "Неподдерживаемый тип ресурса или размер более 16 MB.")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "Имя ресурса превышает 63 символа.")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "При вычислении математической функции произошло переполнение.")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Выход за дату окончания тестирования после вызова Sleep().")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                      "ERR_PROGRAM_STOPPED",                     "Тестирование было прекращено принудительно извне. Например, прервана оптимизацию, или закрыто окно визуального тестирования, или остановлен агент тестирования.")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "Ошибочный идентификатор графика.")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "График не отвечает.")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "График не найден.")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "У графика нет эксперта, который мог бы обработать событие.")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "Ошибка открытия графика.")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "Ошибка при изменении для графика символа и периода.")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "Ошибочное значение параметра для функции по работе с графиком.")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "Ошибка при создании таймера.")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "Ошибочный идентификатор свойства графика.")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "Ошибка при создании скриншота.")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "Ошибка навигации по графику.")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "Ошибка при применении шаблона.")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "Подокно, содержащее указанный индикатор, не найдено.")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "Ошибка при добавлении индикатора на график.")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "Ошибка при удалении индикатора с графика.")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "Индикатор не найден на указанном графике.")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "Ошибка при работе с графическим объектом.")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "Графический объект не найден.")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "Ошибочный идентификатор свойства графического объекта.")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "Невозможно получить дату, соответствующую значению.")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "Невозможно получить значение, соответствующее дате.")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "Неизвестный символ.")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "Символ не выбран в MarketWatch.")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "Ошибочный идентификатор свойства символа.")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "Время последнего тика неизвестно (тиков не было).")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "Ошибка добавления или удаления символа в MarketWatch.")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "Запрашиваемая история не найдена.")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "Ошибочный идентификатор свойства истории.")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "Превышен таймаут при запросе истории.")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "Количество запрашиваемых баров ограничено настройками терминала.")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "Множество ошибок при загрузке истории.")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "Принимающий массив слишком мал чтобы вместить все запрошенные данные.")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "Глобальная переменная клиентского терминала не найдена.")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "Глобальная переменная клиентского терминала с таким именем уже существует.")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "Не было модификаций глобальных переменных.")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "Не удалось открыть и прочитать файл со значениями глобальных переменных.")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "Не удалось записать файл со значениями глобальных переменных.")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "Не удалось отправить письмо.")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "Не удалось воспроизвести звук.")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "Ошибочный идентификатор свойства программы.")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "Ошибочный идентификатор свойства терминала.")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "Не удалось отправить файл по ftp.")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "Не удалось отправить уведомление.")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "Неверный параметр для отправки уведомления – в функцию SendNotification()  передали пустую строку или NULL.")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "Неверные настройки уведомлений в терминале (не указан ID или не выставлено разрешение).")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "Слишком частая отправка уведомлений.")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "Не указан FTP сервер.")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "Не указан FTP логин.")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "Не найден файл в директории MQL5\\Files для отправки на FTP сервер.")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "Ошибка при подключении к FTP серверу.")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "На FTP сервере не найдена директория для выгрузки файла.")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "Подключение к FTP серверу закрыто.")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "Недостаточно памяти для распределения индикаторных буферов.")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "Ошибочный индекс своего индикаторного буфера.")


        // Custom Indicator Properties

            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "Ошибочный идентификатор свойства пользовательского индикатора.")


        // Account

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "Ошибочный идентификатор свойства счета.")
            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "Ошибочный идентификатор свойства торговли.")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "Торговля для эксперта запрещена.")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "Позиция не найдена.")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "Ордер не найден.")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "Сделка не найдена.")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "Не удалось отправить торговый запрос.")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "Не удалось вычислить значение прибыли или маржи.")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "Неизвестный символ.")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "Индикатор не может быть создан.")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "Недостаточно памяти для добавления индикатора.")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "Индикатор не может быть применен к другому индикатору.")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "Ошибка при добавлении индикатора.")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "Запрошенные данные не найдены.")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "Ошибочный хэндл индикатора.")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "Неправильное количество параметров при создании индикатора.")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "Отсутствуют параметры при создании индикатора.")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "Первым параметром в массиве должно быть имя пользовательского индикатора.")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "Неправильный тип параметра в массиве при создании индикатора.")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "Ошибочный индекс запрашиваемого индикаторного буфера.")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "Стакан цен не может быть добавлен.")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "Стакан цен не может быть удален.")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "Данные стакана цен не могут быть получены.")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "Ошибка при подписке на получение новых данных стакана цен.")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "Не может быть открыто одновременно более 64 файлов.")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "Недопустимое имя файла.")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "Слишком длинное имя файла.")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "Ошибка открытия файла.")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "Недостаточно памяти для кеша чтения.")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "Ошибка удаления файла.")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "Файл с таким хэндлом уже был закрыт, либо не открывался вообще.")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "Ошибочный хэндл файла.")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "Файл должен быть открыт для записи.")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "Файл должен быть открыт для чтения.")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "Файл должен быть открыт как бинарный.")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "Файл должен быть открыт как текстовый.")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "Файл должен быть открыт как текстовый или CSV.")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "Файл должен быть открыт как CSV.")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "Ошибка чтения файла.")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "Должен быть указан размер строки, так как файл открыт как бинарный.")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "Для строковых массивов должен быть текстовый файл, для остальных – бинарный.")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "Это не файл, а директория.")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "Файл не существует.")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "Файл не может быть переписан.")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "Ошибочное имя директории.")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "Директория не существует.")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "Это файл, а не директория.")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "Директория не может быть удалена.")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "Не удалось очистить директорию (возможно, один или несколько файлов заблокированы и операция удаления не удалась).")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "Не удалось записать ресурс в файл.")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "Не удалось прочитать следующую порцию данных из CSV-файла (FileReadString, FileReadNumber, FileReadDatetime, FileReadBool), так как достигнут конец файла.")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "В строке нет даты.")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "В строке ошибочная дата.")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "В строке ошибочное время.")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "Ошибка преобразования строки в дату.")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "Недостаточно памяти для строки.")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "Длина строки меньше, чем ожидалось.")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "Слишком большое число, больше, чем ULONG_MAX.")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "Ошибочная форматная строка.")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "Форматных спецификаторов больше, чем параметров.")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "Параметров больше, чем форматных спецификаторов.")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "Испорченный параметр типа string.")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "Позиция за пределами строки.")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "К концу строки добавлен 0, бесполезная операция.")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "Неизвестный тип данных при конвертации в строку.")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "Испорченный объект строки.")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "Копирование несовместимых массивов. Строковый массив может быть скопирован только в строковый, а числовой массив – в числовой.")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "Приемный массив объявлен как AS_SERIES, и он недостаточного размера.")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "Слишком маленький массив, стартовая позиция за пределами массива.")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "Массив нулевой длины.")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "Должен быть числовой массив.")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "Должен быть одномерный массив.")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "Таймсерия не может быть использована.")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "Должен быть массив типа double.")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "Должен быть массив типа float.")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "Должен быть массив типа long.")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "Должен быть массив типа int.")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "Должен быть массив типа short.")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "Должен быть массив типа char.")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "Должен быть массив типа string.")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "Функции OpenCL на данном компьютере не поддерживаются.")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "Внутренняя ошибка при выполнении OpenCL.")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "Неправильный хэндл OpenCL.")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "Ошибка при создании контекста OpenCL.")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "Ошибка создания очереди выполнения в OpenCL.")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "Ошибка при компиляции программы OpenCL.")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "Слишком длинное имя точки входа (кернел OpenCL).")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "Ошибка создания кернел - точки входа OpenCL.")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "Ошибка при установке параметров для кернел OpenCL (точки входа в программу OpenCL).")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "Ошибка выполнения программы OpenCL.")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "Неверный размер буфера OpenCL.")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "Неверное смещение в буфере OpenCL.")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "Ошибка создания буфера OpenCL.")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "Превышено максимальное число OpenCL объектов.")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "Ошибка выбора OpenCL устройства.")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "Внутренняя ошибка базы данных.")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "Невалидный хендл базы данных.")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "Превышено максимально допустимое количество объектов Database.")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "Ошибка подключения к базе данных.")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "Ошибка выполнения запроса.")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "Ошибка создания запроса.")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "Данных для чтения больше нет.")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "Ошибка перехода к следующей записи запроса.")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "Данные для чтения результатов запроса еще не готовы.")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "Ошибка автоподстановки параметров в SQL-запрос.")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "URL не прошел проверку.")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "Не удалось подключиться к указанному URL.")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "Превышен таймаут получения данных.")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "Ошибка в результате выполнения HTTP запроса.")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "В функцию передан неверный хэндл сокета.")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "Открыто слишком много сокетов (максимум 128).")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "Ошибка соединения с удаленным хостом.")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "Ошибка отправки/получения данных из сокета.")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "Ошибка установления защищенного соединения (TLS Handshake).")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "Отсутствуют данные о сертификате, которым защищено подключение.")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "Должен быть указан пользовательский символ.")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "Некорректное имя пользовательского символа. В имени символа можно использовать только латинские буквы без знаков препинания, пробелов и спецсимволов (допускаются '.', '_', '&' и '#'). Не рекомендуется использовать символы <, >, :, \", /,\\, |, ?, *..")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "Слишком длинное имя для пользовательского символа. Длина имени символа не должна превышать 32 знака с учётом завершающего 0.")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "Слишком длинный путь для пользовательского символа. Длина пути не более 128 знаков с учётом 'Custom\\\\', имени символа, разделителей групп и завершающего 0.")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "Пользовательский символ с таким именем уже существует.")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "Ошибка при создании, удалении или изменении пользовательского символа.")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "Попытка удалить пользовательский символ, выбранный в обзоре рынка (Market Watch).")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "Неправильное свойство пользовательского символа.")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "Ошибочный параметр при установке свойства пользовательского символа.")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "Слишком длинный строковый параметр при установке свойства пользовательского символа.")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "Не упорядоченный по времени массив тиков.")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "Размер массива недостаточен для получения описаний всех значений.")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "Превышен лимит запроса по времени.")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "Страна не найдена.")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "Общая ошибка.")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "Внутренняя логическая ошибка в SQLite.")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "Отказано в доступе.")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "Процедура обратного вызова запросила прерывание.")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "Файл базы данных заблокирован.")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "Таблица в базе данных заблокирована.")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "Сбой malloc ().")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "Попытка записи в базу данных, доступной только для чтения.")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "Операция прекращена с помощью sqlite3_interrupt ().")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "Ошибка дискового ввода-вывода.")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "Образ диска базы данных испорчен.")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "Неизвестный код операции в sqlite3_file_control ().")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "Ошибка вставки, так как база данных заполнена.")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "Невозможно открыть файл базы данных.")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "Ошибка протокола блокировки базы данных.")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "Только для внутреннего использования.")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "Схема базы данных изменена.")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "Строка или BLOB превышает ограничение по размеру.")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "Прервано из-за нарушения ограничения.")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "Несоответствие типов данных.")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "Ошибка неправильного использования библиотеки.")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "Использование функций операционной системы, не поддерживаемых на хосте.")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "Отказано в авторизации.")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "Не используется.")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "2-й параметр для sqlite3_bind находится вне диапазона.")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "Открытый файл не является файлом базы данных.")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "Реквота.")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "Запрос отклонен.")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "Запрос отменен трейдером.")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "Ордер размещен.")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "Заявка выполнена.")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "Заявка выполнена частично.")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "Ошибка обработки запроса.")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "Запрос отменен по истечению времени.")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "Неправильный запрос.")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "Неправильный объем в запросе.")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "Неправильная цена в запросе.")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "Неправильные стопы в запросе.")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "Торговля запрещена.")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "Рынок закрыт.")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "Нет достаточных денежных средств для выполнения запроса.")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "Цены изменились.")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "Отсутствуют котировки для обработки запроса.")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "Неверная дата истечения ордера в запросе.")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "Состояние ордера изменилось.")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "Слишком частые запросы.")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "В запросе нет изменений.")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "Автотрейдинг запрещен сервером.")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "Автотрейдинг запрещен клиентским терминалом.")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "Запрос заблокирован для обработки.")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "Ордер или позиция заморожены.")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "Указан неподдерживаемый тип исполнения ордера по остатку.")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "Нет соединения с торговым сервером.")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "Операция разрешена только для реальных счетов.")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "Достигнут лимит на количество отложенных ордеров.")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "Достигнут лимит на объем ордеров и позиций для данного символа.")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "Неверный или запрещённый тип ордера.")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "Позиция с указанным POSITION_IDENTIFIER уже закрыта.")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "Закрываемый объем превышает текущий объем позиции.")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "Для указанной позиции уже есть ордер на закрытие. Может возникнуть при работе в системе хеджинга: \r\nпри попытке закрытия позиции встречной, если уже есть ордера на закрытие этой позиции \r\nпри попытке полного или частичного закрытия, если суммарный объем уже имеющихся ордеров на закрытие и вновь выставляемого ордера превышает текущий объем позиции.")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "Количество открытых позиций, которое можно одновременно иметь на счете, может быть ограничено настройками сервера. При достижении лимита в ответ на выставление ордера сервер вернет ошибку TRADE_RETCODE_LIMIT_POSITIONS. Ограничение работает по-разному в зависимости от типа учета позиций на счете: \r\nНеттинговая система — учитывается количество открытых позиции. При достижении лимита платформа не позволит выставлять новые ордера, в результате исполнения которых может увеличиться количество открытых позиций. Фактически, платформа позволит выставлять ордера только по тем символам, по которым уже есть открытые позиции. В неттинговой системе при проверке лимита не учитываются текущие отложенные ордера, поскольку их исполнение может привести к изменению текущих позиций, а не увеличению их количества. \r\nХеджинговая система — помимо открытых позиций, учитываются выставленные отложенные ордера, поскольку их срабатывание всегда приводит к открытию новой позиции. При достижении лимита платформа не позволит выставлять рыночные ордера на открытие позиций, а также отложенные ордера.")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "Запрос на активацию отложенного ордера отклонен, а сам ордер отменен.")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "Запрос отклонен, так как на символе установлено правило 'Разрешены только длинные позиции'  (POSITION_TYPE_BUY).")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "Запрос отклонен, так как на символе установлено правило 'Разрешены только короткие позиции' (POSITION_TYPE_SELL).")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "Запрос отклонен, так как на символе установлено правило 'Разрешено только закрывать существующие позиции'.")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "Запрос отклонен, так как для торгового счета установлено правило 'Разрешено закрывать существующие позиции только по правилу FIFO' (ACCOUNT_FIFO_CLOSE=true).")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "Запрос отклонен, так как для торгового счета установлено правило 'Запрещено открывать встречные позиции по одному символу'. Например, если на счете имеется позиция Buy, то пользователь не может открыть позицию Sell или выставить отложенный ордер на продажу. Правило может применяться только на счетах с хеджинговой системой учета (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING).")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
};
#endif


// Language specific error code resolver (chinese)
#ifdef LIB_ERROR_LANG_TERM_ID_ZH
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_ZH)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "操作成功完成")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "意外内部错误")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "客户端函数内部调用的错误参数")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "当调用系统函数时的错误参量")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "没有足够空间执行系统函数")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "结构包括字符串和/或动态数组和/或结构对象和/或分类")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "数组错误类型，错误大小，或者动态数组的损害对象")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "数组没有足够空间重置，或者没有能够改变静态数组的大小")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "没有足够内存重置字符串")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "没有初始化字符串")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "无效日期和/时间")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "数组中的元素总数不能超过 2147483647")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "错误指针")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "错误指针类型")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "系统函数不允许调用")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "动态 和 静态 resource匹配的名称")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "该名称的resource在EX5没有找到")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "不支持的resource类型或其大小超过 16 Mb")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "resource名称超过 63 个字符")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "计算数学函数时产生的溢值")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "调用Sleep()后超过测试截止日期")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                      "ERR_PROGRAM_STOPPED",                     "测试从外部强行停止。例如，优化中断、可视化测试窗口关闭或测试代理停止")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "错误图表ID")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "图表不能回应")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "图表未发现")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "图表中没有EA交易可以处理事件")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "图表打开错误")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "改变图表交易品种或周期失败")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "图表使用函数 的错误参数值")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "增加定时器失败")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "错误图表属性ID")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "错误生成截屏")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "错误操作图表")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "错误申请模板")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "未找到窗口包含的指标")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "错误添加指标到图表")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "删除图表指标的错误")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "指定图表上未发现指标")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "图解对象的误差")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "未发现图解对象")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "图解对象属性的错误ID")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "不能与值相一致获得日期")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "不能与日期相一致获得值")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "未知交易品种")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "市场报价中未被挑选出来的交易品种")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "交易品种属性的错误标识符")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "时间的最后标志未识别（无标志）")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "在市场报价中添加或删除交易品种的错误")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "需求历史未找到")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "历史属性的错误ID")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "历史请求超时过多")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "请求柱的数量受到程序端设置的限制")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "加载历史时发生多个错误")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "接受数组太小，无法存储所有请求数据")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "客户端全局变量未找到")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "相同名称客户端全局变量已经存在")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "全局变量未被修改")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "无法通过全局变量值读取文件")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "无法通过全局变量值编写文件")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "发送邮件失败")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "声音播放失败")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "程序属性错误标识符")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "客户端属性错误标识符")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "通过ftp发送文件失败")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "发送 通知 失败")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "发送通知的无效参数 – 空字符串或 NULL 被传递到 SendNotification() 函数")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "错误的程序端通知设置（未指定ID或未设置权限）")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "发送通知过于频繁")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "未指定FTP 服务器")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "未指定FTP登录名")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "在MQL5\\Files目录未找到发送至FTP服务器的文件")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "FTP 连接失败")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "在服务器上未找到FTP路径")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "FTP 连接关闭")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "没有足够内存建立指标缓冲区")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "错误指标缓冲区索引")


        // Custom Indicator Properties

            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "自定义指标的错误ID")


        // Account

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "错误账户属性ID")
            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "错误交易属性ID")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "EA交易禁止交易")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "未找到位置")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "未找到命令")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "未找到订单")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "交易需求发送失败")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "计算利润或预付款失败")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "未知交易品种")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "不能创建指标")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "没有足够内存添加指标")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "指标不能适应另一指标")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "错误申请指标到图表")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "需求数据未找到")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "错误指标处理")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "当建立指标时使用的错误参量数")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "当建立指标时没有参量")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "在数组中的第一参量一定与自定义指标相同")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "当建立指标时，数组中无效参量类型")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "错误索引需求的指标缓冲区")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "不能添加市场深度")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "不能移动市场深度")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "深度市场数据未获得")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "从市场深度接收新数据时出错")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "不能同时打开超过64个文件")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "无效文件名")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "太长文件名")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "文件打开错误")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "没有足够内存隐藏阅读")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "文件删除错误")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "文件处理关闭，或者根本没打开")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "错误文件处理")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "文件必须打开编辑")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "文件必须打开阅读")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "文件必须以二进制打开")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "文件必须以文本形式打开")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "文件必须以文本或者CSV打开")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "文件必须以CSV格式打开")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "文件阅读错误")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "字符串大小必须制定，因为文件以二进制打开")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "文本文件必须以字符串数组打开，或其他数组-二进制")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "没有文件，只有目录")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "文件不存在")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "文件不能重写")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "错误目录名称")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "目录不存在")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "只有文件，没有目录")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "目录不能更改")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "清除目录失败（或许一个或多个文件阻塞因而操作失败）")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "将 resource 写入文件失败")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "已到文件末端，不能阅读CSV文件的下一块数据（FileReadString， FileReadNumber，FileReadDatetime，FileReadBool）")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "字符串无日期")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "字符串错误日期")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "字符串错误时间")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "错误转变字符串到日期")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "没有足够空间建立字符串")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "字符串太短")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "太多数组，比ULONG_MAX多")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "无效格式字符串")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "格式说明符数量比参量多")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "参量数多于格式说明符")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "字符串类型破坏参量")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "字符串外部位置")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "字符串末尾添加0，无用操作")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "当转换字符串时的未知数据类型")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "破坏字符串对象")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "复制不兼容数组，字符串数组只能复制成字符串数组，和数字数组-只在数字数组中")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "以AS_SERIES形式接收数据，不够大")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "太小数组，启动位置在数组外")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "0长度数组")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "一定是数字数组")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "一定是一维数组")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "不能使用时序列")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "必须是双精度类型数组")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "必须是浮点型数组")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "必须是长型数组")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "必须是整型数组")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "必须是短型数组")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "必须是图表型数据")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "仅字符串数组")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "该计算机不支持OpenCL 函数")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "运行 OpenCL 时发生的内部错误")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "无效的 OpenCL 句柄")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "创建 OpenCL 语境 的错误")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "在OpenCL创建运行队列失败")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "编译 OpenCL 程序 时发生的错误")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "过长的内核名称 (OpenCL kernel)")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "创建 OpenCL kernel 的错误")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "当为OpenCL kernel设置参数 时发生的错误")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "OpenCL 程序 运行时间错误")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "无效的 OpenCL 缓存大小")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "无效的 OpenCL 缓存补偿")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "创建 OpenCL 缓存 失败")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "OpenCL 对象过多")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "OpenCL 设备选择错误")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "内部数据库错误")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "无效数据库句柄")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "超出数据库对象的最大可接受数量")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "数据库连接错误")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "请求执行错误")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "请求生成错误")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "无需再读取数据")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "无法移动到下一个请求条目")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "读取请求结果的数据尚未准备好")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "无法自动将参数替换为SQL请求")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "无效 URL")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "连接指定URL失败")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "超时")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "HTTP 请求失败")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "传递给函数的套接句柄无效")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "打开的套接太多（最多128）")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "连接远程主机失败")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "发送数据/从套接接收数据失败")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "建立安全连接失败(TLS Handshake)")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "在保护连接的证书上没有数据")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "必须指定一个自定义交易品种")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "自定义交易品种名称无效。交易品种名称只能包含拉丁字母不可含有标点符号，空格或特殊字符（仅可以包含'.'，'_'，'&' 和 '#'符号）。不建议使用下列字符<，>，:，\"，/，\\，|，?，*。")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "自定义交易品种的名称过长。交易品种名称的总长度不可超过32个字符，包括末位的0字符")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "自定义交易品种的路径过长。路径长度不应超过128个字符，包括'Custom\\\\'，交易品种名称，组分隔符和末位的0字符")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "已存在同名的自定义交易品种")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "创建，删除或更改自定义交易品种时出现错误")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "您正在试图删除市场报价中选定的自定义交易品种")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "无效的自定义交易品种属性")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "设置自定义交易品种属性时的错误参数")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "设置自定义交易品种属性时过长的字符串参数")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "数组中的报价未按时间顺序排列")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "数组大小不足以接收所有值的描述")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "超过请求时限")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "国家未找到")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "通用错误")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "SQLite内部逻辑错误")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "拒绝访问")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "回调程序请求中止")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "数据库文件锁定")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "数据库表格锁定")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "内存不足，无法完成操作")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "尝试写入只读数据库")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "sqlite3_interrupt()终止操作")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "磁盘I/O错误")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "数据库磁盘映像损坏")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "sqlite3_file_control()中的未知操作代码")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "数据库已满，插入失败")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "无法打开数据库文件")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "数据库锁定协议错误")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "仅供内部使用")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "数据库架构改变")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "字符串或BLOB超出大小限制")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "由于违反约束而中止")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "数据类型不匹配")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "程序库使用错误")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "使用主机上不支持的OS功能")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "授权失败")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "未使用")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "绑定参数错误，索引不正确")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "打开的文件不是数据库文件")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "报价请求")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "拒绝请求")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "交易者取消请求")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "安置命令")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "完成要求")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "请求部分完成")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "请求处理错误")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "超时取消请求")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "无效请求")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "请求中无效成交量")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "请求中的无效价格")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "请求中的无效访问")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "关闭交易")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "收市")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "没有足够的钱实现请求")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "改变价格")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "没有报价处理请求")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "请求中的无效命令截止日期")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "改变命令状态")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "太频繁的请求")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "不改变请求")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "服务器无效自动交易")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "客户端无效自动交易")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "处理锁住请求")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "命令或安置冻结")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "无效命令填满字节")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "与服务器无连接")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "只在流水账允许操作")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "待办订单数量达到限制")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "订单成交量和交易品种位置达到限制")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "错误或禁止的 订单类型")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "指定 POSITION_IDENTIFIER的持仓已经被关闭")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "平仓交易量超出当前持仓交易量")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "指定持仓已存在平仓订单。这可能在锁仓系统工作时出现： \r\n如果持仓的平仓订单已经存在，试图反向平仓 \r\n如果已有平仓订单和新下单的总交易量超出了当前持仓交易量，试图完全或部分平仓")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "同时存在于账户中的持仓数量可以通过服务器的设置来限定。达到限定数以后，当再尝试下单时服务器会返回TRADE_RETCODE_LIMIT_POSITIONS错误。限定操作的差异取决于账户持仓类型： \r\n单边持仓 ― 考虑持仓数。达到限定时，平台禁止可能增加持仓数的新下单行为。实际上，平台仅允许下单已有持仓的交易品种。由于执行挂单可能导致当前持仓变化但不会增加持仓数，所以不会考虑当前挂单。 \r\n锁仓持仓 ― 同时考虑持仓和挂单，因为激活挂单经常意味着一个新的持仓。当限定达到时，平台禁止下可以持仓和挂单的新市场订单。")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "挂单激活请求被拒绝，订单被取消")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "因为交易品种(POSITION_TYPE_BUY)设置了'只允许买入持仓'的规则，所以请求被拒绝")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "因为交易品种 (POSITION_TYPE_SELL)设置了'只允许卖出持仓'的规则，所以请求被拒绝")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "因为交易品种设置了'只允许平仓'的规则，所以请求被拒绝")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "请求被拒绝，因为已为交易账户设置了“仅允许通过FIFO规则平仓”标识(ACCOUNT_FIFO_CLOSE=true)")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "请求被拒绝，因为该交易账户设置了“禁用单个交易品种的反向持仓”规则。例如，如果该账户是Buy持仓，那么用户就不能建立Sell持仓或下单卖出挂单。该规则仅适用于使用锁仓账户系统的账户 (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING)。")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
};
#endif


// Language specific error code resolver (japanese)
#ifdef LIB_ERROR_LANG_TERM_ID_JP
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_JP)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "操作が正常に完了しました。")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "予期しない内部エラー。")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "クライアント端末関数の内部呼び出しでの不正なパラメータ。")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "システム関数呼び出し時の不正なパラメータ。")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "システム関数の実行に不充分なメモリ。")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "構造体に、文字列、及び/または動的な配列及び/またはそのようなオブジェクトの構造体及び/またはクラスが含まれます。")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "型やサイズが不正な配列、または動的配列内に損傷を受けたオブジェクト。")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "配列の移転に不充分なメモリ、または静的配列のサイズを変更する試み。")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "文字列の再配置に不充分なメモリ。")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "初期化されていない文字列。")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "無効な日付/時刻。")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "配列の要素数の合計は 2,147,483,647を超えることは出来ません。")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "不正なポインタ。")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "不正なポインタ型。")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "関数呼び出しの許可がありません。")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "同一の動的及び静的リソース名。")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "この名称のリソースがEX5で見つかりません。")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "リソースタイプがサポートされていないかサイズが 16 MB を超えます。")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "リソース名が 63 字を超えます。")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "数学関数の計算時にオーバーフローが発生")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Sleep()呼び出しが終了日より後です。")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                      "ERR_PROGRAM_STOPPED",                     "テストは外部から強制停止されました。例は、最適化の中断、視覚的テストウィンドウの終了、テストエージェントの停止です。")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "不正なチャート識別子。")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "チャートが応答しません。")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "チャートが見つかりません。")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "イベントを処理出来るエキスパートアドバイザーがチャートに不在。")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "チャートオープンエラー。")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "銘柄と期間の変更に失敗。")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "チャート操作の関数のパラメータ値のエラー。")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "タイマー作成に失敗。")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "不正なチャートプロパティ識別子。")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "スクリーンショット作成エラー。")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "チャートナビゲートエラー。")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "テンプレート適用エラー。")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "指標を含むサブウィンドウが不在。")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "指標をチャートに追加するのに失敗。")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "指標をチャートから削除するのに失敗。")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "指標が指定されたチャートに不在。")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "グラフィックオブジェクト操作エラー。")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "グラフィックオブジェクトが見つかりません。")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "グラフィックオブジェクトプロパティの不正な ID。")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "値に対応する日付の取得が不可能。")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "日付に対応する値の取得が不可能。")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "未知のシンボル。")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "「気配値表示」でシンボルが未選択。")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "シンボルプロパティの不正な識別子。")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "最後のティックの時間が未知（ティック不在）。")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "「気配値表示」のシンボル追加・削除に失敗。")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "リクエストされた履歴が見つかりません。")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "不正な履歴プロパティ識別子。")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "履歴リクエストがタイムアウトしました。")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "要求されたバーの数が端末の設定によって制限されています。")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "履歴を読み込む際に複数のエラーが生成されました。")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "受信する配列が小さすぎて、リクエストされたすべてのデータを格納できません。")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "クライアント端末のグローバル変数が見つかりません。")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "同名のクライアント端末のグローバル変数が既存。")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "グローバル変数が変更されていない")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "グローバル変数値を持つファイルの読み取りが不可能")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "グローバル変数値を持つファイルの書き込みが不可能")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "メール送信に失敗。")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "音の再生に失敗。")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "プログラムプロパティの不正な識別子。")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "端末プロパティの不正な識別子。")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "FTP でのファイル送信に失敗。")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "通知送信に失敗。")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "通知送信に無効なパラメータ（空の文字列か NULL ）が SendNotification() 関数に渡されました。")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "端末内の不正な通知の設定（IDの未指定か、許可の無設定）。")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "頻繁過ぎる通知の送信。")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "FTPサーバが指定されていません。")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "FTPログインが指定されていません。")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "FTPサーバに送信するファイルがMQL5\\Filesディレクトリで見つかりません。")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "FTP接続に失敗しました。")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "サーバでFTPパスが見つかりません。")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "FTP接続が閉じられました。")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "指標バッファ配布に不充分なメモリ。")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "不正な指標バッファインデックス。")


        // Custom Indicator Properties

            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "不正なカスタム指標プロパティ識別子。")


        // Account

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "不正な口座プロパティ識別子。")
            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "不正な取引プロパティ識別子。")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "エキスパートアドバイザーでの取引が許可されていません。")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "ポジションが見つかりません。")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "注文が見つかりません。")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "約定が見つかりません。")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "取引リクエスト送信に失敗。")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "利益または証拠金の計算に失敗")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "未知のシンボル。")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "指標作成が不可。")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "指標追加に不充分なメモリ。")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "指標の他の指標への適用は不可。")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "指標をチャートに適用するのに失敗。")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "リクエストされたデータが見つかりません。")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "不正な指標ハンドル。")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "指標作成時の不正なパラメータ数。")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "指標作成時にパラメータ型が不在。")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "配列の最初のパラメータは、カスタム指標の名称でなければなりません。")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "指標作成時の配列内の無効なパラメータ型。")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "リクエストされた指標バッファの不正なインデックス。")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "板情報の追加が不可能。")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "板情報の削除が不可能。")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "板情報データ取得が不可能。")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "板情報から新規データを取得するのにサブスクライブ中にエラーが発生。")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "64 を超えるファイルを同時に開く事は不可能。")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "無効なファイル名。")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "長すぎるファイル名。")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "ファイルオープンエラー。")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "読み込みのためにキャッシュに出来るメモリが不足。")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "ファイル削除エラー。")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "このハンドルを使用したファイルは閉じられた、または、初めから開けられませんでした。")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "不正なファイルハンドル。")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "ファイルは書き込むために開かれる必要があります。")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "ファイルは読み込むために開かれる必要があります。")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "ファイルはバイナリとして開かれる必要があります。")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "ファイルはテキストとして開かれる必要があります。")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "ファイルはテキストまたは CSV として開かれる必要があります。")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "ファイルは CSV として開かれる必要があります。")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "ファイル読み込みエラー。")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "ファイルがバイナリとしてオープンされたため、文字列のサイズ指定が必要。")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "文字列配列はテキストファイル、他の配列は バイナリファイルでなければいけません。")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "これはファイルではなくディレクトリです。")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "ファイルが不在。")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "ファイルの書き換えが不可。")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "不正なディレクトリ名。")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "ディレクトリ不在。")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "これはディレクトリではなくファイルです。")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "ディレクトリを削除に失敗。")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "ディレクトリのクリアに失敗（おそらく1つ以上のファイルがブロックされ、除去操作が失敗）。")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "ファイルへのリソースの書き込みに失敗。")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "ファイルの終わりに達する為、CSVファイル(FileReadString、FileReadNumber、FileReadDatetime、FileReadBool)から次のデータを読み取ることができませんでした。")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "文字列内に日付なし。")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "文字列で不正な日付。")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "文字列内の不正な時刻。")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "文字列から日付への変換エラー。")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "文字列に不充分なメモリ。")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "予想より短い文字列。")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "大きすぎて ULONG_MAX を超える数。")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "無効なフォーマットストリング。")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "フォーマット指定子数がパラメータ数を超過。")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "パラメータ数がフォーマット指定子数を超過。")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "損傷した文字列型のパラメータ。")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "位置が文字列の範囲外。")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "文字列の末尾に 0 が追加されました（無効な操作）。")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "文字列への変換時の未知なデータ型。")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "破損した文字列オブジェクト。")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "互換性のない配列の複製。文字列配列は文字列配列、数値配列は数値配列のみに複製することが出来ます。")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "受け取り側の配列は AS_SERIES として宣言されていて、サイズが不充分です。")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "配列が小さすぎ、開始位置が配列の外側にあります。")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "長さゼロの配列。")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "数値配列のみ可。")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "1 次元配列のみが可。")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "時系列は使用不可。")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "double 型の配列のみ可。")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "float 型の配列のみ可。")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "long 型の配列のみ可。")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "int 型の配列のみ可。")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "short 型の配列のみ可。")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "char 型の配列のみ可。")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "文字列配列のみ")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "OpenCL 関数がこのコンピューターでサポートされていません。")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "OpenCL実行中中に内部エラー発生。")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "無効なOpenCL ハンドル。")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "OpenCL コンテキスト作成に失敗。")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "OpenCL の実行キューの作成に失敗。")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "OpenCL プログラムのコンパイル中にエラー発生。")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "カーネル名が長すぎます(OpenCL カーネル)。")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "OpenCL カーネル作成エラー。")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "OpenCL カーネルパラメータ設定中にエラー発生。")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "OpenCL プログラムランタイムエラー。")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "OpenCL バッファの無効なサイズ。")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "OpenCL バッファ内の無効なオフセット。")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "OpenCL バッファの作成に失敗。")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "OpenCLオブジェクトが多すぎる")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "OpenCLデバイス選択エラー")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "内部データベースエラー")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "無効なデータベースハンドル")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "Databaseオブジェクトの最大数を超えました")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "データベース接続エラー")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "要求実行エラー")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "要求生成エラー")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "読み込むデータがありません")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "次の要求エントリに移動できませんでした")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "要求結果を読み取るためのデータはまだ準備できていません")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "SQL要求へのパラメーターの自動置換に失敗しました")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "無効な URL。")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "指定された URL への接続に失敗。")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "タイムアウトを超過。")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "HTTP リクエストに失敗。")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "関数に無効なソケットハンドルが渡されました。")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "開いているソケットが多すぎます(最高128)。")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "遠隔ホストに接続できません。")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "ソケットからデータを送受信できません。")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "安全な接続を確立できません(TLSハンドシェイク)。")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "接続を保護する証明書に関するデータがありません。")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "カスタムシンボルが指定されていません。")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "カスタムシンボル名が無効です。シンボル名には、句読点、スペース、特殊文字以外のラテン文字を含めることができます（'.'、 '_'、 '&' 、'#'は可）。<、>、 :、\"、 /、\\、|、?、*の使用は推奨されていません。")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "カスタムシンボル名が長すぎます。シンボル名の長さは、末尾の0文字を含んで32文字を超えてはなりません。")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "カスタムシンボルのパスが長すぎます。パスの長さは'Custom\\\\'、シンボル名、グループセパレータ、および末尾の0を含んで128文字を超えてはなりません。")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "同じ名称のカスタムシンボルが既存。")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "カスタムシンボルの作成、削除または変更中にエラーが発生。")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "板情報で選択されたカスタムシンボルを削除しようとしています。")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "カスタムシンボルプロパティが無効。")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "カスタムシンボルのプロパティを設定している際のパラメータが不正。")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "カスタムシンボルのプロパティを設定する際に文字列パラメータが長すぎます。")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "配列内のティックが時間順でありません")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "配列サイズがすべての値の説明を受け取るには不十分です")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "リクエストの制限時間を超えました")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "国が見つかりません")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "一般的なエラー")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "SQLite内部ロジックエラー")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "アクセスが拒否されました")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "コールバックルーチンが中止を要求しました")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "データベースファイルがロックされています")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "データベーステーブルがロックされています<分節 2781")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "操作を完了するためのメモリが不足しています")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "読み取り専用データベースへの書き込みが試みされました")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "操作がsqlite3_interrupt()によって終了されました")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "ディスクI/Oエラー")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "データベースディスクイメージが破損しています")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "sqlite3_file_control()に不明な操作コードがあります")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "データベースがいっぱいのため、挿入に失敗しました")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "データベースファイルを開くことができません")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "データベースロックプロトコルエラー")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "内部使用のみ")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "データベーススキーマが変更されました")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "文字列またはBLOBがサイズ制限を超えています")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "制約違反による中止")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "データ型の不一致")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "ライブラリが正しく使用されていません")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "ホストでサポートされていないOS機能を使用しています")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "承認が拒否されました")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "未使用")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "バインドパラメータエラー、不正なインデックス")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "データベースファイルではないファイルが開かれました")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "リクオート。")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "リクエストの拒否。")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "トレーダーによるリクエストのキャンセル。")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "注文が出されました。")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "リクエスト完了。")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "リクエストが一部のみ完了。")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "リクエスト処理エラー。")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "リクエストが時間切れでキャンセル。")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "無効なリクエスト。")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "リクエスト内の無効なボリューム。")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "リクエスト内の無効な価格。")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "リクエスト内の無効なストップ。")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "取引が無効化されています。")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "市場が閉鎖中。")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "リクエストを完了するのに資金が不充分。")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "価格変更。")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "リクエスト処理に必要な相場が不在。")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "リクエスト内の無効な注文有効期限。")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "注文状態の変化。")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "頻繁過ぎるリクエスト。")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "リクエストに変更なし。")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "サーバが自動取引を無効化。")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "クライアント端末が自動取引を無効化。")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "リクエストが処理のためにロック中。")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "注文やポジションが凍結。")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "無効な注文充填タイプ。")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "取引サーバに未接続。")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "操作は、ライブ口座のみで許可。")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "未決注文の数が上限に達しました。")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "シンボルの注文やポジションのボリュームが限界に達しました。")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "不正または禁止された注文の種類。")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "指定されたPOSITION_IDENTIFIER を持つポジションがすでに閉鎖。")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "決済ボリュームが現在のポジションのボリュームを超過。")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "指定されたポジションの決済注文が既存。これは、ヘッジシステムでの作業中に発生する可能性があります。\r\n反対のポジションを決済しようとしているときにそのポジションの決済注文が既に存在している場合\r\nポジションを完全または部分的に決済しようとしているときに既存する決済注文と新しく出された決済注文の合計が現在のポジションボリュームを超えている場合")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "アカウントに同時に存在するポジションの数は、サーバー設定によって制限されます。 限度に達すると、サーバーは出された注文を処理するときにTRADE_RETCODE_LIMIT_POSITIONSエラーを返します。 これは、ポジション会計タイプによって異なる動作につながります。\r\nネッティング - ポジションの数が考慮されます。 限度に達すると、プラットフォームはその実行によってポジションの数が増加する可能性がある新しい注文の発注を無効にします。 実際には、プラットホームは、既にポジションを有する銘柄についてのみの発注を可能にします。 現在の未決注文は、実行によって現在のポジションの変更につながる可能性がありますがその数を増やすことはできないので考慮されません。\r\nヘッジング - 未決注文のアクティブ化によって常に新しいポジションが開かれるため、未決注文はポジションとともに考慮されます。限度に達すると、プラットフォームは、成行注文と未決注文の両方での新しい発注を無効にします。")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "未決注文アクティベーションリクエストは却下され、注文はキャンセルされます。")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "銘柄に'Only long positions are allowed（買いポジションのみ）' (POSITION_TYPE_BUY)のルールが設定されているため、リクエストは却下されます。")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "銘柄に'Only short positions are allowed（売りポジションのみ）' (POSITION_TYPE_SELL)のルールが設定されているため、リクエストは却下されます。")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "銘柄に'Only position closing is allowed（ポジション決済のみ）'のルールが設定されているため、リクエストは却下されます。")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "取引口座に'Position closing is allowed only by FIFO rule（FIFOによるポジション決済のみ）'(ACCOUNT_FIFO_CLOSE=true)のフラグが設定されているため、リクエストは却下されます")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "口座で「単一の銘柄の反対のポジションは無効にする」ルールが設定されているため、リクエストが拒否されます。たとえば、銘柄に買いポジションがある場合、売りポジションを開いたり、売り指値注文を出すことはできません。このルールは口座がヘッジ勘定の場合 (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING)のみ適用されます。")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
};
#endif


// Language specific error code resolver (korean)
#ifdef LIB_ERROR_LANG_TERM_ID_KO
const string LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_KO)(const int error_code)
{
    // Perform switch error code
    switch(error_code)
    {
        // General

            /*0*/      LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SUCCESS,                              "ERR_SUCCESS",                             "작업이 성공적으로 완료되었습니다")
            /*4001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INTERNAL_ERROR,                       "ERR_INTERNAL_ERROR",                      "예상하지 못한 내부 오류")
            /*4002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_INTERNAL_PARAMETER,             "ERR_WRONG_INTERNAL_PARAMETER",            "클라이언트 터미널 함수의 내부 호출에 잘못된 매개변수")
            /*4003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_PARAMETER,                    "ERR_INVALID_PARAMETER",                   "시스템 기능을 호출할 때 잘못된 매개변수")
            /*4004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_ENOUGH_MEMORY,                    "ERR_NOT_ENOUGH_MEMORY",                   "메모리가 부족하여 시스템 기능을 수행할 수 없습니다")
            /*4005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRUCT_WITHOBJECTS_ORCLASS,           "ERR_STRUCT_WITHOBJECTS_ORCLASS",          "구조에는 문자열 및/또는 동적 배열 개체 및/또는 그러한 개체 및/또는 클래스의 구조가 포함됩니다")
            /*4006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_ARRAY,                        "ERR_INVALID_ARRAY",                       "잘못된 유형, 잘못된 크기 또는 동적 배열의 손상된 개체 배열")
            /*4007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_RESIZE_ERROR,                   "ERR_ARRAY_RESIZE_ERROR",                  "메모리가 부족하여 배열을 재배치하거나 정적 어레이의 크기를 변경하려고 시도하지 못했습니다")
            /*4008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_RESIZE_ERROR,                  "ERR_STRING_RESIZE_ERROR",                 "메모리가 부족하여 문자열을 재배치할 수 없습니다")
            /*4009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTINITIALIZED_STRING,                "ERR_NOTINITIALIZED_STRING",               "초기화되지 않은 문자열")
            /*4010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_DATETIME,                     "ERR_INVALID_DATETIME",                    "유효하지 않은 날짜 및/또는 시간")
            /*4011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ARRAY_BAD_SIZE,                       "ERR_ARRAY_BAD_SIZE",                      "배열의 총 요소 양은 2147483647을 초과할 수 없습니다")
            /*4012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER,                      "ERR_INVALID_POINTER",                     "잘못된 포인터")
            /*4013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_POINTER_TYPE,                 "ERR_INVALID_POINTER_TYPE",                "포인터의 잘못된 유형")
            /*4014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FUNCTION_NOT_ALLOWED,                 "ERR_FUNCTION_NOT_ALLOWED",                "호출에 허용되지 않는 함수")
            /*4015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_DUPLICATED,             "ERR_RESOURCE_NAME_DUPLICATED",            "동적 리소스와 정적 리소스의 이름이 일치합니다")
            /*4016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NOT_FOUND,                   "ERR_RESOURCE_NOT_FOUND",                  "이 이름의 리소스를 EX5에서 찾을 수 없습니다")
            /*4017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_UNSUPPORTED_TYPE,            "ERR_RESOURCE_UNSUPPORTED_TYPE",           "지원되지 않는 리소스 유형 또는 해당 크기가 16 Mb를 초과합니다")
            /*4018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_RESOURCE_NAME_IS_TOO_LONG,            "ERR_RESOURCE_NAME_IS_TOO_LONG",           "리소스 이름이 63자를 초과합니다")
            /*4019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MATH_OVERFLOW,                        "ERR_MATH_OVERFLOW",                       "산술 함수를 계산할 때 오버플로우가 발생했습니다")
            /*4020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SLEEP_ERROR,                          "ERR_SLEEP_ERROR",                         "Sleep() 호출 후 테스트 종료 날짜 종료")
            /*4022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PROGRAM_STOPPED,                      "ERR_PROGRAM_STOPPED",                     "외부에서 테스트가 강제로 중지되었습니다. 예를 들어 최적화가 중단되거나, 시각적 테스트 창이 닫히거나, 테스트 에이전트가 중지되었습니다")


        // Charts

            /*4101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_ID,                       "ERR_CHART_WRONG_ID",                      "잘못된 차트 ID")
            /*4102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_REPLY,                       "ERR_CHART_NO_REPLY",                      "차트가 응답하지 않음")
            /*4103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NOT_FOUND,                      "ERR_CHART_NOT_FOUND",                     "차트를 찾을 수 없음")
            /*4104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NO_EXPERT,                      "ERR_CHART_NO_EXPERT",                     "차트에 이벤트를 처리할 수 있는 엑스퍼트 어드바이저가 없음")
            /*4105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_OPEN,                    "ERR_CHART_CANNOT_OPEN",                   "차트 열기 오류")
            /*4106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CHANGE,                  "ERR_CHART_CANNOT_CHANGE",                 "차트 기호 및 기간을 변경하는데 실패함")
            /*4107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PARAMETER,                "ERR_CHART_WRONG_PARAMETER",               "차트 작업 함수에 대한 매개변수의 오류 값")
            /*4108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_CANNOT_CREATE_TIMER,            "ERR_CHART_CANNOT_CREATE_TIMER",           "타이머 생성 실패")
            /*4109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WRONG_PROPERTY,                 "ERR_CHART_WRONG_PROPERTY",                "잘못된 차트 속성 ID")
            /*4110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_SCREENSHOT_FAILED,              "ERR_CHART_SCREENSHOT_FAILED",             "스크린샷 생성 오류")
            /*4111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_NAVIGATE_FAILED,                "ERR_CHART_NAVIGATE_FAILED",               "차트를 탐색하는 중 오류")
            /*4112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_TEMPLATE_FAILED,                "ERR_CHART_TEMPLATE_FAILED",               "템플릿 적용 오류")
            /*4113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_WINDOW_NOT_FOUND,               "ERR_CHART_WINDOW_NOT_FOUND",              "지표가 포함된 하위 창을 찾을 수 없습니다")
            /*4114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_ADD,           "ERR_CHART_INDICATOR_CANNOT_ADD",          "차트에 지표 추가 오류")
            /*4115*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_CANNOT_DEL,           "ERR_CHART_INDICATOR_CANNOT_DEL",          "차트 지표 추가 오류")
            /*4116*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHART_INDICATOR_NOT_FOUND,            "ERR_CHART_INDICATOR_NOT_FOUND",           "지정된 차트에서 지표를 찾을 수 없습니다")


        // Graphical Objects

            /*4201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_ERROR,                         "ERR_OBJECT_ERROR",                        "그래픽 개체 작업 오류")
            /*4202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_NOT_FOUND,                     "ERR_OBJECT_NOT_FOUND",                    "그래픽 개체를 찾을 수 없습니다")
            /*4203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_WRONG_PROPERTY,                "ERR_OBJECT_WRONG_PROPERTY",               "그래픽 개체 속성의 ID가 잘못되었습니다")
            /*4204*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETDATE_FAILED,                "ERR_OBJECT_GETDATE_FAILED",               "값에 해당하는 날짜를 가져올 수 없습니다")
            /*4205*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OBJECT_GETVALUE_FAILED,               "ERR_OBJECT_GETVALUE_FAILED",              "날짜에 해당하는 값을 가져올 수 없습니다")


        // MarketInfo

            /*4301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_UNKNOWN_SYMBOL,                "ERR_MARKET_UNKNOWN_SYMBOL",               "알 수 없는 기호")
            /*4302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_NOT_SELECTED,                  "ERR_MARKET_NOT_SELECTED",                 "MarketWatch에서 기호가 선택되지 않았습니다")
            /*4303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_WRONG_PROPERTY,                "ERR_MARKET_WRONG_PROPERTY",               "기호 속성의 잘못된 식별자")
            /*4304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_LASTTIME_UNKNOWN,              "ERR_MARKET_LASTTIME_UNKNOWN",             "마지막 틱 시간을 알 수 없음(틱 없음)")
            /*4305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MARKET_SELECT_ERROR,                  "ERR_MARKET_SELECT_ERROR",                 "MarketWatch에서 기호 추가 또는 삭제 오류")


        // History Access

            /*4401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_NOT_FOUND,                    "ERR_HISTORY_NOT_FOUND",                   "요청 내역을 찾을 수 없음")
            /*4402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_WRONG_PROPERTY,               "ERR_HISTORY_WRONG_PROPERTY",              "내역 속성의 ID가 잘못되었습니다")
            /*4403*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_TIMEOUT,                      "ERR_HISTORY_TIMEOUT",                     "내역 요청 시간 초과")
            /*4404*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_BARS_LIMIT,                   "ERR_HISTORY_BARS_LIMIT",                  "터미널 설정에 의해 제한된 요청된 막대 수")
            /*4405*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_LOAD_ERRORS,                  "ERR_HISTORY_LOAD_ERRORS",                 "내역 로드 시 여러 오류 발생")
            /*4407*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_HISTORY_SMALL_BUFFER,                 "ERR_HISTORY_SMALL_BUFFER",                "수신 배열이 너무 작아 요청된 모든 데이터를 저장할 수 없습니다")


        // Global_Variables

            /*4501*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_FOUND,             "ERR_GLOBALVARIABLE_NOT_FOUND",            "클라이언트 터미널의 글로벌 변수를 찾을 수 없습니다")
            /*4502*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_EXISTS,                "ERR_GLOBALVARIABLE_EXISTS",               "이름이 같은 클라이언트 터미널의 글로벌 변수가 이미 있습니다")
            /*4503*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_NOT_MODIFIED,          "ERR_GLOBALVARIABLE_NOT_MODIFIED",         "글로벌 변수가 수정되지 않았습니다")
            /*4504*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTREAD,            "ERR_GLOBALVARIABLE_CANNOTREAD",           "글로벌 변수 값이 있는 파일을 읽을 수 없습니다")
            /*4505*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_GLOBALVARIABLE_CANNOTWRITE,           "ERR_GLOBALVARIABLE_CANNOTWRITE",          "글로벌 변수 값을 사용하여 파일을 쓸 수 없습니다")
            /*4510*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MAIL_SEND_FAILED,                     "ERR_MAIL_SEND_FAILED",                    "이메일 전송 실패")
            /*4511*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_PLAY_SOUND_FAILED,                    "ERR_PLAY_SOUND_FAILED",                   "사운드 재생 실패")
            /*4512*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_MQL5_WRONG_PROPERTY,                  "ERR_MQL5_WRONG_PROPERTY",                 "프로그램 속성의 식별자가 잘못되었습니다")
            /*4513*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TERMINAL_WRONG_PROPERTY,              "ERR_TERMINAL_WRONG_PROPERTY",             "터미널 속성의 식별자가 잘못되었습니다")
            /*4514*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_SEND_FAILED,                      "ERR_FTP_SEND_FAILED",                     "FTP를 통한 파일 전송 실패")
            /*4515*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_SEND_FAILED,             "ERR_NOTIFICATION_SEND_FAILED",            "알림 전송에 실패")
            /*4516*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_PARAMETER,         "ERR_NOTIFICATION_WRONG_PARAMETER",        "알림 전송 매개변수가 잘못되었습니다. 빈 문자열 또는 NULL이 SendNotification() 함수에 전달되었습니다")
            /*4517*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_WRONG_SETTINGS,          "ERR_NOTIFICATION_WRONG_SETTINGS",         "터미널의 잘못된 알림 설정 (ID가 지정되지 않았거나 권한이 설정되지 않음)")
            /*4518*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOTIFICATION_TOO_FREQUENT,            "ERR_NOTIFICATION_TOO_FREQUENT",           "너무 잦은 알림 전송")
            /*4519*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOSERVER,                         "ERR_FTP_NOSERVER",                        "FTP 서버가 지정되지 않았습니다")
            /*4520*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_NOLOGIN,                          "ERR_FTP_NOLOGIN",                         "FTP 사용자명이 지정되지 않았습니다")
            /*4521*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_FILE_ERROR,                       "ERR_FTP_FILE_ERROR",                      "FTP 서버에서 보낼 MQL5\\Files 디렉토리에서 파일을 찾을 수 없습니다")
            /*4522*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CONNECT_FAILED,                   "ERR_FTP_CONNECT_FAILED",                  "FTP 연결 실패")
            /*4523*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CHANGEDIR,                        "ERR_FTP_CHANGEDIR",                       "서버에서 FTP 경로를 찾을 수 없습니다")
            /*4524*/ //LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FTP_CLOSED,                           "ERR_FTP_CLOSED",                          "FTP 연결 닫힘")


        // Custom Indicator Buffers

            /*4601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_NO_MEMORY,                    "ERR_BUFFERS_NO_MEMORY",                   "메모리가 부족하여 지표 버퍼를 배포할 수 없습니다")
            /*4602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BUFFERS_WRONG_INDEX,                  "ERR_BUFFERS_WRONG_INDEX",                 "잘못된 지표 버퍼 인덱스")
            /*4603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_WRONG_PROPERTY,                "ERR_CUSTOM_WRONG_PROPERTY",               "잘못된 사용자 지정 지표 속성 ID")


        // Custom Indicator Properties")

            /*4701*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ACCOUNT_WRONG_PROPERTY,               "ERR_ACCOUNT_WRONG_PROPERTY",              "잘못된 계정 속성 ID")


        // Account

            /*4751*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_WRONG_PROPERTY,                 "ERR_TRADE_WRONG_PROPERTY",                "잘못된 거래 속성 ID")
            /*4752*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DISABLED,                       "ERR_TRADE_DISABLED",                      "엑스퍼트 어드바이저에 의한 트레이딩 금지")
            /*4753*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_POSITION_NOT_FOUND,             "ERR_TRADE_POSITION_NOT_FOUND",            "포지션을 찾을 수 없습니다")
            /*4754*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_ORDER_NOT_FOUND,                "ERR_TRADE_ORDER_NOT_FOUND",               "주문을 찾을 수 없습니다")
            /*4755*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_DEAL_NOT_FOUND,                 "ERR_TRADE_DEAL_NOT_FOUND",                "딜을 찾을 수 없습니다")
            /*4756*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_SEND_FAILED,                    "ERR_TRADE_SEND_FAILED",                   "거래 요청 전송 실패")
            /*4758*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TRADE_CALC_FAILED,                    "ERR_TRADE_CALC_FAILED",                   "이익 또는 마진을 계산하지 못했습니다")


        // Indicators

            /*4801*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_UNKNOWN_SYMBOL,             "ERR_INDICATOR_UNKNOWN_SYMBOL",            "알 수 없는 기호")
            /*4802*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_CREATE,              "ERR_INDICATOR_CANNOT_CREATE",             "지표가 생성되지 않았습니다")
            /*4803*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_NO_MEMORY,                  "ERR_INDICATOR_NO_MEMORY",                 "지표를 추가할 수 있는 충분한 자금이 없습니다")
            /*4804*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_APPLY,               "ERR_INDICATOR_CANNOT_APPLY",              "지표를 다른 지표에 적용할 수 없습니다")
            /*4805*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CANNOT_ADD,                 "ERR_INDICATOR_CANNOT_ADD",                "차트에 지표 적용 오류")
            /*4806*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_DATA_NOT_FOUND,             "ERR_INDICATOR_DATA_NOT_FOUND",            "요청 데이터를 찾을 수 없습니다")
            /*4807*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_HANDLE,               "ERR_INDICATOR_WRONG_HANDLE",              "잘못된 지표 핸들")
            /*4808*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_PARAMETERS,           "ERR_INDICATOR_WRONG_PARAMETERS",          "지표 생성 시 잘못된 매개변수의 수")
            /*4809*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETERS_MISSING,         "ERR_INDICATOR_PARAMETERS_MISSING",        "지표 작성 시 매개변수 없음")
            /*4810*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_CUSTOM_NAME,                "ERR_INDICATOR_CUSTOM_NAME",               "배열의 첫 번째 매개변수는 사용자 지정 지표의 이름이어야 합니다")
            /*4811*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_PARAMETER_TYPE,             "ERR_INDICATOR_PARAMETER_TYPE",            "지표를 만들 때 배열의 매개변수 유형이 잘못되었습니다")
            /*4812*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INDICATOR_WRONG_INDEX,                "ERR_INDICATOR_WRONG_INDEX",               "요청한 지표 버퍼의 인덱스가 잘못되었습니다")


        // Depth of Market

            /*4901*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_ADD,                     "ERR_BOOKS_CANNOT_ADD",                    "Depth Of Market을 추가할 수 없습니다")
            /*4902*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_DELETE,                  "ERR_BOOKS_CANNOT_DELETE",                 "Depth Of Market을 제거할 수 없습니다")
            /*4903*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_GET,                     "ERR_BOOKS_CANNOT_GET",                    "Depth Of Market의 데이터를 가져올 수 없습니다")
            /*4904*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_BOOKS_CANNOT_SUBSCRIBE,               "ERR_BOOKS_CANNOT_SUBSCRIBE",              "Depth Of Market에서 새 데이터를 수신하는 동안 오류가 발생했습니다")


        // File Operations

            /*5001*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FILES,                       "ERR_TOO_MANY_FILES",                      "64개 이상의 파일을 동시에 열 수 없습니다")
            /*5002*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILENAME,                       "ERR_WRONG_FILENAME",                      "유효하지 않은 파일 이름")
            /*5003*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_LONG_FILENAME,                    "ERR_TOO_LONG_FILENAME",                   "파일 이름이 너무 깁니다")
            /*5004*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_OPEN_FILE,                     "ERR_CANNOT_OPEN_FILE",                    "파일 열기 오류")
            /*5005*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CACHEBUFFER_ERROR,               "ERR_FILE_CACHEBUFFER_ERROR",              "캐시를 읽을 메모리가 부족합니다")
            /*5006*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_FILE,                   "ERR_CANNOT_DELETE_FILE",                  "파일 삭제 오류")
            /*5007*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INVALID_FILEHANDLE,                   "ERR_INVALID_FILEHANDLE",                  "이 핸들이 있는 파일이 닫혔거나 전혀 열리지 않습니다")
            /*5008*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FILEHANDLE,                     "ERR_WRONG_FILEHANDLE",                    "잘못된 파일 핸들")
            /*5009*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOWRITE,                      "ERR_FILE_NOTTOWRITE",                     "쓰기 위해 파일을 열어야 합니다")
            /*5010*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTOREAD,                       "ERR_FILE_NOTTOREAD",                      "읽기 위해 파일을 열어야 합니다")
            /*5011*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTBIN,                          "ERR_FILE_NOTBIN",                         "파일을 바이너리 파일로 열어야 합니다")
            /*5012*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXT,                          "ERR_FILE_NOTTXT",                         "파일을 텍스트로 열어야 합니다")
            /*5013*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTTXTORCSV,                     "ERR_FILE_NOTTXTORCSV",                    "파일을 텍스트 또는 CSV로 열어야 합니다")
            /*5014*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOTCSV,                          "ERR_FILE_NOTCSV",                         "파일을 CSV로 열어야 합니다")
            /*5015*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_READERROR,                       "ERR_FILE_READERROR",                      "파일 읽기 오류")
            /*5016*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_BINSTRINGSIZE,                   "ERR_FILE_BINSTRINGSIZE",                  "파일이 바이너리 파일로 열렸으므로 문자열 크기를 지정해야 합니다")
            /*5017*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_FILE,                    "ERR_INCOMPATIBLE_FILE",                   "텍스트 파일은 문자열 배열이어야 하며, 기타 배열은 바이너리여야 합니다")
            /*5018*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_IS_DIRECTORY,                    "ERR_FILE_IS_DIRECTORY",                   "파일이 아니라, 디렉토리입니다")
            /*5019*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_NOT_EXIST,                       "ERR_FILE_NOT_EXIST",                      "파일이 존재하지 않습니다")
            /*5020*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_CANNOT_REWRITE,                  "ERR_FILE_CANNOT_REWRITE",                 "파일을 재쓰기할 수 없습니다")
            /*5021*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_DIRECTORYNAME,                  "ERR_WRONG_DIRECTORYNAME",                 "잘못된 디렉토리 이름")
            /*5022*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DIRECTORY_NOT_EXIST,                  "ERR_DIRECTORY_NOT_EXIST",                 "디렉토리가 존재하지 않습니다")
            /*5023*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ISNOT_DIRECTORY,                 "ERR_FILE_ISNOT_DIRECTORY",                "디렉토리가 아니라, 파일입니다")
            /*5024*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_DELETE_DIRECTORY,              "ERR_CANNOT_DELETE_DIRECTORY",             "디렉토리를 제거할 수 없습니다")
            /*5025*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CANNOT_CLEAN_DIRECTORY,               "ERR_CANNOT_CLEAN_DIRECTORY",              "디렉토리 비우기 실패 (하나 이상의 파일이 차단되고 제거 작업이 실패했을 수 있음)")
            /*5026*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_WRITEERROR,                      "ERR_FILE_WRITEERROR",                     "파일에 리소스를 쓰지 못했습니다")
            /*5027*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FILE_ENDOFFILE,                       "ERR_FILE_ENDOFFILE",                      "파일의 끝에 도달했기 때문에 CSV 파일(FileReadString, FileReadNumber, FileReadDatetime, FileReadBool)에서 다음 데이터를 읽을 수 없습니다")


        // String Casting

            /*5030*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NO_STRING_DATE,                       "ERR_NO_STRING_DATE",                      "문자열에 데이터가 없습니다")
            /*5031*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_DATE,                    "ERR_WRONG_STRING_DATE",                   "잘못된 문자열 데이터")
            /*5032*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_TIME,                    "ERR_WRONG_STRING_TIME",                   "잘못된 문자열 시간")
            /*5033*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TIME_ERROR,                    "ERR_STRING_TIME_ERROR",                   "문자열을 날짜로 전환하는데 오류")
            /*5034*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_OUT_OF_MEMORY,                 "ERR_STRING_OUT_OF_MEMORY",                "문자열에 대해 메모리가 충분하지 않습니다")
            /*5035*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_SMALL_LEN,                     "ERR_STRING_SMALL_LEN",                    "문자열 길이가 예상보다 적습니다")
            /*5036*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_TOO_BIGNUMBER,                 "ERR_STRING_TOO_BIGNUMBER",                "너무 큰 수, ULONG_MAX보다 큼")
            /*5037*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_FORMATSTRING,                   "ERR_WRONG_FORMATSTRING",                  "유효하지 않은 서식 문자열")
            /*5038*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_FORMATTERS,                  "ERR_TOO_MANY_FORMATTERS",                 "서식 지정자의 양이 매개변수보다 큼")
            /*5039*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_TOO_MANY_PARAMETERS,                  "ERR_TOO_MANY_PARAMETERS",                 "서식 지정자보다 많은 매개변수 양")
            /*5040*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_PARAMETER,               "ERR_WRONG_STRING_PARAMETER",              "문자열 유형의 매개변수가 손상됨")
            /*5041*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRINGPOS_OUTOFRANGE,                 "ERR_STRINGPOS_OUTOFRANGE",                "문자열 외부에 위치")
            /*5042*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ZEROADDED,                     "ERR_STRING_ZEROADDED",                    "문자열 끝에 0이 추가되어 사용할 수 없는 작업입니다")
            /*5043*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_UNKNOWNTYPE,                   "ERR_STRING_UNKNOWNTYPE",                  "문자열로 변환할 때 알 수 없는 데이터 유형")
            /*5044*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WRONG_STRING_OBJECT,                  "ERR_WRONG_STRING_OBJECT",                 "손상된 문자열 개체")


        // Operations with Arrays

            /*5050*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INCOMPATIBLE_ARRAYS,                  "ERR_INCOMPATIBLE_ARRAYS",                 "호환되지 않는 배열을 복사. 문자열 배열은 문자열 배열 및 숫자 배열은 숫자 배열에만 복사할 수 있습니다")
            /*5051*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ASSERIES_ARRAY,                 "ERR_SMALL_ASSERIES_ARRAY",                "수신 배열이 AS_SERIES로 선언되었으며 크기가 부족합니다")
            /*5052*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SMALL_ARRAY,                          "ERR_SMALL_ARRAY",                         "시작 포지션이 배열 외부에 있는 너무 작은 배열입니다")
            /*5053*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ZEROSIZE_ARRAY,                       "ERR_ZEROSIZE_ARRAY",                      "0길이의 배열")
            /*5054*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NUMBER_ARRAYS_ONLY,                   "ERR_NUMBER_ARRAYS_ONLY",                  "숫자 배열이어야 합니다")
            /*5055*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_ONEDIM_ARRAYS_ONLY,                   "ERR_ONEDIM_ARRAYS_ONLY",                  "1차원 배열이어야 합니다")
            /*5056*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SERIES_ARRAY,                         "ERR_SERIES_ARRAY",                        "시계열을 사용할 수 없습니다")
            /*5057*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DOUBLE_ARRAY_ONLY,                    "ERR_DOUBLE_ARRAY_ONLY",                   "double 유형의 배열이어야 합니다")
            /*5058*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_FLOAT_ARRAY_ONLY,                     "ERR_FLOAT_ARRAY_ONLY",                    "float 유형의 배열이어야 합니다")
            /*5059*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_LONG_ARRAY_ONLY,                      "ERR_LONG_ARRAY_ONLY",                     "long 유형의 배열이어야 합니다")
            /*5060*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_INT_ARRAY_ONLY,                       "ERR_INT_ARRAY_ONLY",                      "int 유형의 배열이어야 합니다")
            /*5061*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_SHORT_ARRAY_ONLY,                     "ERR_SHORT_ARRAY_ONLY",                    "short 유형의 배열이어야 합니다")
            /*5062*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CHAR_ARRAY_ONLY,                      "ERR_CHAR_ARRAY_ONLY",                     "char 유형의 배열이어야 합니다")
            /*5063*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_STRING_ARRAY_ONLY,                    "ERR_STRING_ARRAY_ONLY",                   "문자열 배열 전용")


        // Operations with OpenCL

            /*5100*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_NOT_SUPPORTED,                 "ERR_OPENCL_NOT_SUPPORTED",                "OpenCL 기능은 이 컴퓨터에서 지원되지 않습니다")
            /*5101*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INTERNAL,                      "ERR_OPENCL_INTERNAL",                     "다음을 실행하는 동안 내부 오류가 발생했습니다: OpenCL 실행 중")
            /*5102*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_INVALID_HANDLE,                "ERR_OPENCL_INVALID_HANDLE",               "유효하지 않은 OpenCL 핸들")
            /*5103*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_CONTEXT_CREATE,                "ERR_OPENCL_CONTEXT_CREATE",               "다음을 생성하는데 오류: OpenCL 컨텍스트")
            /*5104*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_QUEUE_CREATE,                  "ERR_OPENCL_QUEUE_CREATE",                 "OpenCL에서 실행 대기열을 만들지 못했습니다")
            /*5105*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_PROGRAM_CREATE,                "ERR_OPENCL_PROGRAM_CREATE",               "다음 중 오류 발생: OpenCL 프로그램 컴파일링")
            /*5106*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_LONG_KERNEL_NAME,          "ERR_OPENCL_TOO_LONG_KERNEL_NAME",         "너무 긴 커널 이름 (OpenCL 커널)")
            /*5107*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_KERNEL_CREATE,                 "ERR_OPENCL_KERNEL_CREATE",                "다음 생성 시 오류: OpenCL 커널")
            /*5108*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SET_KERNEL_PARAMETER,          "ERR_OPENCL_SET_KERNEL_PARAMETER",         "다음 중 오류 발생: OpenCL 커널에 대한매개변수 설정 중")
            /*5109*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_EXECUTE,                       "ERR_OPENCL_EXECUTE",                      "OpenCL 프로그램 런타임 오류")
            /*5110*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_SIZE,             "ERR_OPENCL_WRONG_BUFFER_SIZE",            "유효하지 않은 OpenCL 버퍼 크기")
            /*5111*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_WRONG_BUFFER_OFFSET,           "ERR_OPENCL_WRONG_BUFFER_OFFSET",          "유효하지 않은 OpenCL 버퍼의 오프셋")
            /*5112*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_BUFFER_CREATE,                 "ERR_OPENCL_BUFFER_CREATE",                "다음을 생성하는데 실패: OpenCL 버퍼")
            /*5113*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_TOO_MANY_OBJECTS,              "ERR_OPENCL_TOO_MANY_OBJECTS",             "너무 많은 OpenCL 개체")
            /*5114*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_OPENCL_SELECTDEVICE,                  "ERR_OPENCL_SELECTDEVICE",                 "OpenCL 장치 선택 오류")


        // Operations with Databases

            /*5120*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERNAL,                    "ERR_DATABASE_INTERNAL",                   "내부 데이터베이스 오류")
            /*5121*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INVALID_HANDLE,              "ERR_DATABASE_INVALID_HANDLE",             "유효하지 않은 데이터베이스 핸들")
            /*5122*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOO_MANY_OBJECTS,            "ERR_DATABASE_TOO_MANY_OBJECTS",           "허용되는 최대 데이터베이스 개체 수를 초과")
            /*5123*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONNECT,                     "ERR_DATABASE_CONNECT",                    "데이터베이스 연결 오류")
            /*5124*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EXECUTE,                     "ERR_DATABASE_EXECUTE",                    "요청 실행 오류")
            /*5125*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PREPARE,                     "ERR_DATABASE_PREPARE",                    "요청 생성 오류")
            /*5126*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NO_MORE_DATA,                "ERR_DATABASE_NO_MORE_DATA",               "읽을 데이터가 더 없습니다")
            /*5127*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_STEP,                        "ERR_DATABASE_STEP",                       "다음 요청 진입으로 이동 실패")
            /*5128*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOT_READY,                   "ERR_DATABASE_NOT_READY",                  "요청 결과를 읽기 위한 데이터가 준비되지 않았습니다")
            /*5129*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BIND_PARAMETERS,             "ERR_DATABASE_BIND_PARAMETERS",            "SQL 요청에 매개변수를 자동 대체하지 못했습니다")


        // Operations with WebRequest

            /*5200*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_INVALID_ADDRESS,           "ERR_WEBREQUEST_INVALID_ADDRESS",          "유효하지 않은 URL")
            /*5201*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_CONNECT_FAILED,            "ERR_WEBREQUEST_CONNECT_FAILED",           "지정 URL로 연결 실패")
            /*5202*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_TIMEOUT,                   "ERR_WEBREQUEST_TIMEOUT",                  "시간 초과")
            /*5203*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_WEBREQUEST_REQUEST_FAILED,            "ERR_WEBREQUEST_REQUEST_FAILED",           "HTTP 요청 실패")


        // Operations with Network Sockets

            /*5270*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_INVALIDHANDLE,              "ERR_NETSOCKET_INVALIDHANDLE",             "유효하지 않은 소켓 핸들이 함수로 전달됨")
            /*5271*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_TOO_MANY_OPENED,            "ERR_NETSOCKET_TOO_MANY_OPENED",           "너무 많은 오픈 소캣 (최대 128)")
            /*5272*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_CANNOT_CONNECT,             "ERR_NETSOCKET_CANNOT_CONNECT",            "원격 호스트에 연결 실패")
            /*5273*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_IO_ERROR,                   "ERR_NETSOCKET_IO_ERROR",                  "소켓에서 데이터 송수신 실패")
            /*5274*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_HANDSHAKE_FAILED,           "ERR_NETSOCKET_HANDSHAKE_FAILED",          "보안 연결 설정을 실패 (TLS Handshake)")
            /*5275*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NETSOCKET_NO_CERTIFICATE,             "ERR_NETSOCKET_NO_CERTIFICATE",            "연결을 보호하는 인증서에 데이터가 없음")


        // Custom Symbols

            /*5300*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_NOT_CUSTOM_SYMBOL,                    "ERR_NOT_CUSTOM_SYMBOL",                   "사용자 지정 기호를 지정해야 합니다")
            /*5301*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_WRONG_NAME,             "ERR_CUSTOM_SYMBOL_WRONG_NAME",            "사용자 지정 기호의 이름이 잘못되었습니다. 기호 이름에는 구두점, 공백 또는 특수 문자(may only contain '.', '_', '&' and '#') 없이 라틴 문자만 사용할 수 있습니다. <, >, :, \", /,\\, |, ?, *. 문자를 사용하지 마십시오")
            /*5302*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_NAME_LONG,              "ERR_CUSTOM_SYMBOL_NAME_LONG",             "사용자 지정 기호의 이름이 너무 깁니다. 기호 이름의 길이는 끝 0자를 포함하여 32자를 초과할 수 없습니다")
            /*5303*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PATH_LONG,              "ERR_CUSTOM_SYMBOL_PATH_LONG",             "사용자 지정 기호의 경로가 너무 깁니다. 경로 길이는 'Custom\\', 기호 이름, 그룹 구분 기호 및 끝 0을 포함하여 128자를 초과할 수 없습니다")
            /*5304*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_EXIST,                  "ERR_CUSTOM_SYMBOL_EXIST",                 "이름이 같은 사용자 지정 기호가 이미 있습니다")
            /*5305*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_ERROR,                  "ERR_CUSTOM_SYMBOL_ERROR",                 "사용자 지정 기호를 작성, 삭제 또는 변경하는 동안 오류가 발생했습니다")
            /*5306*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_SELECTED,               "ERR_CUSTOM_SYMBOL_SELECTED",              "마켓 워치(Market Watch)에서 선택한 사용자 지정 기호를 삭제하려고 합니다")
            /*5307*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PROPERTY_WRONG,         "ERR_CUSTOM_SYMBOL_PROPERTY_WRONG",        "유효하지 않은 사용자 지정 기호 속성")
            /*5308*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_ERROR,        "ERR_CUSTOM_SYMBOL_PARAMETER_ERROR",       "사용자 지정 기호의 속성을 설정하는 동안 잘못된 매개변수")
            /*5309*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_SYMBOL_PARAMETER_LONG,         "ERR_CUSTOM_SYMBOL_PARAMETER_LONG",        "사용자 지정 기호의 속성을 설정하는 동안 문자열 매개변수가 너무 깁니다")
            /*5310*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CUSTOM_TICKS_WRONG_ORDER,             "ERR_CUSTOM_TICKS_WRONG_ORDER",            "배열의 틱은 시간 순서대로 배열되지 않습니다")


        // Economics calendar

            /*5400*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_MORE_DATA,                   "ERR_CALENDAR_MORE_DATA",                  "배열의 크기가 부족하여 모든 값에 대한 설명을 수신할 수 없습니다")
            /*5401*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_TIMEOUT,                     "ERR_CALENDAR_TIMEOUT",                    "요청 시간 제한 초과")
            /*5402*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_CALENDAR_NO_DATA,                     "ERR_CALENDAR_NO_DATA",                    "국가를 찾을 수 없습니다]")


        // Working with Databases

            /*5601*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ERROR,                       "ERR_DATABASE_ERROR",                      "일반 오류")
            /*5602*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOGIC,                       "ERR_DATABASE_LOGIC",                      "SQLite 내부 로직 오류")
            /*5603*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PERM,                        "ERR_DATABASE_PERM",                       "액세스 거부됨")
            /*5604*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_ABORT,                       "ERR_DATABASE_ABORT",                      "콜백 루틴 중단이 요청됨")
            /*5605*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_BUSY,                        "ERR_DATABASE_BUSY",                       "데이터베이스 파일 잠김")
            /*5606*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_LOCKED,                      "ERR_DATABASE_LOCKED",                     "데이터베이스 테이블 잠김")
            /*5607*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOMEM,                       "ERR_DATABASE_NOMEM",                      "작업을 완료하기에 충분하지 않은 메모리")
            /*5608*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_READONLY,                    "ERR_DATABASE_READONLY",                   "읽기전용 데이터베이스에 쓰기 시도")
            /*5609*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_INTERRUPT,                   "ERR_DATABASE_INTERRUPT",                  "sqlite3_interrupt()가 작업을 종료함")
            /*5610*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_IOERR,                       "ERR_DATABASE_IOERR",                      "Disk I/O error")
            /*5611*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CORRUPT,                     "ERR_DATABASE_CORRUPT",                    "데이터베이스 디스크 이미지가 손상됨")
            /*5612*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTFOUND,                    "ERR_DATABASE_NOTFOUND",                   "sqlite3_file_control()의 알 수 없는 작업 코드")
            /*5613*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FULL,                        "ERR_DATABASE_FULL",                       "데이터베이스가 가득 차서 삽입에 실패")
            /*5614*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CANTOPEN,                    "ERR_DATABASE_CANTOPEN",                   "데이터베이스 파일을 열 수 없습니다")
            /*5615*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_PROTOCOL,                    "ERR_DATABASE_PROTOCOL",                   "데이터베이스 잠금 프로토콜 오류")
            /*5616*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_EMPTY,                       "ERR_DATABASE_EMPTY",                      "내부 사용 전용")
            /*5617*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_SCHEMA,                      "ERR_DATABASE_SCHEMA",                     "데이터베이스 개요 변경됨")
            /*5618*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_TOOBIG,                      "ERR_DATABASE_TOOBIG",                     "문자열 또는 BLOB가 크기 제한을 초과")
            /*5619*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_CONSTRAINT,                  "ERR_DATABASE_CONSTRAINT",                 "제약 위반으로 인해 중단")
            /*5620*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISMATCH,                    "ERR_DATABASE_MISMATCH",                   "데이터 유형 일치하지 않음")
            /*5621*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_MISUSE,                      "ERR_DATABASE_MISUSE",                     "라이브러리가 잘못 사용됨")
            /*5622*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOLFS,                       "ERR_DATABASE_NOLFS",                      "호스트에서 지원되지 않는 OS 기능 사용")
            /*5623*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_AUTH,                        "ERR_DATABASE_AUTH",                       "인증 거부됨")
            /*5624*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_FORMAT,                      "ERR_DATABASE_FORMAT",                     "사용되지 않음")
            /*5625*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_RANGE,                       "ERR_DATABASE_RANGE",                      "바인딩 매개변수 오류, 잘못된 인덱스")
            /*5626*/   LIB_ERR_REGISTER_RESOLVER_MSGCODE(ERR_DATABASE_NOTADB,                      "ERR_DATABASE_NOTADB",                     "데이터베이스 파일이 아닌 열려 있는 파일")


        // Return Codes of the Trade Server

            /*10004*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REQUOTE,                    "TRADE_RETCODE_REQUOTE",                   "재산정")
            /*10006*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT,                     "TRADE_RETCODE_REJECT",                    "요청 거부됨")
            /*10007*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CANCEL,                     "TRADE_RETCODE_CANCEL",                    "트레이더에 의한 요청 취소")
            /*10008*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PLACED,                     "TRADE_RETCODE_PLACED",                    "주문 발주")
            /*10009*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE,                       "TRADE_RETCODE_DONE",                      "요청 완료")
            /*10010*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_DONE_PARTIAL,               "TRADE_RETCODE_DONE_PARTIAL",              "요청의 일부분만 완료됨")
            /*10011*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ERROR,                      "TRADE_RETCODE_ERROR",                     "요청 진행 오류")
            /*10012*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TIMEOUT,                    "TRADE_RETCODE_TIMEOUT",                   "시간 종료에 의한 요청 취소")
            /*10013*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID,                    "TRADE_RETCODE_INVALID",                   "유효하지 않은 요청")
            /*10014*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_VOLUME,             "TRADE_RETCODE_INVALID_VOLUME",            "요청의 유효하지 않은 볼륨")
            /*10015*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_PRICE,              "TRADE_RETCODE_INVALID_PRICE",             "요청의 유효하지 않은 가격")
            /*10016*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_STOPS,              "TRADE_RETCODE_INVALID_STOPS",             "요청의 유효하지 않은 중지")
            /*10017*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TRADE_DISABLED,             "TRADE_RETCODE_TRADE_DISABLED",            "거래가 불가능")
            /*10018*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_MARKET_CLOSED,              "TRADE_RETCODE_MARKET_CLOSED",             "마켓이 닫힘")
            /*10019*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_MONEY,                   "TRADE_RETCODE_NO_MONEY",                  "금액이 부족하여 요청을 완료할 수 없습니다")
            /*10020*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_CHANGED,              "TRADE_RETCODE_PRICE_CHANGED",             "가격 변경됨")
            /*10021*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_PRICE_OFF,                  "TRADE_RETCODE_PRICE_OFF",                 "요청을 진행할 시세가 없습니다")
            /*10022*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_EXPIRATION,         "TRADE_RETCODE_INVALID_EXPIRATION",        "요청의 유효하지 않은 주문 만료일")
            /*10023*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ORDER_CHANGED,              "TRADE_RETCODE_ORDER_CHANGED",             "주문 상태 변경됨")
            /*10024*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_TOO_MANY_REQUESTS,          "TRADE_RETCODE_TOO_MANY_REQUESTS",         "너무 빈번한 요청")
            /*10025*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_NO_CHANGES,                 "TRADE_RETCODE_NO_CHANGES",                "요청에 변경사항 없음")
            /*10026*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SERVER_DISABLES_AT,         "TRADE_RETCODE_SERVER_DISABLES_AT",        "서버에서 자동거래 사용하지 않음")
            /*10027*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLIENT_DISABLES_AT,         "TRADE_RETCODE_CLIENT_DISABLES_AT",        "클라이언트 터미널에서 자동거래 사용하지 않음")
            /*10028*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LOCKED,                     "TRADE_RETCODE_LOCKED",                    "요청을 처리하기 위해 잠김")
            /*10029*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FROZEN,                     "TRADE_RETCODE_FROZEN",                    "주문 또는 포지션이 동결됨")
            /*10030*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_FILL,               "TRADE_RETCODE_INVALID_FILL",              "유효하지 않은 주문 채우기 유형")
            /*10031*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CONNECTION,                 "TRADE_RETCODE_CONNECTION",                "거래 서버와의 연결이 없음")
            /*10032*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_ONLY_REAL,                  "TRADE_RETCODE_ONLY_REAL",                 "활성 계정에 대해서만 작업이 허용됩니다")
            /*10033*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_ORDERS,               "TRADE_RETCODE_LIMIT_ORDERS",              "보류 중인 주문의 수가 한도에 도달했습니다")
            /*10034*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_VOLUME,               "TRADE_RETCODE_LIMIT_VOLUME",              "기호에 대한 주문 및 포지션의 양이 한계에 도달했습니다")
            /*10035*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_ORDER,              "TRADE_RETCODE_INVALID_ORDER",             "잘못되었거나 금지된 주문 유형")
            /*10036*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_POSITION_CLOSED,            "TRADE_RETCODE_POSITION_CLOSED",           "지정한 POSITION_IDENTIFIER가 있는 포지션이 이미 닫혔습니다")
            /*10038*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_INVALID_CLOSE_VOLUME,       "TRADE_RETCODE_INVALID_CLOSE_VOLUME",      "닫기 볼륨이 현재 포지션 볼륨을 초과합니다")
            /*10039*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ORDER_EXIST,          "TRADE_RETCODE_CLOSE_ORDER_EXIST",         "지정 포지션에 대한 마감 순서가 이미 있습니다. 이러한 상황은 위험회피 시스템에서 작업할 때 발생할 수 있습니다: \r\n포지션에 대한 닫기 명령이 이미 있는 동안 반대 포지션으로 포지션을 닫으려고 할 때 \r\n이미 존재하는 마감 주문의 총 볼륨과 새로 배치된 주문의 총 볼륨이 현재 위치 볼륨을 초과하는 경우 전체 또는 부분적으로 위치를 닫으려고 할 때")
            /*10040*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LIMIT_POSITIONS,            "TRADE_RETCODE_LIMIT_POSITIONS",           "계정에 동시에 존재하는 열려 있는 포지션 수는 서버 설정에 의해 제한될 수 있습니다. 제한에 도달하면 서버는 주문을 시도할 때 TRADE_RETCODE_LIMIT_POSITIONS 오류를 반환합니다. 포지션 계정 유형에 따라 제한이 다르게 작동합니다: \r\nNetting — 열린 포지션의 수를 고려합니다. 제한에 도달하면 플랫폼이 새 주문을 작성할 수 없도록 하고, 이 주문이 실행되면 열린 포지션 수가 증가할 수 있습니다. 실제로 플랫폼에서는 이미 열린 포지션이 있는 기호에 대해서만 주문을 할 수 있습니다. 현재 보류 중인 주문은 실행이 현재 위치의 변경으로 이어질 수 있지만 수를 늘릴 수는 없기 때문에 고려되지 않습니다. \r\nHedging — 보류 중인 주문 활성화는 항상 새 포지션을 열기 때문에 보류 중인 주문은 열린 포지션과 함꼐 고려됩니다. 한도에 도달하면 플랫폼에서는 신규 시장 주문과 보류 중인 주문을 모두 배치할 수 없습니다")
            /*10041*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_REJECT_CANCEL,              "TRADE_RETCODE_REJECT_CANCEL",             "보류 중인 주문 활성화 요청이 거부되어 주문이 취소되었습니다")
            /*10042*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_LONG_ONLY,                  "TRADE_RETCODE_LONG_ONLY",                 "기호에 대해 '장기 포지션만 허용' 규칙이 설정되었기 때문에 요청이 거부되었습니다 (POSITION_TYPE_BUY)")
            /*10043*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_SHORT_ONLY,                 "TRADE_RETCODE_SHORT_ONLY",                "기호에 대해 '단기 포지션만 허용' 규칙이 설정되었기 때문에 요청이 거부되었습니다 (POSITION_TYPE_SELL)")
            /*10044*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_CLOSE_ONLY,                 "TRADE_RETCODE_CLOSE_ONLY",                "기호에 대해 '포지션 닫기만 허용' 규칙이 설정되었기 때문에 요청이 거부되었습니다")
            /*10045*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_FIFO_ONLY,                  "TRADE_RETCODE_FIFO_ONLY",                 "'포지션 마감은 FIFO 규칙에 의해서만 허용됨' 플래그가 설정이 거래 계정 (ACCOUNT_FIFO_CLOSE=true)에 대해 되었기 때문에 요청이 거부되었습니다")
            /*10046*/  LIB_ERR_REGISTER_RESOLVER_MSGCODE(TRADE_RETCODE_HEDGE_PROHIBITED,           "TRADE_RETCODE_HEDGE_PROHIBITED",          "거래 계정에 대해 '단일 기호의 반대 포지션이 비활성화됨' 규칙이 설정되었기 때문에 요청이 거부됩니다. 예를 들어, 계정에 매수 포지션이 있는 경우 사용자는 매도 포지션을 열거나 보류 중인 매도 주문을 작성할 수 없습니다. 이 규칙은 위험회피 회계 시스템이 있는 계정에만 적용됩니다 (ACCOUNT_MARGIN_MODE=ACCOUNT_MARGIN_MODE_RETAIL_HEDGING)")
    }

    // Return
    return(LIB_ERROR_LANGUAGE_FUNCTION(LIB_ERROR_LANG_TERM_ID_EN)(error_code));
}
#endif



///////////////////////////////////////
#endif // LIB_ERRDESC_MQH_INCLUDED